@@ -22,23 +22,23 @@ from nova.api.openstack import extensions
 from nova.api.openstack import wsgi
 from nova import compute
 from nova import exception
+from nova.policies import deferred_delete as dd_policies
 
 ALIAS = 'os-deferred-delete'
-authorize = extensions.os_compute_authorizer(ALIAS)
 
 
 class DeferredDeleteController(wsgi.Controller):
     def __init__(self, *args, **kwargs):
         super(DeferredDeleteController, self).__init__(*args, **kwargs)
-        self.compute_api = compute.API(skip_policy_check=True)
+        self.compute_api = compute.API()
 
     @wsgi.response(202)
-    @extensions.expected_errors((404, 409, 403))
+    @extensions.expected_errors((403, 404, 409))
     @wsgi.action('restore')
     def _restore(self, req, id, body):
         """Restore a previously deleted instance."""
         context = req.environ["nova.context"]
-        authorize(context)
+        context.can(dd_policies.BASE_POLICY_NAME)
         instance = common.get_instance(self.compute_api, context, id)
         try:
             self.compute_api.restore(context, instance)
@@ -56,10 +56,16 @@ class DeferredDeleteController(wsgi.Controller):
     def _force_delete(self, req, id, body):
         """Force delete of instance before deferred cleanup."""
         context = req.environ["nova.context"]
-        authorize(context)
         instance = common.get_instance(self.compute_api, context, id)
+        context.can(dd_policies.BASE_POLICY_NAME,
+                    target={'user_id': instance.user_id,
+                            'project_id': instance.project_id})
         try:
             self.compute_api.force_delete(context, instance)
+        except exception.InstanceNotFound as e:
+            raise webob.exc.HTTPNotFound(explanation=e.format_message())
+        except exception.InstanceUnknownCell as e:
+            raise webob.exc.HTTPNotFound(explanation=e.format_message())
         except exception.InstanceIsLocked as e:
             raise webob.exc.HTTPConflict(explanation=e.format_message())
 
