@@ -13,9 +13,11 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import six
+
 from webob import exc
 
+from nova.api.openstack.api_version_request import \
+    MAX_IMAGE_META_PROXY_API_VERSION
 from nova.api.openstack import common
 from nova.api.openstack.compute.schemas import image_metadata
 from nova.api.openstack import extensions
@@ -43,6 +45,7 @@ class ImageMetadataController(wsgi.Controller):
             msg = _("Image not found.")
             raise exc.HTTPNotFound(explanation=msg)
 
+    @wsgi.Controller.api_version("2.1", MAX_IMAGE_META_PROXY_API_VERSION)
     @extensions.expected_errors((403, 404))
     def index(self, req, image_id):
         """Returns the list of metadata for a given instance."""
@@ -50,6 +53,7 @@ class ImageMetadataController(wsgi.Controller):
         metadata = self._get_image(context, image_id)['properties']
         return dict(metadata=metadata)
 
+    @wsgi.Controller.api_version("2.1", MAX_IMAGE_META_PROXY_API_VERSION)
     @extensions.expected_errors((403, 404))
     def show(self, req, image_id, id):
         context = req.environ['nova.context']
@@ -59,12 +63,13 @@ class ImageMetadataController(wsgi.Controller):
         else:
             raise exc.HTTPNotFound()
 
-    @extensions.expected_errors((400, 403, 404, 413))
+    @wsgi.Controller.api_version("2.1", MAX_IMAGE_META_PROXY_API_VERSION)
+    @extensions.expected_errors((400, 403, 404))
     @validation.schema(image_metadata.create)
     def create(self, req, image_id, body):
         context = req.environ['nova.context']
         image = self._get_image(context, image_id)
-        for key, value in six.iteritems(body['metadata']):
+        for key, value in body['metadata'].items():
             image['properties'][key] = value
         common.check_img_metadata_properties_quota(context,
                                                    image['properties'])
@@ -75,7 +80,8 @@ class ImageMetadataController(wsgi.Controller):
             raise exc.HTTPForbidden(explanation=e.format_message())
         return dict(metadata=image['properties'])
 
-    @extensions.expected_errors((400, 403, 404, 413))
+    @wsgi.Controller.api_version("2.1", MAX_IMAGE_META_PROXY_API_VERSION)
+    @extensions.expected_errors((400, 403, 404))
     @validation.schema(image_metadata.update)
     def update(self, req, image_id, id, body):
         context = req.environ['nova.context']
@@ -97,7 +103,8 @@ class ImageMetadataController(wsgi.Controller):
             raise exc.HTTPForbidden(explanation=e.format_message())
         return dict(meta=meta)
 
-    @extensions.expected_errors((400, 403, 404, 413))
+    @wsgi.Controller.api_version("2.1", MAX_IMAGE_META_PROXY_API_VERSION)
+    @extensions.expected_errors((400, 403, 404))
     @validation.schema(image_metadata.update_all)
     def update_all(self, req, image_id, body):
         context = req.environ['nova.context']
@@ -112,6 +119,7 @@ class ImageMetadataController(wsgi.Controller):
             raise exc.HTTPForbidden(explanation=e.format_message())
         return dict(metadata=metadata)
 
+    @wsgi.Controller.api_version("2.1", MAX_IMAGE_META_PROXY_API_VERSION)
     @extensions.expected_errors((403, 404))
     @wsgi.response(204)
     def delete(self, req, image_id, id):
