@@ -13,7 +13,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import six
+
 import webob
 
 from nova.api.openstack.compute.schemas import quota_classes
@@ -22,6 +22,7 @@ from nova.api.openstack import wsgi
 from nova.api import validation
 from nova import db
 from nova import exception
+from nova.policies import quota_class_sets as qcs_policies
 from nova import quota
 from nova import utils
 
@@ -34,9 +35,6 @@ EXTENDED_QUOTAS = {'server_groups': 'os-server-group-quotas',
                    'server_group_members': 'os-server-group-quotas'}
 
 
-authorize = extensions.os_compute_authorizer(ALIAS)
-
-
 class QuotaClassSetsController(wsgi.Controller):
 
     supported_quotas = []
@@ -65,7 +63,7 @@ class QuotaClassSetsController(wsgi.Controller):
     @extensions.expected_errors(())
     def show(self, req, id):
         context = req.environ['nova.context']
-        authorize(context, action='show', target={'quota_class': id})
+        context.can(qcs_policies.POLICY_ROOT % 'show', {'quota_class': id})
         values = QUOTAS.get_class_quotas(context, id)
         return self._format_quota_set(id, values)
 
@@ -73,7 +71,7 @@ class QuotaClassSetsController(wsgi.Controller):
     @validation.schema(quota_classes.update)
     def update(self, req, id, body):
         context = req.environ['nova.context']
-        authorize(context, action='update', target={'quota_class': id})
+        context.can(qcs_policies.POLICY_ROOT % 'update', {'quota_class': id})
         try:
             utils.check_string_length(id, 'quota_class_name',
                                       min_length=1, max_length=255)
@@ -83,7 +81,7 @@ class QuotaClassSetsController(wsgi.Controller):
 
         quota_class = id
 
-        for key, value in six.iteritems(body['quota_class_set']):
+        for key, value in body['quota_class_set'].items():
             try:
                 db.quota_class_update(context, quota_class, key, value)
             except exception.QuotaClassNotFound:
