@@ -16,7 +16,6 @@
 
 import abc
 import functools
-import os
 
 from oslo_log import log as logging
 from oslo_utils import importutils
@@ -24,13 +23,11 @@ import six
 import webob.dec
 import webob.exc
 
-import nova.api.openstack
 from nova.api.openstack import wsgi
 from nova import exception
 from nova.i18n import _
 from nova.i18n import _LE
 from nova.i18n import _LW
-import nova.policy
 
 LOG = logging.getLogger(__name__)
 
@@ -140,7 +137,7 @@ class ExtensionManager(object):
     """
     def sorted_extensions(self):
         if self.sorted_ext_list is None:
-            self.sorted_ext_list = sorted(six.iteritems(self.extensions))
+            self.sorted_ext_list = sorted(self.extensions.items())
 
         for _alias, ext in self.sorted_ext_list:
             yield ext
@@ -210,13 +207,6 @@ class ExtensionManager(object):
         LOG.debug("Loading extension %s", ext_factory)
 
         if isinstance(ext_factory, six.string_types):
-            if ext_factory.startswith('nova.api.openstack.compute.contrib'):
-                LOG.warn(_LW("The legacy v2 API module already moved into"
-                             "'nova.api.openstack.compute.legacy_v2.contrib'. "
-                             "Use new path instead of old path %s"),
-                         ext_factory)
-                ext_factory = ext_factory.replace('contrib',
-                                                  'legacy_v2.contrib')
             # Load the factory
             factory = importutils.import_class(ext_factory)
         else:
@@ -273,136 +263,6 @@ class ResourceExtension(object):
         self.member_name = member_name
 
 
-def load_standard_extensions(ext_mgr, logger, path, package, ext_list=None):
-    """Registers all standard API extensions."""
-
-    # Walk through all the modules in our directory...
-    our_dir = path[0]
-    for dirpath, dirnames, filenames in os.walk(our_dir):
-        # Compute the relative package name from the dirpath
-        relpath = os.path.relpath(dirpath, our_dir)
-        if relpath == '.':
-            relpkg = ''
-        else:
-            relpkg = '.%s' % '.'.join(relpath.split(os.sep))
-
-        # Now, consider each file in turn, only considering .py files
-        for fname in filenames:
-            root, ext = os.path.splitext(fname)
-
-            # Skip __init__ and anything that's not .py
-            if ext != '.py' or root == '__init__':
-                continue
-
-            # Try loading it
-            classname = "%s%s" % (root[0].upper(), root[1:])
-            classpath = ("%s%s.%s.%s" %
-                         (package, relpkg, root, classname))
-
-            if ext_list is not None and classname not in ext_list:
-                logger.debug("Skipping extension: %s" % classpath)
-                continue
-
-            try:
-                ext_mgr.load_extension(classpath)
-            except Exception as exc:
-                logger.warn(_LW('Failed to load extension %(classpath)s: '
-                                '%(exc)s'),
-                            {'classpath': classpath, 'exc': exc})
-
-        # Now, let's consider any subdirectories we may have...
-        subdirs = []
-        for dname in dirnames:
-            # Skip it if it does not have __init__.py
-            if not os.path.exists(os.path.join(dirpath, dname, '__init__.py')):
-                continue
-
-            # If it has extension(), delegate...
-            ext_name = "%s%s.%s.extension" % (package, relpkg, dname)
-            try:
-                ext = importutils.import_class(ext_name)
-            except ImportError:
-                # extension() doesn't exist on it, so we'll explore
-                # the directory for ourselves
-                subdirs.append(dname)
-            else:
-                try:
-                    ext(ext_mgr)
-                except Exception as exc:
-                    logger.warn(_LW('Failed to load extension %(ext_name)s:'
-                                    '%(exc)s'),
-                                {'ext_name': ext_name, 'exc': exc})
-
-        # Update the list of directories we'll explore...
-        # using os.walk 'the caller can modify the dirnames list in-place,
-        # and walk() will only recurse into the subdirectories whose names
-        # remain in dirnames'
-        # https://docs.python.org/2/library/os.html#os.walk
-        dirnames[:] = subdirs
-
-
-# This will be deprecated after policy cleanup finished
-def core_authorizer(api_name, extension_name):
-    def authorize(context, target=None, action=None):
-        if target is None:
-            target = {'project_id': context.project_id,
-                      'user_id': context.user_id}
-        if action is None:
-            act = '%s:%s' % (api_name, extension_name)
-        else:
-            act = '%s:%s:%s' % (api_name, extension_name, action)
-        nova.policy.enforce(context, act, target)
-    return authorize
-
-
-# This is only used for Nova V2 API, after v2 API depreciated, this will be
-# deprecated also.
-def extension_authorizer(api_name, extension_name):
-    return core_authorizer('%s_extension' % api_name, extension_name)
-
-
-def _soft_authorizer(hard_authorizer, api_name, extension_name):
-    hard_authorize = hard_authorizer(api_name, extension_name)
-
-    def authorize(context, target=None, action=None):
-        try:
-            hard_authorize(context, target=target, action=action)
-            return True
-        except exception.Forbidden:
-            return False
-    return authorize
-
-
-# This is only used for Nova V2 API, after V2 API depreciated, this will be
-# deprecated also.
-def soft_extension_authorizer(api_name, extension_name):
-    return _soft_authorizer(extension_authorizer, api_name, extension_name)
-
-
-# This will be deprecated after policy cleanup finished
-def soft_core_authorizer(api_name, extension_name):
-    return _soft_authorizer(core_authorizer, api_name, extension_name)
-
-
-# This will be deprecated after ec2 old style policy removed in later release
-def check_compute_policy(context, action, target, scope='compute'):
-    _action = '%s:%s' % (scope, action)
-    nova.policy.enforce(context, _action, target)
-
-
-# NOTE(alex_xu): The functions os_compute_authorizer and
-# os_compute_soft_authorizer are used to policy enforcement for OpenStack
-# Compute API, now Nova V2.1 REST API will invoke it.
-#
-
-def os_compute_authorizer(extension_name):
-    return core_authorizer('os_compute_api', extension_name)
-
-
-def os_compute_soft_authorizer(extension_name):
-    return soft_core_authorizer('os_compute_api', extension_name)
-
-
 @six.add_metaclass(abc.ABCMeta)
 class V21APIExtensionBase(object):
     """Abstract base class for all v2.1 API extensions.
@@ -484,9 +344,9 @@ def expected_errors(errors):
                         t_errors = errors
                     if exc.code in t_errors:
                         raise
-                elif isinstance(exc, exception.PolicyNotAuthorized):
+                elif isinstance(exc, exception.Forbidden):
                     # Note(cyeoh): Special case to handle
-                    # PolicyNotAuthorized exceptions so every
+                    # Forbidden exceptions so every
                     # extension method does not need to wrap authorize
                     # calls. ResourceExceptionHandler silently
                     # converts NotAuthorized to HTTPForbidden
@@ -496,6 +356,12 @@ def expected_errors(errors):
                     # happens due to invalid API parameters, as an
                     # expected error.
                     raise
+                elif isinstance(exc, exception.Unauthorized):
+                    # Handle an authorized exception, will be
+                    # automatically converted to a HTTP 401, clients
+                    # like python-novaclient handle this error to
+                    # generate new token and do another attempt.
+                    raise
 
                 LOG.exception(_LE("Unexpected exception in API method"))
                 msg = _('Unexpected API Error. Please report this at '
