@@ -23,6 +23,23 @@ import six
 
 from nova import db
 from nova.i18n import _
+from nova.objects import tag
+
+
+def single_param(schema):
+    """Macro function for use in JSONSchema to support query parameters that
+    should have only one value.
+    """
+    ret = multi_params(schema)
+    ret['maxItems'] = 1
+    return ret
+
+
+def multi_params(schema):
+    """Macro function for use in JSONSchema to support query parameters that
+    may have multiple values.
+    """
+    return {'type': 'array', 'items': schema}
 
 
 class ValidationRegex(object):
@@ -395,3 +412,14 @@ personality = {
         'additionalProperties': False,
     }
 }
+
+tag = {
+    "type": "string",
+    "minLength": 1, "maxLength": tag.MAX_TAG_LENGTH,
+    "pattern": "^[^,/]*$"
+}
+
+pagination_parameters = {
+    'limit': multi_params(non_negative_integer),
+    'marker': multi_params({'type': 'string'})
+}
