@@ -69,6 +69,7 @@ from oslo_utils import importutils
 from oslo_utils import uuidutils
 import prettytable
 
+import six
 import six.moves.urllib.parse as urlparse
 from sqlalchemy.engine import url as sqla_url
 
@@ -100,7 +101,10 @@ CONF = nova.conf.CONF
 
 QUOTAS = quota.QUOTAS
 
-_EXTRA_DEFAULT_LOG_LEVELS = ['oslo_db=INFO', 'oslo_policy=INFO']
+# Keep this list sorted and one entry per line for readability.
+_EXTRA_DEFAULT_LOG_LEVELS = ['oslo_concurrency=INFO',
+                             'oslo_db=INFO',
+                             'oslo_policy=INFO']
 
 
 # Decorators for actions
@@ -639,9 +643,15 @@ class DbCommands(object):
             except exception.CellMappingNotFound:
                 print(_('WARNING: cell0 mapping not found - not'
                         ' syncing cell0.'))
-            except Exception:
-                print(_('ERROR: could not access cell mapping database - has'
-                        ' api db been created?'))
+            except Exception as e:
+                print(_("""ERROR: Could not access cell0.
+Has the nova_api database been created?
+Has the nova_cell0 database been created?
+Has "nova-manage api_db sync" been run?
+Has "nova-manage cell_v2 map_cell0" been run?
+Is [api_database]/connection set in nova.conf?
+Is the cell0 database connection URL correct?
+Error: %s""") % six.text_type(e))
         return migration.db_sync(version)
 
     def version(self):
@@ -1199,10 +1209,11 @@ class CellV2Commands(object):
             marker = instances[-1].uuid
         return marker
 
-    @args('--cell_uuid', metavar='<cell_uuid>', required=True,
-            help='Unmigrated instances will be mapped to the cell with the '
-                 'uuid provided.')
-    @args('--max-count', metavar='<max_count>',
+    @args('--cell_uuid', metavar='<cell_uuid>', dest='cell_uuid',
+          required=True,
+          help='Unmigrated instances will be mapped to the cell with the '
+               'uuid provided.')
+    @args('--max-count', metavar='<max_count>', dest='max_count',
           help='Maximum number of instances to map')
     def map_instances(self, cell_uuid, max_count=None):
         """Map instances into the provided cell.
