@@ -411,8 +411,10 @@ class ComputeTaskManager(base.Base):
                           ' %(dest)s unexpectedly failed.'),
                       {'instance_id': instance.uuid, 'dest': destination},
                       exc_info=True)
+            # Reset the task state to None to indicate completion of
+            # the operation as it is done in case of known exceptions.
             _set_vm_state(context, instance, ex, vm_states.ERROR,
-                          instance.task_state)
+                          task_state=None)
             migration.status = 'error'
             migration.save()
             raise exception.MigrationError(reason=six.text_type(ex))
@@ -703,7 +705,7 @@ class ComputeTaskManager(base.Base):
                     filter_properties = {'ignore_hosts': [instance.host]}
                     request_spec = scheduler_utils.build_request_spec(
                             context, image_ref, [instance])
-                else:
+                elif recreate:
                     # NOTE(sbauza): Augment the RequestSpec object by excluding
                     # the source host for avoiding the scheduler to pick it
                     request_spec.ignore_hosts = request_spec.ignore_hosts or []
@@ -718,6 +720,10 @@ class ComputeTaskManager(base.Base):
                     filter_properties = request_spec.\
                         to_legacy_filter_properties_dict()
                     request_spec = request_spec.to_legacy_request_spec_dict()
+                else:
+                    filter_properties = request_spec. \
+                        to_legacy_filter_properties_dict()
+                    request_spec = request_spec.to_legacy_request_spec_dict()
                 try:
                     hosts = self._schedule_instances(
                             context, request_spec, filter_properties)
@@ -914,16 +920,15 @@ class ComputeTaskManager(base.Base):
                 with obj_target_cell(instance, cell):
                     instance.create()
 
-            # send a state update notification for the initial create to
-            # show it going from non-existent to BUILDING
-            notifications.send_update_with_states(context, instance, None,
-                    vm_states.BUILDING, None, None, service="conductor")
-
-            objects.InstanceAction.action_start(
-                context, instance.uuid, instance_actions.CREATE,
-                want_result=False)
-
             with obj_target_cell(instance, cell):
+                # send a state update notification for the initial create to
+                # show it going from non-existent to BUILDING
+                # This can lazy-load attributes on instance.
+                notifications.send_update_with_states(context, instance, None,
+                        vm_states.BUILDING, None, None, service="conductor")
+                objects.InstanceAction.action_start(
+                    context, instance.uuid, instance_actions.CREATE,
+                    want_result=False)
                 instance_bdms = self._create_block_device_mapping(
                     instance.flavor, instance.uuid, block_device_mapping)
 
