@@ -18,30 +18,24 @@ Websocket proxy that is compatible with OpenStack Nova.
 Leverages websockify.py by Joel Martin
 '''
 
-from six.moves import http_cookies as Cookie
-import six.moves.urllib.parse as urlparse
 import socket
 import sys
 
 from oslo_log import log as logging
+from six.moves import http_cookies as Cookie
+import six.moves.urllib.parse as urlparse
 import websockify
 
+import nova.conf
 from nova.consoleauth import rpcapi as consoleauth_rpcapi
 from nova import context
 from nova import exception
 from nova.i18n import _
-from oslo_config import cfg
+from nova.i18n import _LW
 
 LOG = logging.getLogger(__name__)
 
-CONF = cfg.CONF
-console_origin_opts = [
-    cfg.ListOpt('console_allowed_origins',
-                default=[],
-                help='Allowed Origin header hostnames for access to console '
-                     'proxy servers'),
-]
-CONF.register_opts(console_origin_opts)
+CONF = nova.conf.CONF
 
 
 class NovaProxyRequestHandlerBase(object):
@@ -95,9 +89,17 @@ class NovaProxyRequestHandlerBase(object):
             hcookie = self.headers.getheader('cookie')
             if hcookie:
                 cookie = Cookie.SimpleCookie()
-                cookie.load(hcookie)
-                if 'token' in cookie:
-                    token = cookie['token'].value
+                for hcookie_part in hcookie.split(';'):
+                    hcookie_part = hcookie_part.lstrip()
+                    try:
+                        cookie.load(hcookie_part)
+                    except Cookie.CookieError:
+                        # NOTE(stgleb): Do not print out cookie content
+                        # for security reasons.
+                        LOG.warning(_LW('Found malformed cookie'))
+                    else:
+                        if 'token' in cookie:
+                            token = cookie['token'].value
 
         ctxt = context.get_admin_context()
         rpcapi = consoleauth_rpcapi.ConsoleAuthAPI()
@@ -114,7 +116,7 @@ class NovaProxyRequestHandlerBase(object):
                 expected_origin_hostname = e.split(']')[0][1:]
             else:
                 expected_origin_hostname = e.split(':')[0]
-        expected_origin_hostnames = CONF.console_allowed_origins
+        expected_origin_hostnames = CONF.console.allowed_origins
         expected_origin_hostnames.append(expected_origin_hostname)
         origin_url = self.headers.getheader('Origin')
         # missing origin header indicates non-browser client which is OK
@@ -160,7 +162,8 @@ class NovaProxyRequestHandlerBase(object):
             if tsock:
                 tsock.shutdown(socket.SHUT_RDWR)
                 tsock.close()
-                self.vmsg(_("%(host)s:%(port)s: Target closed") %
+                self.vmsg(_("%(host)s:%(port)s: "
+                          "Websocket client or target closed") %
                           {'host': host, 'port': port})
             raise
 
