@@ -20,7 +20,6 @@ versioned object model os_vif.objects.*
 
 import sys
 
-import os_vif
 from os_vif import objects
 from oslo_config import cfg
 from oslo_log import log as logging
@@ -33,9 +32,6 @@ from nova.network import model
 LOG = logging.getLogger(__name__)
 CONF = cfg.CONF
 
-# Ensure os-vif objects are registered and plugins loaded
-os_vif.initialize()
-
 
 def _get_vif_name(vif):
     """Get a VIF device name
@@ -82,6 +78,26 @@ def _is_firewall_required(vif):
     return False
 
 
+def _set_vhostuser_settings(vif, obj):
+    """Set vhostuser socket mode and path
+
+    :param vif: the nova.network.model.VIF instance
+    :param obj: a os_vif.objects.vif.VIFVHostUser instance
+
+    :raises: exception.VifDetailsMissingVhostuserSockPath
+    """
+
+    obj.mode = vif['details'].get(
+        model.VIF_DETAILS_VHOSTUSER_MODE, 'server')
+    path = vif['details'].get(
+        model.VIF_DETAILS_VHOSTUSER_SOCKET, None)
+    if path:
+        obj.path = path
+    else:
+        raise exception.VifDetailsMissingVhostuserSockPath(
+            vif_id=vif['id'])
+
+
 def nova_to_osvif_instance(instance):
     """Convert a Nova instance object to an os-vif instance object
 
@@ -211,6 +227,8 @@ def _nova_to_osvif_network(network):
     if network['label'] is not None:
         netobj.label = network['label']
 
+    if network.get_meta("mtu") is not None:
+        netobj.mtu = network.get_meta("mtu")
     if network.get_meta("multi_host") is not None:
         netobj.multi_host = network.get_meta("multi_host")
     if network.get_meta("should_create_bridge") is not None:
@@ -281,6 +299,44 @@ def _nova_to_osvif_vif_ovs(vif):
     return obj
 
 
+# VIF_TYPE_VHOST_USER = 'vhostuser'
+def _nova_to_osvif_vif_vhostuser(vif):
+    if vif['details'].get(model.VIF_DETAILS_VHOSTUSER_FP_PLUG, False):
+        if vif['details'].get(model.VIF_DETAILS_VHOSTUSER_OVS_PLUG, False):
+            profile = objects.vif.VIFPortProfileFPOpenVSwitch(
+                    interface_id=vif.get('ovs_interfaceid') or vif['id'])
+            if _is_firewall_required(vif) or vif.is_hybrid_plug_enabled():
+                profile.bridge_name = _get_hybrid_bridge_name(vif)
+                profile.hybrid_plug = True
+            else:
+                profile.hybrid_plug = False
+                if vif["network"]["bridge"] is not None:
+                    profile.bridge_name = vif["network"]["bridge"]
+        else:
+            profile = objects.vif.VIFPortProfileFPBridge()
+            if vif["network"]["bridge"] is not None:
+                profile.bridge_name = vif["network"]["bridge"]
+        obj = _get_vif_instance(vif, objects.vif.VIFVHostUser,
+                        plugin="vhostuser_fp",
+                        vif_name=_get_vif_name(vif),
+                        port_profile=profile)
+        _set_vhostuser_settings(vif, obj)
+        return obj
+    elif vif['details'].get(model.VIF_DETAILS_VHOSTUSER_OVS_PLUG, False):
+        profile = objects.vif.VIFPortProfileOpenVSwitch(
+            interface_id=vif.get('ovs_interfaceid') or vif['id'])
+        vif_name = ('vhu' + vif['id'])[:model.NIC_NAME_LEN]
+        obj = _get_vif_instance(vif, objects.vif.VIFVHostUser,
+                                port_profile=profile, plugin="ovs",
+                                vif_name=vif_name)
+        if vif["network"]["bridge"] is not None:
+            obj.bridge_name = vif["network"]["bridge"]
+        _set_vhostuser_settings(vif, obj)
+        return obj
+    else:
+        raise NotImplementedError()
+
+
 # VIF_TYPE_IVS = 'ivs'
 def _nova_to_osvif_vif_ivs(vif):
     raise NotImplementedError()
@@ -321,11 +377,6 @@ def _nova_to_osvif_vif_midonet(vif):
     raise NotImplementedError()
 
 
-# VIF_TYPE_VHOSTUSER = 'vhostuser'
-def _nova_to_osvif_vif_vhostuser(vif):
-    raise NotImplementedError()
-
-
 # VIF_TYPE_VROUTER = 'vrouter'
 def _nova_to_osvif_vif_vrouter(vif):
     raise NotImplementedError()
