@@ -22,12 +22,14 @@ from oslo_serialization import jsonutils
 import nova.conf
 from nova import exception
 from nova.objects import base as objects_base
+from nova import profiler
 from nova import rpc
 
 
 CONF = nova.conf.CONF
 
 
+@profiler.trace_cls("rpc")
 class NetworkAPI(object):
     '''Client side of the network rpc API.
 
@@ -101,11 +103,15 @@ class NetworkAPI(object):
         * 1.16 - Transfer instance in addition to instance_id in
                  setup_networks_on_host
 
-        ... Liberty supports message version 1.16.  So, any changes to
+        ... Mitaka supports message version 1.16.  So, any changes to
         existing methods in 1.x after that point should be done such that they
         can handle the version_cap being set to 1.16.
 
         * 1.17 - Add method release_dhcp()
+
+        ... Newton supports message version 1.17.  So, any changes to
+        existing methods in 1.x after that point should be done such that they
+        can handle the version_cap being set to 1.17.
     '''
 
     VERSION_ALIASES = {
@@ -116,6 +122,7 @@ class NetworkAPI(object):
         'kilo': '1.13',
         'liberty': '1.15',
         'mitaka': '1.16',
+        'newton': '1.17',
     }
 
     def __init__(self, topic=None):
