@@ -15,7 +15,7 @@
 #    under the License.
 
 from oslo_log import log as logging
-import six
+
 
 from nova.scheduler import filters
 from nova.scheduler.filters import extra_specs_ops
@@ -33,8 +33,6 @@ class AggregateInstanceExtraSpecsFilter(filters.BaseHostFilter):
     # Aggregate data and instance type does not change within a request
     run_filter_once_per_request = True
 
-    RUN_ON_REBUILD = False
-
     def host_passes(self, host_state, spec_obj):
         """Return a list of hosts that can create instance_type
 
@@ -50,7 +48,7 @@ class AggregateInstanceExtraSpecsFilter(filters.BaseHostFilter):
 
         metadata = utils.aggregate_metadata_get_by_host(host_state)
 
-        for key, req in six.iteritems(instance_type.extra_specs):
+        for key, req in instance_type.extra_specs.items():
             # Either not scope format, or aggregate_instance_extra_specs scope
             scope = key.split(':', 1)
             if len(scope) > 1:
