@@ -17,18 +17,17 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from oslo_config import cfg
 from oslo_log import log as logging
 from oslo_utils import timeutils
 
 from nova import cache_utils
+import nova.conf
 from nova.i18n import _, _LI, _LW
 from nova.servicegroup import api
 from nova.servicegroup.drivers import base
 
 
-CONF = cfg.CONF
-CONF.import_opt('service_down_time', 'nova.service')
+CONF = nova.conf.CONF
 
 
 LOG = logging.getLogger(__name__)
@@ -64,7 +63,7 @@ class MemcachedDriver(base.Driver):
         key = "%(topic)s:%(host)s" % service_ref
         is_up = self.mc.get(str(key)) is not None
         if not is_up:
-            LOG.debug('Seems service %s is down' % key)
+            LOG.debug('Seems service %s is down', key)
 
         return is_up
 
@@ -89,5 +88,5 @@ class MemcachedDriver(base.Driver):
         except Exception:
             if not getattr(service, 'model_disconnected', False):
                 service.model_disconnected = True
-                LOG.warn(_LW('Lost connection to memcache server '
+                LOG.warning(_LW('Lost connection to memcache server '
                              'for reporting service status.'))
