@@ -14,17 +14,16 @@
 import mock
 from oslo_db import exception as db_exc
 
+import nova
 from nova import context
 from nova import exception
 from nova import objects
 from nova.objects import fields
+from nova.objects import resource_provider as rp_obj
 from nova import test
 from nova.tests import fixtures
 from nova.tests import uuidsentinel
 
-RESOURCE_CLASS = fields.ResourceClass.DISK_GB
-RESOURCE_CLASS_ID = fields.ResourceClass.index(
-    fields.ResourceClass.DISK_GB)
 DISK_INVENTORY = dict(
     total=200,
     reserved=10,
@@ -32,13 +31,13 @@ DISK_INVENTORY = dict(
     max_unit=5,
     step_size=1,
     allocation_ratio=1.0,
-    resource_class=RESOURCE_CLASS
+    resource_class=fields.ResourceClass.DISK_GB
 )
 
 DISK_ALLOCATION = dict(
     consumer_id=uuidsentinel.disk_consumer,
     used=2,
-    resource_class=RESOURCE_CLASS
+    resource_class=fields.ResourceClass.DISK_GB
 )
 
 
@@ -49,22 +48,23 @@ class ResourceProviderBaseCase(test.NoDBTestCase):
     def setUp(self):
         super(ResourceProviderBaseCase, self).setUp()
         self.useFixture(fixtures.Database())
-        self.useFixture(fixtures.Database(database='api'))
+        self.api_db = self.useFixture(fixtures.Database(database='api'))
         self.context = context.RequestContext('fake-user', 'fake-project')
 
     def _make_allocation(self, rp_uuid=None):
         rp_uuid = rp_uuid or uuidsentinel.allocation_resource_provider
-        db_rp = objects.ResourceProvider(
+        rp = objects.ResourceProvider(
             context=self.context,
             uuid=rp_uuid,
             name=rp_uuid)
-        db_rp.create()
-        updates = dict(DISK_ALLOCATION,
-                       resource_class_id=RESOURCE_CLASS_ID,
-                       resource_provider_id=db_rp.id)
-        db_allocation = objects.Allocation._create_in_db(self.context,
-                                                         updates)
-        return db_rp, db_allocation
+        rp.create()
+        alloc = objects.Allocation(
+            self.context,
+            resource_provider=rp,
+            **DISK_ALLOCATION
+        )
+        alloc.create()
+        return rp, alloc
 
 
 class ResourceProviderTestCase(ResourceProviderBaseCase):
@@ -206,6 +206,87 @@ class ResourceProviderTestCase(ResourceProviderBaseCase):
             self.context, resource_provider.uuid))
         self.assertEqual(33, reloaded_inventories[0].total)
 
+    def test_set_inventory_unknown_resource_class(self):
+        """Test attempting to set inventory to an unknown resource class raises
+        an exception.
+        """
+        rp = objects.ResourceProvider(
+            context=self.context,
+            uuid=uuidsentinel.rp_uuid,
+            name='compute-host',
+        )
+        rp.create()
+
+        inv = objects.Inventory(
+            resource_provider=rp,
+            resource_class='UNKNOWN',
+            total=1024,
+            reserved=15,
+            min_unit=10,
+            max_unit=100,
+            step_size=10,
+            allocation_ratio=1.0,
+        )
+
+        inv_list = objects.InventoryList(objects=[inv])
+        self.assertRaises(exception.ResourceClassNotFound,
+                          rp.set_inventory, inv_list)
+
+    def test_set_inventory_fail_in_used(self):
+        """Test attempting to set inventory which would result in removing an
+        inventory record for a resource class that still has allocations
+        against it.
+        """
+        rp = objects.ResourceProvider(
+            context=self.context,
+            uuid=uuidsentinel.rp_uuid,
+            name='compute-host',
+        )
+        rp.create()
+
+        inv = objects.Inventory(
+            resource_provider=rp,
+            resource_class='VCPU',
+            total=12,
+            reserved=0,
+            min_unit=1,
+            max_unit=12,
+            step_size=1,
+            allocation_ratio=1.0,
+        )
+
+        inv_list = objects.InventoryList(objects=[inv])
+        rp.set_inventory(inv_list)
+
+        alloc = objects.Allocation(
+            resource_provider=rp,
+            resource_class='VCPU',
+            consumer_id=uuidsentinel.consumer,
+            used=1,
+        )
+
+        alloc_list = objects.AllocationList(
+            self.context,
+            objects=[alloc]
+        )
+        alloc_list.create_all()
+
+        inv = objects.Inventory(
+            resource_provider=rp,
+            resource_class='MEMORY_MB',
+            total=1024,
+            reserved=0,
+            min_unit=256,
+            max_unit=1024,
+            step_size=256,
+            allocation_ratio=1.0,
+        )
+
+        inv_list = objects.InventoryList(objects=[inv])
+        self.assertRaises(exception.InventoryInUse,
+                          rp.set_inventory,
+                          inv_list)
+
     @mock.patch('nova.objects.resource_provider.LOG')
     def test_set_inventory_over_capacity(self, mock_log):
         rp = objects.ResourceProvider(context=self.context,
@@ -425,7 +506,7 @@ class ResourceProviderTestCase(ResourceProviderBaseCase):
         disk_inv.obj_set_defaults()
         error = self.assertRaises(exception.NotFound, rp.update_inventory,
                                   disk_inv)
-        self.assertIn('No inventory of class DISK_GB found for update',
+        self.assertIn('No inventory of class DISK_GB found',
                       str(error))
 
     @mock.patch('nova.objects.resource_provider.LOG')
@@ -477,6 +558,20 @@ class ResourceProviderTestCase(ResourceProviderBaseCase):
         self.assertIn("on resource provider '%s'."
                       % rp.uuid, str(error))
 
+    def test_add_allocation_increments_generation(self):
+        rp = objects.ResourceProvider(context=self.context,
+                uuid=uuidsentinel.inventory_resource_provider, name='foo')
+        rp.create()
+        inv = objects.Inventory(context=self.context, resource_provider=rp,
+                **DISK_INVENTORY)
+        inv.create()
+        expected_gen = rp.generation + 1
+        alloc = objects.Allocation(context=self.context, resource_provider=rp,
+                **DISK_ALLOCATION)
+        alloc_list = objects.AllocationList(self.context, objects=[alloc])
+        alloc_list.create_all()
+        self.assertEqual(expected_gen, rp.generation)
+
 
 class ResourceProviderListTestCase(ResourceProviderBaseCase):
     def setUp(self):
@@ -496,7 +591,7 @@ class ResourceProviderListTestCase(ResourceProviderBaseCase):
             self.context)
         self.assertEqual(2, len(resource_providers))
         resource_providers = objects.ResourceProviderList.get_all_by_filters(
-            self.context, filters={'name': 'rp_name_1'})
+            self.context, filters={'name': u'rp_name_1'})
         self.assertEqual(1, len(resource_providers))
         resource_providers = objects.ResourceProviderList.get_all_by_filters(
             self.context, filters={'can_host': 1})
@@ -506,6 +601,224 @@ class ResourceProviderListTestCase(ResourceProviderBaseCase):
         self.assertEqual(1, len(resource_providers))
         self.assertEqual('rp_name_2', resource_providers[0].name)
 
+    def test_get_all_by_filters_with_resources(self):
+        for rp_i in ['1', '2']:
+            uuid = getattr(uuidsentinel, 'rp_uuid_' + rp_i)
+            name = 'rp_name_' + rp_i
+            rp = objects.ResourceProvider(self.context, name=name, uuid=uuid)
+            rp.create()
+            inv = objects.Inventory(
+                resource_provider=rp,
+                resource_class=fields.ResourceClass.VCPU,
+                min_unit=1,
+                max_unit=2,
+                total=2,
+                allocation_ratio=1.0)
+            inv.obj_set_defaults()
+
+            inv2 = objects.Inventory(
+                resource_provider=rp,
+                resource_class=fields.ResourceClass.DISK_GB,
+                total=1024, reserved=2,
+                min_unit=1,
+                max_unit=1024,
+                allocation_ratio=1.0)
+            inv2.obj_set_defaults()
+
+            # Write that specific inventory for testing min/max units and steps
+            inv3 = objects.Inventory(
+                resource_provider=rp,
+                resource_class=fields.ResourceClass.MEMORY_MB,
+                total=1024, reserved=2,
+                min_unit=2,
+                max_unit=4,
+                step_size=2,
+                allocation_ratio=1.0)
+            inv3.obj_set_defaults()
+
+            inv_list = objects.InventoryList(objects=[inv, inv2, inv3])
+            rp.set_inventory(inv_list)
+
+            # Create the VCPU allocation only for the first RP
+            if rp_i != '1':
+                continue
+            allocation_1 = objects.Allocation(
+                resource_provider=rp,
+                consumer_id=uuidsentinel.consumer,
+                resource_class=fields.ResourceClass.VCPU,
+                used=1)
+            allocation_list = objects.AllocationList(
+                self.context, objects=[allocation_1])
+            allocation_list.create_all()
+
+        # Both RPs should accept that request given the only current allocation
+        # for the first RP is leaving one VCPU
+        resource_providers = objects.ResourceProviderList.get_all_by_filters(
+            self.context, {'resources': {fields.ResourceClass.VCPU: 1}})
+        self.assertEqual(2, len(resource_providers))
+        # Now, when asking for 2 VCPUs, only the second RP should accept that
+        # given the current allocation for the first RP
+        resource_providers = objects.ResourceProviderList.get_all_by_filters(
+            self.context, {'resources': {fields.ResourceClass.VCPU: 2}})
+        self.assertEqual(1, len(resource_providers))
+        # Adding a second resource request should be okay for the 2nd RP
+        # given it has enough disk but we also need to make sure that the
+        # first RP is not acceptable because of the VCPU request
+        resource_providers = objects.ResourceProviderList.get_all_by_filters(
+            self.context, {'resources': {fields.ResourceClass.VCPU: 2,
+                                         fields.ResourceClass.DISK_GB: 1022}})
+        self.assertEqual(1, len(resource_providers))
+        # Now, we are asking for both disk and VCPU resources that all the RPs
+        # can't accept (as the 2nd RP is having a reserved size)
+        resource_providers = objects.ResourceProviderList.get_all_by_filters(
+            self.context, {'resources': {fields.ResourceClass.VCPU: 2,
+                                         fields.ResourceClass.DISK_GB: 1024}})
+        self.assertEqual(0, len(resource_providers))
+
+        # We also want to verify that asking for a specific RP can also be
+        # checking the resource usage.
+        resource_providers = objects.ResourceProviderList.get_all_by_filters(
+            self.context, {'name': u'rp_name_1',
+                           'resources': {fields.ResourceClass.VCPU: 1}})
+        self.assertEqual(1, len(resource_providers))
+
+        # Let's verify that the min and max units are checked too
+        # Case 1: amount is in between min and max and modulo step_size
+        resource_providers = objects.ResourceProviderList.get_all_by_filters(
+            self.context, {'resources': {fields.ResourceClass.MEMORY_MB: 2}})
+        self.assertEqual(2, len(resource_providers))
+        # Case 2: amount is less than min_unit
+        resource_providers = objects.ResourceProviderList.get_all_by_filters(
+            self.context, {'resources': {fields.ResourceClass.MEMORY_MB: 1}})
+        self.assertEqual(0, len(resource_providers))
+        # Case 3: amount is more than min_unit
+        resource_providers = objects.ResourceProviderList.get_all_by_filters(
+            self.context, {'resources': {fields.ResourceClass.MEMORY_MB: 5}})
+        self.assertEqual(0, len(resource_providers))
+        # Case 4: amount is not modulo step_size
+        resource_providers = objects.ResourceProviderList.get_all_by_filters(
+            self.context, {'resources': {fields.ResourceClass.MEMORY_MB: 3}})
+        self.assertEqual(0, len(resource_providers))
+
+    def test_get_all_by_filters_with_resources_not_existing(self):
+        self.assertRaises(
+            exception.ResourceClassNotFound,
+            objects.ResourceProviderList.get_all_by_filters,
+            self.context, {'resources': {'FOOBAR': 3}})
+
+    def test_get_all_by_filters_aggregate(self):
+        for rp_i in [1, 2, 3, 4]:
+            uuid = getattr(uuidsentinel, 'rp_uuid_' + str(rp_i))
+            name = 'rp_name_' + str(rp_i)
+            rp = objects.ResourceProvider(self.context, name=name, uuid=uuid)
+            rp.create()
+            if rp_i % 2:
+                aggregate_uuids = [uuidsentinel.agg_a, uuidsentinel.agg_b]
+                rp.set_aggregates(aggregate_uuids)
+
+        resource_providers = objects.ResourceProviderList.get_all_by_filters(
+            self.context, filters={'member_of': [uuidsentinel.agg_a]})
+
+        self.assertEqual(2, len(resource_providers))
+        names = [_rp.name for _rp in resource_providers]
+        self.assertIn('rp_name_1', names)
+        self.assertIn('rp_name_3', names)
+        self.assertNotIn('rp_name_2', names)
+        self.assertNotIn('rp_name_4', names)
+
+        resource_providers = objects.ResourceProviderList.get_all_by_filters(
+            self.context, filters={'member_of':
+                                   [uuidsentinel.agg_a, uuidsentinel.agg_b]})
+        self.assertEqual(2, len(resource_providers))
+
+        resource_providers = objects.ResourceProviderList.get_all_by_filters(
+            self.context, filters={'member_of':
+                                   [uuidsentinel.agg_a, uuidsentinel.agg_b],
+                                   'name': u'rp_name_1'})
+        self.assertEqual(1, len(resource_providers))
+
+        resource_providers = objects.ResourceProviderList.get_all_by_filters(
+            self.context, filters={'member_of':
+                                   [uuidsentinel.agg_a, uuidsentinel.agg_b],
+                                   'name': u'barnabas'})
+        self.assertEqual(0, len(resource_providers))
+
+        resource_providers = objects.ResourceProviderList.get_all_by_filters(
+            self.context, filters={'member_of':
+                                   [uuidsentinel.agg_1, uuidsentinel.agg_2]})
+        self.assertEqual(0, len(resource_providers))
+
+
+class TestResourceProviderAggregates(test.NoDBTestCase):
+
+    USES_DB_SELF = True
+
+    def setUp(self):
+        super(TestResourceProviderAggregates, self).setUp()
+        self.useFixture(fixtures.Database(database='main'))
+        self.useFixture(fixtures.Database(database='api'))
+        self.context = context.RequestContext('fake-user', 'fake-project')
+
+    def test_set_and_get_new_aggregates(self):
+        rp = objects.ResourceProvider(
+            context=self.context,
+            uuid=uuidsentinel.rp_uuid,
+            name=uuidsentinel.rp_name
+        )
+        rp.create()
+
+        aggregate_uuids = [uuidsentinel.agg_a, uuidsentinel.agg_b]
+        rp.set_aggregates(aggregate_uuids)
+
+        read_aggregate_uuids = rp.get_aggregates()
+        self.assertItemsEqual(aggregate_uuids, read_aggregate_uuids)
+
+        # Since get_aggregates always does a new query this is
+        # mostly nonsense but is here for completeness.
+        read_rp = objects.ResourceProvider.get_by_uuid(
+            self.context, uuidsentinel.rp_uuid)
+        re_read_aggregate_uuids = read_rp.get_aggregates()
+        self.assertItemsEqual(aggregate_uuids, re_read_aggregate_uuids)
+
+    def test_set_aggregates_is_replace(self):
+        rp = objects.ResourceProvider(
+            context=self.context,
+            uuid=uuidsentinel.rp_uuid,
+            name=uuidsentinel.rp_name
+        )
+        rp.create()
+
+        start_aggregate_uuids = [uuidsentinel.agg_a, uuidsentinel.agg_b]
+        rp.set_aggregates(start_aggregate_uuids)
+        read_aggregate_uuids = rp.get_aggregates()
+        self.assertItemsEqual(start_aggregate_uuids, read_aggregate_uuids)
+
+        rp.set_aggregates([uuidsentinel.agg_a])
+        read_aggregate_uuids = rp.get_aggregates()
+        self.assertNotIn(uuidsentinel.agg_b, read_aggregate_uuids)
+        self.assertIn(uuidsentinel.agg_a, read_aggregate_uuids)
+
+        # Empty list means delete.
+        rp.set_aggregates([])
+        read_aggregate_uuids = rp.get_aggregates()
+        self.assertEqual([], read_aggregate_uuids)
+
+    def test_delete_rp_clears_aggs(self):
+        rp = objects.ResourceProvider(
+            context=self.context,
+            uuid=uuidsentinel.rp_uuid,
+            name=uuidsentinel.rp_name
+        )
+        rp.create()
+        rp_id = rp.id
+        start_aggregate_uuids = [uuidsentinel.agg_a, uuidsentinel.agg_b]
+        rp.set_aggregates(start_aggregate_uuids)
+        aggs = objects.ResourceProvider._get_aggregates(self.context, rp_id)
+        self.assertEqual(2, len(aggs))
+        rp.destroy()
+        aggs = objects.ResourceProvider._get_aggregates(self.context, rp_id)
+        self.assertEqual(0, len(aggs))
+
 
 class TestAllocation(ResourceProviderBaseCase):
 
@@ -548,6 +861,140 @@ class TestAllocation(ResourceProviderBaseCase):
 
         self.assertEqual(0, len(allocations))
 
+    def test_multi_provider_allocation(self):
+        """Tests that an allocation that includes more than one resource
+        provider can be created, listed and deleted properly.
+
+        Bug #1707669 highlighted a situation that arose when attempting to
+        remove part of an allocation for a source host during a resize
+        operation where the exiting allocation was not being properly
+        deleted.
+        """
+        cn_source = objects.ResourceProvider(
+            context=self.context,
+            uuid=uuidsentinel.cn_source,
+            name=uuidsentinel.cn_source,
+        )
+        cn_source.create()
+
+        cn_dest = objects.ResourceProvider(
+            context=self.context,
+            uuid=uuidsentinel.cn_dest,
+            name=uuidsentinel.cn_dest,
+        )
+        cn_dest.create()
+
+        # Add same inventory to both source and destination host
+        for cn in (cn_source, cn_dest):
+            cpu_inv = objects.Inventory(
+                context=self.context,
+                resource_provider=cn,
+                resource_class=fields.ResourceClass.VCPU,
+                total=24,
+                reserved=0,
+                min_unit=1,
+                max_unit=24,
+                step_size=1,
+                allocation_ratio=16.0)
+            ram_inv = objects.Inventory(
+                context=self.context,
+                resource_provider=cn,
+                resource_class=fields.ResourceClass.MEMORY_MB,
+                total=1024,
+                reserved=0,
+                min_unit=64,
+                max_unit=1024,
+                step_size=64,
+                allocation_ratio=1.5)
+            inv_list = objects.InventoryList(context=self.context,
+                objects=[cpu_inv, ram_inv])
+            cn.set_inventory(inv_list)
+
+        # Now create an allocation that represents a move operation where the
+        # scheduler has selected cn_dest as the target host and created a
+        # "doubled-up" allocation for the duration of the move operation
+        alloc_list = objects.AllocationList(context=self.context,
+            objects=[
+                objects.Allocation(
+                    context=self.context,
+                    consumer_id=uuidsentinel.instance,
+                    resource_provider=cn_source,
+                    resource_class=fields.ResourceClass.VCPU,
+                    used=1),
+                objects.Allocation(
+                    context=self.context,
+                    consumer_id=uuidsentinel.instance,
+                    resource_provider=cn_source,
+                    resource_class=fields.ResourceClass.MEMORY_MB,
+                    used=256),
+                objects.Allocation(
+                    context=self.context,
+                    consumer_id=uuidsentinel.instance,
+                    resource_provider=cn_dest,
+                    resource_class=fields.ResourceClass.VCPU,
+                    used=1),
+                objects.Allocation(
+                    context=self.context,
+                    consumer_id=uuidsentinel.instance,
+                    resource_provider=cn_dest,
+                    resource_class=fields.ResourceClass.MEMORY_MB,
+                    used=256),
+            ])
+        alloc_list.create_all()
+
+        src_allocs = objects.AllocationList.get_all_by_resource_provider_uuid(
+            self.context, cn_source.uuid)
+
+        self.assertEqual(2, len(src_allocs))
+
+        dest_allocs = objects.AllocationList.get_all_by_resource_provider_uuid(
+            self.context, cn_dest.uuid)
+
+        self.assertEqual(2, len(dest_allocs))
+
+        consumer_allocs = objects.AllocationList.get_all_by_consumer_id(
+            self.context, uuidsentinel.instance)
+
+        self.assertEqual(4, len(consumer_allocs))
+
+        # Validate that when we create an allocation for a consumer that we
+        # delete any existing allocation and replace it with what the new.
+        # Here, we're emulating the step that occurs on confirm_resize() where
+        # the source host pulls the existing allocation for the instance and
+        # removes any resources that refer to itself and saves the allocation
+        # back to placement
+        new_alloc_list = objects.AllocationList(context=self.context,
+            objects=[
+                objects.Allocation(
+                    context=self.context,
+                    consumer_id=uuidsentinel.instance,
+                    resource_provider=cn_dest,
+                    resource_class=fields.ResourceClass.VCPU,
+                    used=1),
+                objects.Allocation(
+                    context=self.context,
+                    consumer_id=uuidsentinel.instance,
+                    resource_provider=cn_dest,
+                    resource_class=fields.ResourceClass.MEMORY_MB,
+                    used=256),
+            ])
+        new_alloc_list.create_all()
+
+        src_allocs = objects.AllocationList.get_all_by_resource_provider_uuid(
+            self.context, cn_source.uuid)
+
+        self.assertEqual(0, len(src_allocs))
+
+        dest_allocs = objects.AllocationList.get_all_by_resource_provider_uuid(
+            self.context, cn_dest.uuid)
+
+        self.assertEqual(2, len(dest_allocs))
+
+        consumer_allocs = objects.AllocationList.get_all_by_consumer_id(
+            self.context, uuidsentinel.instance)
+
+        self.assertEqual(2, len(consumer_allocs))
+
     def test_destroy(self):
         rp, allocation = self._make_allocation()
         allocations = objects.AllocationList.get_all_by_resource_provider_uuid(
@@ -566,7 +1013,7 @@ class TestAllocation(ResourceProviderBaseCase):
             self.context, rp.uuid)
         self.assertEqual(1, len(allocations))
         self.assertEqual(rp.id, allocations[0].resource_provider_id)
-        self.assertEqual(allocation.resource_provider_id,
+        self.assertEqual(allocation.resource_provider.id,
                          allocations[0].resource_provider_id)
 
         allocations = objects.AllocationList._get_allocations_from_db(
@@ -579,56 +1026,9 @@ class TestAllocation(ResourceProviderBaseCase):
             self.context, rp.uuid)
         self.assertEqual(1, len(allocations))
         self.assertEqual(rp.id, allocations[0].resource_provider.id)
-        self.assertEqual(allocation.resource_provider_id,
+        self.assertEqual(allocation.resource_provider.id,
                          allocations[0].resource_provider.id)
 
-    def test_get_all_multiple_providers(self):
-        # This confirms that the join with resource provider is
-        # behaving.
-        rp1, allocation1 = self._make_allocation(uuidsentinel.rp1)
-        rp2, allocation2 = self._make_allocation(uuidsentinel.rp2)
-        allocations = objects.AllocationList.get_all_by_resource_provider_uuid(
-            self.context, rp1.uuid)
-        self.assertEqual(1, len(allocations))
-        self.assertEqual(rp1.id, allocations[0].resource_provider.id)
-        self.assertEqual(allocation1.resource_provider_id,
-                         allocations[0].resource_provider.id)
-
-        # add more allocations for the first resource provider
-        # of the same class
-        updates = dict(consumer_id=uuidsentinel.consumer1,
-                       resource_class_id=RESOURCE_CLASS_ID,
-                       resource_provider_id=rp1.id,
-                       used=2)
-        objects.Allocation._create_in_db(self.context, updates)
-        allocations = objects.AllocationList.get_all_by_resource_provider_uuid(
-            self.context, rp1.uuid)
-        self.assertEqual(2, len(allocations))
-
-        # add more allocations for the first resource provider
-        # of a different class
-        updates = dict(consumer_id=uuidsentinel.consumer1,
-                       resource_class_id=fields.ResourceClass.index(
-                           fields.ResourceClass.IPV4_ADDRESS),
-                       resource_provider_id=rp1.id,
-                       used=4)
-        objects.Allocation._create_in_db(self.context, updates)
-        allocations = objects.AllocationList.get_all_by_resource_provider_uuid(
-            self.context, rp1.uuid)
-        self.assertEqual(3, len(allocations))
-        self.assertEqual(rp1.uuid, allocations[0].resource_provider.uuid)
-
-        allocations = objects.AllocationList.get_all_by_resource_provider_uuid(
-            self.context, rp2.uuid)
-        self.assertEqual(1, len(allocations))
-        self.assertEqual(rp2.uuid, allocations[0].resource_provider.uuid)
-        self.assertIn(RESOURCE_CLASS,
-                      [allocation.resource_class
-                       for allocation in allocations])
-        self.assertNotIn(fields.ResourceClass.IPV4_ADDRESS,
-                      [allocation.resource_class
-                       for allocation in allocations])
-
 
 class TestAllocationListCreateDelete(ResourceProviderBaseCase):
 
@@ -734,8 +1134,14 @@ class TestAllocationListCreateDelete(ResourceProviderBaseCase):
             self.context, objects=[allocation_1, allocation_2])
 
         # There's no inventory, we have a failure.
-        self.assertRaises(exception.InvalidInventory,
-                          allocation_list.create_all)
+        error = self.assertRaises(exception.InvalidInventory,
+                                  allocation_list.create_all)
+        # Confirm that the resource class string, not index, is in
+        # the exception and resource providers are listed by uuid.
+        self.assertIn(rp1_class, str(error))
+        self.assertIn(rp2_class, str(error))
+        self.assertIn(rp1.uuid, str(error))
+        self.assertIn(rp2.uuid, str(error))
 
         # Add inventory for one of the two resource providers. This should also
         # fail, since rp2 has no inventory.
@@ -949,3 +1355,256 @@ class UsageListTestCase(ResourceProviderBaseCase):
         usage_list = objects.UsageList.get_all_by_resource_provider_uuid(
             self.context, db_rp.uuid)
         self.assertEqual(2, len(usage_list))
+
+
+class ResourceClassListTestCase(ResourceProviderBaseCase):
+
+    def test_get_all_no_custom(self):
+        """Test that if we haven't yet added any custom resource classes, that
+        we only get a list of ResourceClass objects representing the standard
+        classes.
+        """
+        rcs = objects.ResourceClassList.get_all(self.context)
+        self.assertEqual(len(fields.ResourceClass.STANDARD), len(rcs))
+
+    def test_get_all_with_custom(self):
+        """Test that if we add some custom resource classes, that we get a list
+        of ResourceClass objects representing the standard classes as well as
+        the custom classes.
+        """
+        customs = [
+            ('CUSTOM_IRON_NFV', 10001),
+            ('CUSTOM_IRON_ENTERPRISE', 10002),
+        ]
+        with self.api_db.get_engine().connect() as conn:
+            for custom in customs:
+                c_name, c_id = custom
+                ins = rp_obj._RC_TBL.insert().values(id=c_id, name=c_name)
+                conn.execute(ins)
+
+        rcs = objects.ResourceClassList.get_all(self.context)
+        expected_count = len(fields.ResourceClass.STANDARD) + len(customs)
+        self.assertEqual(expected_count, len(rcs))
+
+
+class ResourceClassTestCase(ResourceProviderBaseCase):
+
+    def test_get_by_name(self):
+        rc = objects.ResourceClass.get_by_name(
+            self.context,
+            fields.ResourceClass.VCPU
+        )
+        vcpu_id = fields.ResourceClass.STANDARD.index(
+            fields.ResourceClass.VCPU
+        )
+        self.assertEqual(vcpu_id, rc.id)
+        self.assertEqual(fields.ResourceClass.VCPU, rc.name)
+
+    def test_get_by_name_not_found(self):
+        self.assertRaises(exception.ResourceClassNotFound,
+                          objects.ResourceClass.get_by_name,
+                          self.context,
+                          'CUSTOM_NO_EXISTS')
+
+    def test_get_by_name_custom(self):
+        rc = objects.ResourceClass(
+            self.context,
+            name='CUSTOM_IRON_NFV',
+        )
+        rc.create()
+        get_rc = objects.ResourceClass.get_by_name(
+            self.context,
+            'CUSTOM_IRON_NFV',
+        )
+        self.assertEqual(rc.id, get_rc.id)
+        self.assertEqual(rc.name, get_rc.name)
+
+    def test_create_fail_not_using_namespace(self):
+        rc = objects.ResourceClass(
+            context=self.context,
+            name='IRON_NFV',
+        )
+        exc = self.assertRaises(exception.ObjectActionError, rc.create)
+        self.assertIn('name must start with', str(exc))
+
+    def test_create_duplicate_standard(self):
+        rc = objects.ResourceClass(
+            context=self.context,
+            name=fields.ResourceClass.VCPU,
+        )
+        self.assertRaises(exception.ResourceClassExists, rc.create)
+
+    def test_create(self):
+        rc = objects.ResourceClass(
+            self.context,
+            name='CUSTOM_IRON_NFV',
+        )
+        rc.create()
+        min_id = objects.ResourceClass.MIN_CUSTOM_RESOURCE_CLASS_ID
+        self.assertEqual(min_id, rc.id)
+
+        rc = objects.ResourceClass(
+            self.context,
+            name='CUSTOM_IRON_ENTERPRISE',
+        )
+        rc.create()
+        self.assertEqual(min_id + 1, rc.id)
+
+    @mock.patch.object(nova.objects.ResourceClass, "_get_next_id")
+    def test_create_duplicate_id_retry(self, mock_get):
+        # This order of ID generation will create rc1 with an ID of 42, try to
+        # create rc2 with the same ID, and then return 43 in the retry loop.
+        mock_get.side_effect = (42, 42, 43)
+        rc1 = objects.ResourceClass(
+            self.context,
+            name='CUSTOM_IRON_NFV',
+        )
+        rc1.create()
+        rc2 = objects.ResourceClass(
+            self.context,
+            name='CUSTOM_TWO',
+        )
+        rc2.create()
+        self.assertEqual(rc1.id, 42)
+        self.assertEqual(rc2.id, 43)
+
+    @mock.patch.object(nova.objects.ResourceClass, "_get_next_id")
+    def test_create_duplicate_id_retry_failing(self, mock_get):
+        """negative case for test_create_duplicate_id_retry"""
+        # This order of ID generation will create rc1 with an ID of 44, try to
+        # create rc2 with the same ID, and then return 45 in the retry loop.
+        mock_get.side_effect = (44, 44, 44, 44)
+        rc1 = objects.ResourceClass(
+            self.context,
+            name='CUSTOM_IRON_NFV',
+        )
+        rc1.create()
+        rc2 = objects.ResourceClass(
+            self.context,
+            name='CUSTOM_TWO',
+        )
+        rc2.RESOURCE_CREATE_RETRY_COUNT = 3
+        self.assertRaises(exception.ResourceClassExists, rc2.create)
+
+    def test_create_duplicate_custom(self):
+        rc = objects.ResourceClass(
+            self.context,
+            name='CUSTOM_IRON_NFV',
+        )
+        rc.create()
+        self.assertEqual(objects.ResourceClass.MIN_CUSTOM_RESOURCE_CLASS_ID,
+                         rc.id)
+        rc = objects.ResourceClass(
+            self.context,
+            name='CUSTOM_IRON_NFV',
+        )
+        self.assertRaises(exception.ResourceClassExists, rc.create)
+
+    def test_destroy_fail_no_id(self):
+        rc = objects.ResourceClass(
+            self.context,
+            name='CUSTOM_IRON_NFV',
+        )
+        self.assertRaises(exception.ObjectActionError, rc.destroy)
+
+    def test_destroy_fail_standard(self):
+        rc = objects.ResourceClass.get_by_name(
+            self.context,
+            'VCPU',
+        )
+        self.assertRaises(exception.ResourceClassCannotDeleteStandard,
+                          rc.destroy)
+
+    def test_destroy(self):
+        rc = objects.ResourceClass(
+            self.context,
+            name='CUSTOM_IRON_NFV',
+        )
+        rc.create()
+        rc_list = objects.ResourceClassList.get_all(self.context)
+        rc_ids = (r.id for r in rc_list)
+        self.assertIn(rc.id, rc_ids)
+
+        rc = objects.ResourceClass.get_by_name(
+            self.context,
+            'CUSTOM_IRON_NFV',
+        )
+
+        rc.destroy()
+        rc_list = objects.ResourceClassList.get_all(self.context)
+        rc_ids = (r.id for r in rc_list)
+        self.assertNotIn(rc.id, rc_ids)
+
+        # Verify rc cache was purged of the old entry
+        self.assertRaises(exception.ResourceClassNotFound,
+                          objects.ResourceClass.get_by_name,
+                          self.context,
+                          'CUSTOM_IRON_NFV')
+
+    def test_destroy_fail_with_inventory(self):
+        """Test that we raise an exception when attempting to delete a resource
+        class that is referenced in an inventory record.
+        """
+        rc = objects.ResourceClass(
+            self.context,
+            name='CUSTOM_IRON_NFV',
+        )
+        rc.create()
+        rp = objects.ResourceProvider(
+            self.context,
+            name='my rp',
+            uuid=uuidsentinel.rp,
+        )
+        rp.create()
+        inv = objects.Inventory(
+            resource_provider=rp,
+            resource_class='CUSTOM_IRON_NFV',
+            total=1,
+        )
+        inv.obj_set_defaults()
+        inv_list = objects.InventoryList(objects=[inv])
+        rp.set_inventory(inv_list)
+
+        self.assertRaises(exception.ResourceClassInUse,
+                          rc.destroy)
+
+        rp.set_inventory(objects.InventoryList(objects=[]))
+        rc.destroy()
+        rc_list = objects.ResourceClassList.get_all(self.context)
+        rc_ids = (r.id for r in rc_list)
+        self.assertNotIn(rc.id, rc_ids)
+
+    def test_save_fail_no_id(self):
+        rc = objects.ResourceClass(
+            self.context,
+            name='CUSTOM_IRON_NFV',
+        )
+        self.assertRaises(exception.ObjectActionError, rc.save)
+
+    def test_save_fail_standard(self):
+        rc = objects.ResourceClass.get_by_name(
+            self.context,
+            'VCPU',
+        )
+        self.assertRaises(exception.ResourceClassCannotUpdateStandard,
+                          rc.save)
+
+    def test_save(self):
+        rc = objects.ResourceClass(
+            self.context,
+            name='CUSTOM_IRON_NFV',
+        )
+        rc.create()
+
+        rc = objects.ResourceClass.get_by_name(
+            self.context,
+            'CUSTOM_IRON_NFV',
+        )
+        rc.name = 'CUSTOM_IRON_SILVER'
+        rc.save()
+
+        # Verify rc cache was purged of the old entry
+        self.assertRaises(exception.NotFound,
+                          objects.ResourceClass.get_by_name,
+                          self.context,
+                          'CUSTOM_IRON_NFV')
