@@ -16,12 +16,10 @@
 """Tests for the aggregates admin api."""
 
 import mock
-import uuid
 from webob import exc
 
+from nova.api.openstack import api_version_request
 from nova.api.openstack.compute import aggregates as aggregates_v21
-from nova.api.openstack.compute.legacy_v2.contrib import aggregates \
-        as aggregates_v2
 from nova.compute import api as compute_api
 from nova import context
 from nova import exception
@@ -156,6 +154,17 @@ class AggregateTestCaseV21(test.NoDBTestCase):
                                      {"name": "test",
                                       "availability_zone": "nova1"}})
 
+    @mock.patch.object(compute_api.AggregateAPI, 'create_aggregate')
+    def test_create_with_unmigrated_aggregates(self, mock_create_aggregate):
+        mock_create_aggregate.side_effect = \
+                exception.ObjectActionError(action='create',
+                    reason='main database still contains aggregates')
+
+        self.assertRaises(exc.HTTPConflict, self.controller.create,
+                          self.req, body={"aggregate":
+                                     {"name": "test",
+                                      "availability_zone": "nova1"}})
+
     def test_create_with_incorrect_availability_zone(self):
         def stub_create_aggregate(context, name, availability_zone):
             raise exception.InvalidAggregateAction(action='create_aggregate',
@@ -243,7 +252,7 @@ class AggregateTestCaseV21(test.NoDBTestCase):
                                           {"name": "test",
                                            "availability_zone": "  nova1  "}})
 
-    def test_create_availabiltiy_zone_with_leading_trailing_spaces_compat_mode(
+    def test_create_availability_zone_with_leading_trailing_spaces_compat_mode(
             self):
 
         def fake_mock_aggs(context, name, az):
@@ -267,11 +276,12 @@ class AggregateTestCaseV21(test.NoDBTestCase):
 
     @mock.patch('nova.compute.api.AggregateAPI.create_aggregate')
     def test_create_with_none_availability_zone(self, mock_create_agg):
-        mock_create_agg.return_value = objects.Aggregate(self.context,
-                                                         name='test',
-                                                         uuid=uuid.uuid4(),
-                                                         hosts=[],
-                                                         metadata={})
+        mock_create_agg.return_value = objects.Aggregate(
+            self.context,
+            name='test',
+            uuid=uuidsentinel.aggregate,
+            hosts=[],
+            metadata={})
         body = {"aggregate": {"name": "test",
                               "availability_zone": None}}
         result = self.controller.create(self.req, body=body)
@@ -397,7 +407,7 @@ class AggregateTestCaseV21(test.NoDBTestCase):
 
     @mock.patch('nova.compute.api.AggregateAPI.update_aggregate')
     def test_update_with_none_availability_zone(self, mock_update_agg):
-        agg_id = uuid.uuid4()
+        agg_id = uuidsentinel.aggregate
         mock_update_agg.return_value = objects.Aggregate(self.context,
                                                          name='test',
                                                          uuid=agg_id,
@@ -734,89 +744,26 @@ class AggregateTestCaseV21(test.NoDBTestCase):
                'metadata': {'foo': 'bar', 'availability_zone': 'nova'},
                'hosts': ['host1', 'host2']}
         agg_obj = _make_agg_obj(agg)
-        marshalled_agg = self.controller._marshall_aggregate(agg_obj)
 
         # _marshall_aggregate() puts all fields and obj_extra_fields in the
         # top-level dict, so we need to put availability_zone at the top also
         agg['availability_zone'] = 'nova'
+
+        avr_v240 = api_version_request.APIVersionRequest("2.40")
+        avr_v241 = api_version_request.APIVersionRequest("2.41")
+
+        req = mock.MagicMock(api_version_request=avr_v241)
+        marshalled_agg = self.controller._marshall_aggregate(req, agg_obj)
+
+        self.assertEqual(agg, marshalled_agg['aggregate'])
+
+        req = mock.MagicMock(api_version_request=avr_v240)
+        marshalled_agg = self.controller._marshall_aggregate(req, agg_obj)
+
+        # UUID isn't in microversion 2.40 and before
         del agg['uuid']
         self.assertEqual(agg, marshalled_agg['aggregate'])
 
     def _assert_agg_data(self, expected, actual):
         self.assertTrue(obj_base.obj_equal_prims(expected, actual),
                         "The aggregate objects were not equal")
-
-
-class AggregateTestCaseV2(AggregateTestCaseV21):
-    add_host = 'self.controller.action'
-    remove_host = 'self.controller.action'
-    set_metadata = 'self.controller.action'
-    bad_request = exc.HTTPBadRequest
-
-    def _set_up(self):
-        self.controller = aggregates_v2.AggregateController()
-        self.req = FakeRequest()
-        self.user_req = fakes.HTTPRequest.blank('/v2/os-aggregates')
-        self.context = self.req.environ['nova.context']
-
-    def test_add_host_raises_key_error(self):
-        def stub_add_host_to_aggregate(context, aggregate, host):
-            raise KeyError
-        self.stubs.Set(self.controller.api, "add_host_to_aggregate",
-                       stub_add_host_to_aggregate)
-        # NOTE(mtreinish) The check for a KeyError here is to ensure that
-        # if add_host_to_aggregate() raises a KeyError it propagates. At
-        # one point the api code would mask the error as a HTTPBadRequest.
-        # This test is to ensure that this doesn't occur again.
-        self.assertRaises(KeyError, eval(self.add_host), self.req, "1",
-                          body={"add_host": {"host": "host1"}})
-
-    def test_add_host_to_aggregate_with_non_admin(self):
-        rule_name = "compute_extension:aggregates"
-        self.policy.set_rules({rule_name: ""})
-        self.assertRaises(exception.AdminRequired, self.controller._add_host,
-                          self.user_req, '1', {'host': 'fake_host'})
-
-    def test_remove_host_from_aggregate_with_non_admin(self):
-        rule_name = "compute_extension:aggregates"
-        self.policy.set_rules({rule_name: ""})
-        self.assertRaises(exception.AdminRequired,
-                          self.controller._remove_host, self.user_req,
-                          '1', {'host': 'fake_host'})
-
-    def test_create_name_with_leading_trailing_spaces(self):
-
-        def fake_mock_aggs(context, name, az):
-            # NOTE(alex_xu): legacy v2 api didn't strip the spaces.
-            self.assertEqual('  test  ', name)
-            return AGGREGATE
-
-        with mock.patch.object(compute_api.AggregateAPI,
-                               'create_aggregate') as mock_aggs:
-            mock_aggs.side_effect = fake_mock_aggs
-            self.controller.create(self.req,
-                                   body={"aggregate":
-                                         {"name": "  test  ",
-                                          "availability_zone": "nova1"}})
-
-    def test_create_name_with_leading_trailing_spaces_compat_mode(self):
-        pass
-
-    def test_create_availability_zone_with_leading_trailing_spaces(self):
-
-        def fake_mock_aggs(context, name, az):
-            # NOTE(alex_xu): legacy v2 api didn't strip the spaces.
-            self.assertEqual('  nova1  ', az)
-            return AGGREGATE
-
-        with mock.patch.object(compute_api.AggregateAPI,
-                               'create_aggregate') as mock_aggs:
-            mock_aggs.side_effect = fake_mock_aggs
-            self.controller.create(self.req,
-                                   body={"aggregate":
-                                         {"name": "  test  ",
-                                          "availability_zone": "  nova1  "}})
-
-    def test_create_availabiltiy_zone_with_leading_trailing_spaces_compat_mode(
-            self):
-        pass
