@@ -13,25 +13,20 @@
 #    under the License.
 
 import datetime
+
 import iso8601
 
 from nova.api.openstack.compute import availability_zone as az_v21
 from nova.api.openstack.compute import extension_info
-from nova.api.openstack.compute.legacy_v2.contrib import availability_zone \
-        as az_v2
-from nova.api.openstack.compute.legacy_v2 import servers as servers_v2
 from nova.api.openstack.compute import servers as servers_v21
-from nova.api.openstack import extensions
 from nova import availability_zones
 from nova.compute import api as compute_api
-from nova.compute import flavors
 from nova import context
 from nova import db
 from nova import exception
 from nova import servicegroup
 from nova import test
 from nova.tests.unit.api.openstack import fakes
-from nova.tests.unit import fake_instance
 from nova.tests.unit.image import fake
 from nova.tests.unit import matchers
 from nova.tests.unit.objects import test_service
@@ -101,6 +96,7 @@ class AvailabilityZoneApiTestV21(test.NoDBTestCase):
     def setUp(self):
         super(AvailabilityZoneApiTestV21, self).setUp()
         availability_zones.reset_cache()
+        fakes.stub_out_nw_api(self)
         self.stub_out('nova.db.service_get_all', fake_service_get_all)
         self.stubs.Set(availability_zones, 'set_availability_zones',
                        fake_set_availability_zones)
@@ -178,19 +174,6 @@ class AvailabilityZoneApiTestV21(test.NoDBTestCase):
                         matchers.DictMatches(expected_response))
 
 
-class AvailabilityZoneApiTestV2(AvailabilityZoneApiTestV21):
-    availability_zone = az_v2
-
-    def setUp(self):
-        super(AvailabilityZoneApiTestV2, self).setUp()
-        self.req = fakes.HTTPRequest.blank('', use_admin_context=True)
-        self.non_admin_req = fakes.HTTPRequest.blank('')
-
-    def test_availability_zone_detail_with_non_admin(self):
-        self.assertRaises(exception.AdminRequired,
-                          self.controller.detail, self.non_admin_req)
-
-
 class ServersControllerCreateTestV21(test.TestCase):
     base_url = '/v2/fake/'
 
@@ -199,40 +182,17 @@ class ServersControllerCreateTestV21(test.TestCase):
         super(ServersControllerCreateTestV21, self).setUp()
 
         self.instance_cache_num = 0
-
+        fakes.stub_out_nw_api(self)
         self._set_up_controller()
 
-        def instance_create(context, inst):
-            inst_type = flavors.get_flavor_by_flavor_id(3)
-            image_uuid = '76fa36fc-c930-4bf3-8c8a-ea2a2420deb6'
-            def_image_ref = 'http://localhost/images/%s' % image_uuid
-            self.instance_cache_num += 1
-            instance = fake_instance.fake_db_instance(**{
-                'id': self.instance_cache_num,
-                'display_name': inst['display_name'] or 'test',
-                'uuid': FAKE_UUID,
-                'instance_type': inst_type,
-                'access_ip_v4': '1.2.3.4',
-                'access_ip_v6': 'fead::1234',
-                'image_ref': inst.get('image_ref', def_image_ref),
-                'user_id': 'fake',
-                'project_id': 'fake',
-                'availability_zone': 'nova',
-                'reservation_id': inst['reservation_id'],
-                "created_at": datetime.datetime(2010, 10, 10, 12, 0, 0),
-                "updated_at": datetime.datetime(2010, 11, 11, 11, 0, 0),
-                "progress": 0,
-                "fixed_ips": [],
-                "task_state": "",
-                "vm_state": "",
-                "root_device_name": inst.get('root_device_name', 'vda'),
-            })
-
+        def create_db_entry_for_new_instance(*args, **kwargs):
+            instance = args[4]
+            instance.uuid = FAKE_UUID
             return instance
 
         fake.stub_out_image_service(self)
-        self.stub_out('nova.db.instance_create', instance_create)
-
+        self.stub_out('nova.compute.api.API.create_db_entry_for_new_instance',
+                      create_db_entry_for_new_instance)
         self.req = fakes.HTTPRequest.blank('')
 
     def _set_up_controller(self):
@@ -339,29 +299,3 @@ class ServersControllerCreateTestV21(test.TestCase):
         res = self.controller.create(self.req, body=body).obj
         server = res['server']
         self.assertEqual(fakes.FAKE_UUID, server['id'])
-
-
-class ServersControllerCreateTestV2(ServersControllerCreateTestV21):
-    def _set_up_controller(self):
-        ext_mgr = extensions.ExtensionManager()
-        ext_mgr.extensions = {'os-availability-zone': 'fake'}
-        self.controller = servers_v2.Controller(ext_mgr)
-        ext_mgr_no_az = extensions.ExtensionManager()
-        ext_mgr_no_az.extensions = {}
-        self.no_availability_zone_controller = servers_v2.Controller(
-                                                   ext_mgr_no_az)
-
-    def test_create_instance_with_invalid_availability_zone_too_long(self):
-        # NOTE: v2.0 API does not check this bad request case.
-        # So we skip this test for v2.0 API.
-        pass
-
-    def test_create_instance_with_invalid_availability_zone_too_short(self):
-        # NOTE: v2.0 API does not check this bad request case.
-        # So we skip this test for v2.0 API.
-        pass
-
-    def test_create_instance_with_invalid_availability_zone_not_str(self):
-        # NOTE: v2.0 API does not check this bad request case.
-        # So we skip this test for v2.0 API.
-        pass
