@@ -15,7 +15,9 @@
 
 import datetime
 
+import mock
 from oslo_serialization import jsonutils
+import six
 
 from nova.api.openstack import compute
 from nova.compute import api as compute_api
@@ -43,11 +45,11 @@ class DiskConfigTestCaseV21(test.TestCase):
 
     def setUp(self):
         super(DiskConfigTestCaseV21, self).setUp()
+        fakes.stub_out_nw_api(self)
+        fakes.stub_out_secgroup_api(self)
         self._set_up_app()
         self._setup_fake_image_service()
 
-        fakes.stub_out_nw_api(self)
-
         FAKE_INSTANCES = [
             fakes.stub_instance(1,
                                 uuid=MANUAL_INSTANCE_UUID,
@@ -128,13 +130,17 @@ class DiskConfigTestCaseV21(test.TestCase):
         self.stub_out('nova.db.instance_create', fake_instance_create)
 
     def _set_up_app(self):
-        self.app = compute.APIRouterV21(init_only=('servers', 'images',
-                                                   'os-disk-config'))
+        self.app = compute.APIRouterV21()
 
     def _get_expected_msg_for_invalid_disk_config(self):
-        return ('{{"badRequest": {{"message": "Invalid input for'
-                ' field/attribute {0}. Value: {1}. u\'{1}\' is'
-                ' not one of [\'AUTO\', \'MANUAL\']", "code": 400}}}}')
+        if six.PY3:
+            return ('{{"badRequest": {{"message": "Invalid input for'
+                    ' field/attribute {0}. Value: {1}. \'{1}\' is'
+                    ' not one of [\'AUTO\', \'MANUAL\']", "code": 400}}}}')
+        else:
+            return ('{{"badRequest": {{"message": "Invalid input for'
+                    ' field/attribute {0}. Value: {1}. u\'{1}\' is'
+                    ' not one of [\'AUTO\', \'MANUAL\']", "code": 400}}}}')
 
     def _setup_fake_image_service(self):
         self.image_service = nova.tests.unit.image.fake.stub_out_image_service(
@@ -185,6 +191,8 @@ class DiskConfigTestCaseV21(test.TestCase):
             self.assertDiskConfig(server_dict, expected)
 
     def test_show_image(self):
+        self.flags(group='glance', api_servers=['http://localhost:9292'])
+
         req = fakes.HTTPRequest.blank(
             '/fake/images/a440c04b-79fa-479c-bed1-0b816eaec379')
         res = req.get_response(self.app)
@@ -319,13 +327,22 @@ class DiskConfigTestCaseV21(test.TestCase):
         server_dict = jsonutils.loads(res.body)['server']
         self.assertDiskConfig(server_dict, 'MANUAL')
 
-    def _test_update_server_disk_config(self, uuid, disk_config):
+    @mock.patch('nova.api.openstack.common.get_instance')
+    def _test_update_server_disk_config(self, uuid, disk_config,
+                                        get_instance_mock):
         req = fakes.HTTPRequest.blank(
             '/fake/servers/%s' % uuid)
         req.method = 'PUT'
         req.content_type = 'application/json'
         body = {'server': {API_DISK_CONFIG: disk_config}}
         req.body = jsonutils.dump_as_bytes(body)
+        auto_disk_config = (disk_config == 'AUTO')
+        instance = fakes.stub_instance_obj(
+                       req.environ['nova.context'],
+                       project_id=req.environ['nova.context'].project_id,
+                       user_id=req.environ['nova.context'].user_id,
+                       auto_disk_config=auto_disk_config)
+        get_instance_mock.return_value = instance
         res = req.get_response(self.app)
         server_dict = jsonutils.loads(res.body)['server']
         self.assertDiskConfig(server_dict, disk_config)
@@ -349,14 +366,23 @@ class DiskConfigTestCaseV21(test.TestCase):
         expected_msg = self._get_expected_msg_for_invalid_disk_config()
         expected_msg = expected_msg.format(API_DISK_CONFIG, 'server_test')
 
-        self.assertEqual(jsonutils.loads(expected_msg),
-                         jsonutils.loads(res.body))
+        self.assertJsonEqual(jsonutils.loads(expected_msg),
+                             jsonutils.loads(res.body))
 
-    def _test_rebuild_server_disk_config(self, uuid, disk_config):
+    @mock.patch('nova.api.openstack.common.get_instance')
+    def _test_rebuild_server_disk_config(self, uuid, disk_config,
+                                         get_instance_mock):
         req = fakes.HTTPRequest.blank(
             '/fake/servers/%s/action' % uuid)
         req.method = 'POST'
         req.content_type = 'application/json'
+        auto_disk_config = (disk_config == 'AUTO')
+        instance = fakes.stub_instance_obj(
+                       req.environ['nova.context'],
+                       project_id=req.environ['nova.context'].project_id,
+                       user_id=req.environ['nova.context'].user_id,
+                       auto_disk_config=auto_disk_config)
+        get_instance_mock.return_value = instance
         body = {"rebuild": {
                   'imageRef': 'cedef40a-ed67-4d10-800e-17455edce175',
                   API_DISK_CONFIG: disk_config
@@ -396,11 +422,18 @@ class DiskConfigTestCaseV21(test.TestCase):
         server_dict = jsonutils.loads(res.body)['server']
         self.assertDiskConfig(server_dict, 'AUTO')
 
-    def test_rebuild_server_with_auto_disk_config(self):
+    @mock.patch('nova.api.openstack.common.get_instance')
+    def test_rebuild_server_with_auto_disk_config(self, get_instance_mock):
         req = fakes.HTTPRequest.blank(
             '/fake/servers/%s/action' % AUTO_INSTANCE_UUID)
         req.method = 'POST'
         req.content_type = 'application/json'
+        instance = fakes.stub_instance_obj(
+                       req.environ['nova.context'],
+                       project_id=req.environ['nova.context'].project_id,
+                       user_id=req.environ['nova.context'].user_id,
+                       auto_disk_config=True)
+        get_instance_mock.return_value = instance
         body = {"rebuild": {
                   'imageRef': 'cedef40a-ed67-4d10-800e-17455edce175',
                   API_DISK_CONFIG: 'AUTO'
@@ -435,17 +468,3 @@ class DiskConfigTestCaseV21(test.TestCase):
 
         req.body = jsonutils.dump_as_bytes(body)
         req.get_response(self.app)
-
-
-class DiskConfigTestCaseV2(DiskConfigTestCaseV21):
-    def _set_up_app(self):
-        self.flags(verbose=True,
-        osapi_compute_extension=[
-            'nova.api.openstack.compute.contrib.select_extensions'],
-        osapi_compute_ext_list=['Disk_config'])
-
-        self.app = compute.APIRouter(init_only=('servers', 'images'))
-
-    def _get_expected_msg_for_invalid_disk_config(self):
-        return ('{{"badRequest": {{"message": "{0} must be either'
-                ' \'MANUAL\' or \'AUTO\'.", "code": 400}}}}')
