@@ -15,7 +15,6 @@
 
 import mock
 from oslo_serialization import jsonutils
-import webob
 
 from nova.api.openstack.compute import (extended_volumes
                                                    as extended_volumes_v21)
@@ -96,6 +95,7 @@ class ExtendedVolumesTestV21(test.TestCase):
     def setUp(self):
         super(ExtendedVolumesTestV21, self).setUp()
         fakes.stub_out_nw_api(self)
+        fakes.stub_out_secgroup_api(self)
         self.stubs.Set(compute.api.API, 'get', fake_compute_get)
         self.stubs.Set(compute.api.API, 'get_all', fake_compute_get_all)
         self.stub_out('nova.db.block_device_mapping_get_all_by_instance_uuids',
@@ -106,18 +106,17 @@ class ExtendedVolumesTestV21(test.TestCase):
         self.stub_out('nova.db.instance_get_by_uuid', return_server)
 
     def _setup_app(self):
-        return fakes.wsgi_app_v21(init_only=('os-extended-volumes',
-                                             'servers'))
+        return fakes.wsgi_app_v21()
 
     def _setUp(self):
         self.Controller = extended_volumes_v21.ExtendedVolumesController()
         self.stubs.Set(volume.cinder.API, 'get', fake_volume_get)
 
     def _make_request(self, url, body=None):
-        req = webob.Request.blank('/v2/fake/servers' + url)
+        req = fakes.HTTPRequest.blank('/v2/fake/servers' + url)
         req.headers['Accept'] = self.content_type
         req.headers = {os_wsgi.API_VERSION_REQUEST_HEADER:
-                       self.wsgi_api_version}
+                       'compute %s' % self.wsgi_api_version}
         if body:
             req.body = jsonutils.dump_as_bytes(body)
             req.method = 'POST'
@@ -148,18 +147,6 @@ class ExtendedVolumesTestV21(test.TestCase):
             self.assertEqual(self.exp_volumes_detail[i], actual)
 
 
-class ExtendedVolumesTestV2(ExtendedVolumesTestV21):
-
-    def _setup_app(self):
-        return fakes.wsgi_app(init_only=('servers',))
-
-    def _setUp(self):
-        self.flags(
-                   osapi_compute_extension=['nova.api.openstack.compute.'
-                                            'contrib.select_extensions'],
-                   osapi_compute_ext_list=['Extended_volumes'])
-
-
 class ExtendedVolumesTestV23(ExtendedVolumesTestV21):
 
     exp_volumes_show = [
