@@ -14,15 +14,13 @@
 #    under the License.
 
 import copy
-import uuid
 
+import mock
 from oslo_policy import policy as oslo_policy
 import six
 from webob import exc
 
 from nova.api.openstack.compute import instance_actions as instance_actions_v21
-from nova.api.openstack.compute.legacy_v2.contrib import instance_actions \
-        as instance_actions_v2
 from nova.api.openstack import wsgi as os_wsgi
 from nova.compute import api as compute_api
 from nova.db.sqlalchemy import models
@@ -31,8 +29,8 @@ from nova import objects
 from nova import policy
 from nova import test
 from nova.tests.unit.api.openstack import fakes
-from nova.tests.unit import fake_instance
 from nova.tests.unit import fake_server_actions
+from nova.tests import uuidsentinel as uuids
 
 FAKE_UUID = fake_server_actions.FAKE_UUID
 FAKE_REQUEST_ID = fake_server_actions.FAKE_REQUEST_ID1
@@ -80,61 +78,39 @@ class InstanceActionsPolicyTestV21(test.NoDBTestCase):
         fake_url = '/123/servers/12/%s' % action
         return fakes.HTTPRequest.blank(fake_url)
 
+    def _get_instance_other_project(self, req):
+        context = req.environ['nova.context']
+        project_id = '%s_unequal' % context.project_id
+        return objects.Instance(project_id=project_id)
+
     def _set_policy_rules(self):
         rules = {'compute:get': '',
                  'os_compute_api:os-instance-actions':
                      'project_id:%(project_id)s'}
         policy.set_rules(oslo_policy.Rules.from_dict(rules))
 
-    def test_list_actions_restricted_by_project(self):
+    @mock.patch('nova.api.openstack.common.get_instance')
+    def test_list_actions_restricted_by_project(self, mock_instance_get):
         self._set_policy_rules()
-
-        def fake_instance_get_by_uuid(context, instance_id,
-                                      columns_to_join=None,
-                                      use_slave=False):
-            return fake_instance.fake_db_instance(
-                **{'name': 'fake', 'project_id': '%s_unequal' %
-                       context.project_id})
-
-        self.stub_out('nova.db.instance_get_by_uuid',
-                      fake_instance_get_by_uuid)
         req = self._get_http_req('os-instance-actions')
+        mock_instance_get.return_value = self._get_instance_other_project(req)
         self.assertRaises(exception.Forbidden, self.controller.index, req,
-                          str(uuid.uuid4()))
+                          uuids.fake)
 
-    def test_get_action_restricted_by_project(self):
+    @mock.patch('nova.api.openstack.common.get_instance')
+    def test_get_action_restricted_by_project(self, mock_instance_get):
         self._set_policy_rules()
-
-        def fake_instance_get_by_uuid(context, instance_id,
-                                      columns_to_join=None,
-                                      use_slave=False):
-            return fake_instance.fake_db_instance(
-                **{'name': 'fake', 'project_id': '%s_unequal' %
-                       context.project_id})
-
-        self.stub_out('nova.db.instance_get_by_uuid',
-                      fake_instance_get_by_uuid)
         req = self._get_http_req('os-instance-actions/1')
+        mock_instance_get.return_value = self._get_instance_other_project(req)
         self.assertRaises(exception.Forbidden, self.controller.show, req,
-                          str(uuid.uuid4()), '1')
-
-
-class InstanceActionsPolicyTestV2(InstanceActionsPolicyTestV21):
-    instance_actions = instance_actions_v2
-
-    def _set_policy_rules(self):
-        rules = {'compute:get': '',
-                 'compute_extension:instance_actions':
-                     'project_id:%(project_id)s'}
-        policy.set_rules(oslo_policy.Rules.from_dict(rules))
+                          uuids.fake, '1')
 
 
 class InstanceActionsTestV21(test.NoDBTestCase):
     instance_actions = instance_actions_v21
     wsgi_api_version = os_wsgi.DEFAULT_API_VERSION
 
-    def fake_get(self, context, instance_uuid, expected_attrs=None,
-                     want_objects=False):
+    def fake_get(self, context, instance_uuid, expected_attrs=None):
         return objects.Instance(uuid=instance_uuid)
 
     def setUp(self):
@@ -142,14 +118,7 @@ class InstanceActionsTestV21(test.NoDBTestCase):
         self.controller = self.instance_actions.InstanceActionsController()
         self.fake_actions = copy.deepcopy(fake_server_actions.FAKE_ACTIONS)
         self.fake_events = copy.deepcopy(fake_server_actions.FAKE_EVENTS)
-
-        def fake_instance_get_by_uuid(context, instance_id, use_slave=False):
-            return fake_instance.fake_instance_obj(None,
-                **{'name': 'fake', 'project_id': context.project_id})
-
         self.stubs.Set(compute_api.API, 'get', self.fake_get)
-        self.stub_out('nova.db.instance_get_by_uuid',
-                      fake_instance_get_by_uuid)
 
     def _get_http_req(self, action, use_admin_context=False):
         fake_url = '/123/servers/12/%s' % action
@@ -231,8 +200,7 @@ class InstanceActionsTestV21(test.NoDBTestCase):
                           FAKE_UUID, FAKE_REQUEST_ID)
 
     def test_index_instance_not_found(self):
-        def fake_get(self, context, instance_uuid, expected_attrs=None,
-                     want_objects=False):
+        def fake_get(self, context, instance_uuid, expected_attrs=None):
             raise exception.InstanceNotFound(instance_id=instance_uuid)
         self.stubs.Set(compute_api.API, 'get', fake_get)
         req = self._get_http_req('os-instance-actions')
@@ -240,8 +208,7 @@ class InstanceActionsTestV21(test.NoDBTestCase):
                           FAKE_UUID)
 
     def test_show_instance_not_found(self):
-        def fake_get(self, context, instance_uuid, expected_attrs=None,
-                     want_objects=False):
+        def fake_get(self, context, instance_uuid, expected_attrs=None):
             raise exception.InstanceNotFound(instance_id=instance_uuid)
         self.stubs.Set(compute_api.API, 'get', fake_get)
         req = self._get_http_req('os-instance-actions/fake')
@@ -252,17 +219,6 @@ class InstanceActionsTestV21(test.NoDBTestCase):
 class InstanceActionsTestV221(InstanceActionsTestV21):
     wsgi_api_version = "2.21"
 
-    def fake_get(self, context, instance_uuid, expected_attrs=None,
-                 want_objects=False):
+    def fake_get(self, context, instance_uuid, expected_attrs=None):
         self.assertEqual('yes', context.read_deleted)
         return objects.Instance(uuid=instance_uuid)
-
-
-class InstanceActionsTestV2(InstanceActionsTestV21):
-    instance_actions = instance_actions_v2
-
-    def _set_policy_rules(self):
-        rules = {'compute:get': '',
-                 'compute_extension:instance_actions': '',
-                 'compute_extension:instance_actions:events': 'is_admin:True'}
-        policy.set_rules(oslo_policy.Rules.from_dict(rules))
