@@ -13,12 +13,10 @@
 #    under the License.
 
 import datetime
-import mock
 
+import mock
 from oslotest import moxstubout
 
-from nova.api.openstack.compute.legacy_v2.contrib import migrations \
-        as migrations_v2
 from nova.api.openstack.compute import migrations as migrations_v21
 from nova import context
 from nova import exception
@@ -46,10 +44,10 @@ fake_migrations = [
         'hidden': False,
         'memory_total': 123456,
         'memory_processed': 12345,
-        'memory_remaining': 120000,
+        'memory_remaining': 111111,
         'disk_total': 234567,
         'disk_processed': 23456,
-        'disk_remaining': 230000,
+        'disk_remaining': 211111,
         'created_at': datetime.datetime(2012, 10, 29, 13, 42, 2),
         'updated_at': datetime.datetime(2012, 10, 29, 13, 42, 2),
         'deleted_at': None,
@@ -71,10 +69,10 @@ fake_migrations = [
         'hidden': False,
         'memory_total': 123456,
         'memory_processed': 12345,
-        'memory_remaining': 120000,
+        'memory_remaining': 111111,
         'disk_total': 234567,
         'disk_processed': 23456,
-        'disk_remaining': 230000,
+        'disk_remaining': 211111,
         'created_at': datetime.datetime(2012, 10, 29, 13, 42, 2),
         'updated_at': datetime.datetime(2012, 10, 29, 13, 42, 2),
         'deleted_at': None,
@@ -183,28 +181,6 @@ class MigrationsTestCaseV21(test.NoDBTestCase):
         self.assertEqual(migrations_in_progress, response)
 
 
-class MigrationsTestCaseV2(MigrationsTestCaseV21):
-    migrations = migrations_v2
-
-    def _migrations_output(self):
-        return self.migrations.output(migrations_obj)
-
-    def setUp(self):
-        super(MigrationsTestCaseV2, self).setUp()
-        self.context = self.req.environ['nova.context']
-
-    def test_index_needs_authorization(self):
-        user_context = context.RequestContext(user_id=None,
-                                              project_id=None,
-                                              is_admin=False,
-                                              read_deleted="no",
-                                              overwrite=False)
-        self.req.environ['nova.context'] = user_context
-
-        self.assertRaises(exception.PolicyNotAuthorized, self.controller.index,
-                          self.req)
-
-
 class MigrationsTestCaseV223(MigrationsTestCaseV21):
     wsgi_api_version = '2.23'
 
