@@ -10,17 +10,16 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import inspect
-
 import mock
 import six
+import testscenarios
 import webob
 
 from nova.api.openstack import api_version_request as api_version
 from nova.api.openstack import extensions
+from nova.api.openstack import versioned_method
 from nova.api.openstack import wsgi
 from nova import exception
-from nova import i18n
 from nova import test
 from nova.tests.unit.api.openstack import fakes
 from nova.tests.unit import matchers
@@ -28,8 +27,31 @@ from nova.tests.unit import utils
 from oslo_serialization import jsonutils
 
 
-class RequestTest(test.NoDBTestCase):
-    header_name = 'X-OpenStack-Nova-API-Version'
+class MicroversionedTest(testscenarios.WithScenarios, test.NoDBTestCase):
+
+    scenarios = [
+        ('legacy-microverison', {
+            'header_name': 'X-OpenStack-Nova-API-Version',
+        }),
+        ('modern-microversion', {
+            'header_name': 'OpenStack-API-Version',
+        })
+    ]
+
+    def _make_microversion_header(self, value):
+        if 'nova' in self.header_name.lower():
+            return {self.header_name: value}
+        else:
+            return {self.header_name: 'compute %s' % value}
+
+
+class RequestTest(MicroversionedTest):
+
+    def setUp(self):
+        super(RequestTest, self).setUp()
+        self.stub_out('nova.i18n.get_available_languages',
+                      lambda *args, **kwargs:
+                      ['en_GB', 'en_AU', 'de', 'zh_CN', 'en_US'])
 
     def test_content_type_missing(self):
         request = wsgi.Request.blank('/tests/123', method='POST')
@@ -98,9 +120,6 @@ class RequestTest(test.NoDBTestCase):
                  'id2': compute_nodes[2]})
 
     def test_from_request(self):
-        self.stubs.Set(i18n, 'get_available_languages',
-                       fakes.fake_get_available_languages)
-
         request = wsgi.Request.blank('/')
         accepted = 'bogus;q=1.1, en-gb;q=0.7,en-us,en;q=.5,*;q=.7'
         request.headers = {'Accept-Language': accepted}
@@ -109,49 +128,34 @@ class RequestTest(test.NoDBTestCase):
     def test_asterisk(self):
         # asterisk should match first available if there
         # are not any other available matches
-        self.stubs.Set(i18n, 'get_available_languages',
-                       fakes.fake_get_available_languages)
-
         request = wsgi.Request.blank('/')
         accepted = '*,es;q=.5'
         request.headers = {'Accept-Language': accepted}
         self.assertEqual(request.best_match_language(), 'en_GB')
 
     def test_prefix(self):
-        self.stubs.Set(i18n, 'get_available_languages',
-                       fakes.fake_get_available_languages)
-
         request = wsgi.Request.blank('/')
         accepted = 'zh'
         request.headers = {'Accept-Language': accepted}
         self.assertEqual(request.best_match_language(), 'zh_CN')
 
     def test_secondary(self):
-        self.stubs.Set(i18n, 'get_available_languages',
-                       fakes.fake_get_available_languages)
-
         request = wsgi.Request.blank('/')
         accepted = 'nn,en-gb;q=.5'
         request.headers = {'Accept-Language': accepted}
         self.assertEqual(request.best_match_language(), 'en_GB')
 
     def test_none_found(self):
-        self.stubs.Set(i18n, 'get_available_languages',
-                       fakes.fake_get_available_languages)
-
         request = wsgi.Request.blank('/')
         accepted = 'nb-no'
         request.headers = {'Accept-Language': accepted}
-        self.assertIs(request.best_match_language(), None)
+        self.assertIsNone(request.best_match_language())
 
     def test_no_lang_header(self):
-        self.stubs.Set(i18n, 'get_available_languages',
-                       fakes.fake_get_available_languages)
-
         request = wsgi.Request.blank('/')
         accepted = ''
         request.headers = {'Accept-Language': accepted}
-        self.assertIs(request.best_match_language(), None)
+        self.assertIsNone(request.best_match_language())
 
     def test_api_version_request_header_none(self):
         request = wsgi.Request.blank('/')
@@ -164,7 +168,7 @@ class RequestTest(test.NoDBTestCase):
         mock_maxver.return_value = api_version.APIVersionRequest("2.14")
 
         request = wsgi.Request.blank('/')
-        request.headers = {self.header_name: '2.14'}
+        request.headers = self._make_microversion_header('2.14')
         request.set_api_version_request()
         self.assertEqual(api_version.APIVersionRequest("2.14"),
                          request.api_version_request)
@@ -174,14 +178,14 @@ class RequestTest(test.NoDBTestCase):
         mock_maxver.return_value = api_version.APIVersionRequest("3.5")
 
         request = wsgi.Request.blank('/')
-        request.headers = {self.header_name: 'latest'}
+        request.headers = self._make_microversion_header('latest')
         request.set_api_version_request()
         self.assertEqual(api_version.APIVersionRequest("3.5"),
                          request.api_version_request)
 
     def test_api_version_request_header_invalid(self):
         request = wsgi.Request.blank('/')
-        request.headers = {self.header_name: '2.1.3'}
+        request.headers = self._make_microversion_header('2.1.3')
 
         self.assertRaises(exception.InvalidAPIVersionString,
                           request.set_api_version_request)
@@ -268,8 +272,7 @@ class JSONDeserializerTest(test.NoDBTestCase):
                           deserializer.deserialize, data)
 
 
-class ResourceTest(test.NoDBTestCase):
-    header_name = 'X-OpenStack-Nova-API-Version'
+class ResourceTest(MicroversionedTest):
 
     def get_req_id_header_name(self, request):
         header_name = 'x-openstack-request-id'
@@ -307,7 +310,7 @@ class ResourceTest(test.NoDBTestCase):
 
         app = fakes.TestRouterV21(Controller())
         req = webob.Request.blank('/tests')
-        req.headers = {self.header_name: version}
+        req.headers = self._make_microversion_header(version)
         response = req.get_response(app)
         self.assertEqual(b'success', response.body)
         self.assertEqual(response.status_int, 200)
@@ -321,7 +324,7 @@ class ResourceTest(test.NoDBTestCase):
 
         app = fakes.TestRouterV21(Controller())
         req = webob.Request.blank('/tests')
-        req.headers = {self.header_name: invalid_version}
+        req.headers = self._make_microversion_header(invalid_version)
         response = req.get_response(app)
         self.assertEqual(400, response.status_int)
 
@@ -432,7 +435,7 @@ class ResourceTest(test.NoDBTestCase):
         self.assertEqual(response.status_int, 200)
         self.assertEqual(b'success', response.body)
 
-    def test_resource_not_authorized(self):
+    def test_resource_forbidden(self):
         class Controller(object):
             def index(self, req):
                 raise exception.Forbidden()
@@ -442,6 +445,16 @@ class ResourceTest(test.NoDBTestCase):
         response = req.get_response(app)
         self.assertEqual(response.status_int, 403)
 
+    def test_resource_not_authorized(self):
+        class Controller(object):
+            def index(self, req):
+                raise exception.Unauthorized()
+
+        req = webob.Request.blank('/tests')
+        app = fakes.TestRouter(Controller())
+        self.assertRaises(
+            exception.Unauthorized, req.get_response, app)
+
     def test_dispatch(self):
         class Controller(object):
             def index(self, req, pants=None):
@@ -767,7 +780,7 @@ class ResourceTest(test.NoDBTestCase):
         self.assertEqual(method, extended._delete)
         self.assertEqual(extensions, [])
 
-    def test_pre_process_extensions_regular(self):
+    def test_process_extensions_regular(self):
         class Controller(object):
             def index(self, req, pants=None):
                 return pants
@@ -785,96 +798,12 @@ class ResourceTest(test.NoDBTestCase):
             called.append(2)
             return None
 
-        extensions = [extension1, extension2]
-        response, post = resource.pre_process_extensions(extensions, None, {})
-        self.assertEqual(called, [])
-        self.assertIsNone(response)
-        self.assertEqual(list(post), [extension2, extension1])
-
-    def test_pre_process_extensions_generator(self):
-        class Controller(object):
-            def index(self, req, pants=None):
-                return pants
-
-        controller = Controller()
-        resource = wsgi.Resource(controller)
-
-        called = []
-
-        def extension1(req):
-            called.append('pre1')
-            yield
-            called.append('post1')
-
-        def extension2(req):
-            called.append('pre2')
-            yield
-            called.append('post2')
-
-        extensions = [extension1, extension2]
-        response, post = resource.pre_process_extensions(extensions, None, {})
-        post = list(post)
-        self.assertEqual(called, ['pre1', 'pre2'])
-        self.assertIsNone(response)
-        self.assertEqual(len(post), 2)
-        self.assertTrue(inspect.isgenerator(post[0]))
-        self.assertTrue(inspect.isgenerator(post[1]))
-
-        for gen in post:
-            try:
-                gen.send(None)
-            except StopIteration:
-                continue
-
-        self.assertEqual(called, ['pre1', 'pre2', 'post2', 'post1'])
-
-    def test_pre_process_extensions_generator_response(self):
-        class Controller(object):
-            def index(self, req, pants=None):
-                return pants
-
-        controller = Controller()
-        resource = wsgi.Resource(controller)
-
-        called = []
-
-        def extension1(req):
-            called.append('pre1')
-            yield 'foo'
-
-        def extension2(req):
-            called.append('pre2')
-
-        extensions = [extension1, extension2]
-        response, post = resource.pre_process_extensions(extensions, None, {})
-        self.assertEqual(called, ['pre1'])
-        self.assertEqual(response, 'foo')
-        self.assertEqual(post, [])
-
-    def test_post_process_extensions_regular(self):
-        class Controller(object):
-            def index(self, req, pants=None):
-                return pants
-
-        controller = Controller()
-        resource = wsgi.Resource(controller)
-
-        called = []
-
-        def extension1(req, resp_obj):
-            called.append(1)
-            return None
-
-        def extension2(req, resp_obj):
-            called.append(2)
-            return None
-
-        response = resource.post_process_extensions([extension2, extension1],
+        response = resource.process_extensions([extension2, extension1],
                                                     None, None, {})
         self.assertEqual(called, [2, 1])
         self.assertIsNone(response)
 
-    def test_post_process_extensions_regular_response(self):
+    def test_process_extensions_regular_response(self):
         class Controller(object):
             def index(self, req, pants=None):
                 return pants
@@ -892,70 +821,11 @@ class ResourceTest(test.NoDBTestCase):
             called.append(2)
             return 'foo'
 
-        response = resource.post_process_extensions([extension2, extension1],
+        response = resource.process_extensions([extension2, extension1],
                                                     None, None, {})
         self.assertEqual(called, [2])
         self.assertEqual(response, 'foo')
 
-    def test_post_process_extensions_generator(self):
-        class Controller(object):
-            def index(self, req, pants=None):
-                return pants
-
-        controller = Controller()
-        resource = wsgi.Resource(controller)
-
-        called = []
-
-        def extension1(req):
-            yield
-            called.append(1)
-
-        def extension2(req):
-            yield
-            called.append(2)
-
-        ext1 = extension1(None)
-        next(ext1)
-        ext2 = extension2(None)
-        next(ext2)
-
-        response = resource.post_process_extensions([ext2, ext1],
-                                                    None, None, {})
-
-        self.assertEqual(called, [2, 1])
-        self.assertIsNone(response)
-
-    def test_post_process_extensions_generator_response(self):
-        class Controller(object):
-            def index(self, req, pants=None):
-                return pants
-
-        controller = Controller()
-        resource = wsgi.Resource(controller)
-
-        called = []
-
-        def extension1(req):
-            yield
-            called.append(1)
-
-        def extension2(req):
-            yield
-            called.append(2)
-            yield 'foo'
-
-        ext1 = extension1(None)
-        next(ext1)
-        ext2 = extension2(None)
-        next(ext2)
-
-        response = resource.post_process_extensions([ext2, ext1],
-                                                    None, None, {})
-
-        self.assertEqual(called, [2])
-        self.assertEqual(response, 'foo')
-
     def test_resource_exception_handler_type_error(self):
         # A TypeError should be translated to a Fault/HTTP 400.
         def foo(a,):
@@ -984,9 +854,9 @@ class ResourceTest(test.NoDBTestCase):
         for val in six.itervalues(response.headers):
             # All headers must be utf8
             self.assertThat(val, matchers.EncodedByUTF8())
-        self.assertEqual(b'1', response.headers['x-header1'])
-        self.assertEqual(b'header2', response.headers['x-header2'])
-        self.assertEqual(b'header3', response.headers['x-header3'])
+        self.assertEqual('1', response.headers['x-header1'])
+        self.assertEqual('header2', response.headers['x-header2'])
+        self.assertEqual('header3', response.headers['x-header3'])
 
     def test_resource_valid_utf8_body(self):
         class Controller(object):
@@ -1086,3 +956,76 @@ class ValidBodyTest(test.NoDBTestCase):
         wsgi.Resource(controller=None)
         body = {'foo': 'bar'}
         self.assertFalse(self.controller.is_valid_body(body, 'foo'))
+
+
+class TestController(test.NoDBTestCase):
+    def test_check_for_versions_intersection_negative(self):
+        func_list = \
+            [versioned_method.VersionedMethod('foo',
+                                              api_version.APIVersionRequest(
+                                                  '2.1'),
+                                              api_version.APIVersionRequest(
+                                                  '2.4'),
+                                              None),
+             versioned_method.VersionedMethod('foo',
+                                              api_version.APIVersionRequest(
+                                                  '2.11'),
+                                              api_version.APIVersionRequest(
+                                                  '3.1'),
+                                              None),
+             versioned_method.VersionedMethod('foo',
+                                              api_version.APIVersionRequest(
+                                                  '2.8'),
+                                              api_version.APIVersionRequest(
+                                                  '2.9'),
+                                              None),
+             ]
+
+        result = wsgi.Controller.check_for_versions_intersection(func_list=
+                                                                 func_list)
+        self.assertFalse(result)
+
+        func_list = \
+            [versioned_method.VersionedMethod('foo',
+                                              api_version.APIVersionRequest(
+                                                  '2.12'),
+                                              api_version.APIVersionRequest(
+                                                  '2.14'),
+                                              None),
+             versioned_method.VersionedMethod('foo',
+                                              api_version.APIVersionRequest(
+                                                  '3.0'),
+                                              api_version.APIVersionRequest(
+                                                  '3.4'),
+                                              None)
+             ]
+
+        result = wsgi.Controller.check_for_versions_intersection(func_list=
+                                                                 func_list)
+        self.assertFalse(result)
+
+    def test_check_for_versions_intersection_positive(self):
+        func_list = \
+            [versioned_method.VersionedMethod('foo',
+                                              api_version.APIVersionRequest(
+                                                  '2.1'),
+                                              api_version.APIVersionRequest(
+                                                  '2.4'),
+                                              None),
+             versioned_method.VersionedMethod('foo',
+                                              api_version.APIVersionRequest(
+                                                  '2.3'),
+                                              api_version.APIVersionRequest(
+                                                  '3.0'),
+                                              None),
+             versioned_method.VersionedMethod('foo',
+                                              api_version.APIVersionRequest(
+                                                  '2.8'),
+                                              api_version.APIVersionRequest(
+                                                  '2.9'),
+                                              None),
+             ]
+
+        result = wsgi.Controller.check_for_versions_intersection(func_list=
+                                                                 func_list)
+        self.assertTrue(result)
