@@ -28,6 +28,7 @@ from nova.cells import manager
 from nova.compute import api as compute_api
 from nova.compute import cells_api as compute_cells_api
 from nova.compute import flavors
+from nova.compute import task_states
 from nova.compute import utils as compute_utils
 from nova.compute import vm_states
 import nova.conf
@@ -38,6 +39,7 @@ from nova import objects
 from nova import quota
 from nova import test
 from nova.tests.unit.compute import test_compute
+from nova.tests.unit.compute import test_shelve
 from nova.tests.unit import fake_instance
 from nova.tests.unit.objects import test_flavor
 from nova.tests import uuidsentinel as uuids
@@ -106,6 +108,7 @@ def deploy_stubs(stubs, api, original_instance=None):
 
 class CellsComputeAPITestCase(test_compute.ComputeAPITestCase):
     def setUp(self):
+        self.flags(use_neutron=False)
         super(CellsComputeAPITestCase, self).setUp()
         global ORIG_COMPUTE_API
         ORIG_COMPUTE_API = self.compute_api
@@ -144,9 +147,18 @@ class CellsComputeAPITestCase(test_compute.ComputeAPITestCase):
     def test_error_evacuate(self):
         self.skipTest("Test is incompatible with cells.")
 
+    def test_create_instance_sets_system_metadata(self):
+        self.skipTest("Test is incompatible with cells.")
+
+    def test_create_saves_flavor(self):
+        self.skipTest("Test is incompatible with cells.")
+
+    def test_create_instance_associates_security_groups(self):
+        self.skipTest("Test is incompatible with cells.")
+
     @mock.patch.object(compute_api.API, '_local_delete')
     @mock.patch.object(compute_api.API, '_lookup_instance',
-                       return_value=None)
+                       return_value=(None, None))
     def test_delete_instance_no_cell_instance_disappear(self, mock_lookup,
                                                         mock_local_delete):
         inst = self._create_fake_instance_obj()
@@ -172,7 +184,7 @@ class CellsComputeAPITestCase(test_compute.ComputeAPITestCase):
         cells_rpcapi.instance_delete_everywhere(self.context,
                 inst, delete_type)
         compute_api.API._lookup_instance(self.context,
-                                         inst.uuid).AndReturn(inst)
+                                         inst.uuid).AndReturn((None, inst))
         compute_api.API._local_delete(self.context, inst,
                                       mox.IsA(objects.BlockDeviceMappingList),
                                       method_name, mox.IgnoreArg())
@@ -193,7 +205,7 @@ class CellsComputeAPITestCase(test_compute.ComputeAPITestCase):
         @mock.patch.object(self.compute_api.cells_rpcapi,
                            'instance_delete_everywhere')
         @mock.patch.object(compute_api.API, '_lookup_instance',
-                           return_value=inst)
+                           return_value=(None, inst))
         def _test(_mock_lookup_inst, _mock_delete_everywhere):
             self.assertRaises(exception.ObjectActionError,
                     self.compute_api.delete, self.context, inst)
@@ -218,7 +230,7 @@ class CellsComputeAPITestCase(test_compute.ComputeAPITestCase):
         @mock.patch.object(self.compute_api.cells_rpcapi,
                 'instance_delete_everywhere', side_effect=add_cell_name)
         @mock.patch.object(compute_api.API, '_lookup_instance',
-                           return_value=inst)
+                           return_value=(None, inst))
         def _test(_mock_lookup_inst, mock_delete_everywhere,
                   mock_compute_delete):
             self.compute_api.delete(self.context, inst)
@@ -246,7 +258,7 @@ class CellsComputeAPITestCase(test_compute.ComputeAPITestCase):
                            side_effect=actionerror)
         @mock.patch.object(instance, 'refresh', side_effect=notfound)
         @mock.patch.object(compute_api.API, '_lookup_instance',
-                           return_value=instance)
+                           return_value=(None, instance))
         def _test(_mock_lookup_instance, mock_refresh, mock_local_delete,
                   mock_delete_everywhere, mock_compute_delete):
             self.compute_api.delete(self.context, instance)
@@ -273,7 +285,7 @@ class CellsComputeAPITestCase(test_compute.ComputeAPITestCase):
         @mock.patch.object(self.compute_api.cells_rpcapi,
                            'instance_delete_everywhere')
         @mock.patch.object(compute_api.API, '_lookup_instance',
-                           return_value=instance)
+                           return_value=(None, instance))
         @mock.patch.object(compute_api.API, '_local_delete',
                            side_effect=notfound)
         def _test(mock_local_delete, _mock_lookup, mock_delete_everywhere,
@@ -312,7 +324,7 @@ class CellsComputeAPITestCase(test_compute.ComputeAPITestCase):
         instance = self._create_fake_instance_obj()
         instance_with_cell = copy.deepcopy(instance)
         instance_with_cell.cell_name = 'foo'
-        mock_lookup_instance.return_value = instance_with_cell
+        mock_lookup_instance.return_value = None, instance_with_cell
 
         cells_rpcapi = self.compute_api.cells_rpcapi
 
@@ -338,7 +350,7 @@ class CellsComputeAPITestCase(test_compute.ComputeAPITestCase):
         # and therefore no host, set but instance.destroy fails because
         # there is now a host. And then the instance can't be looked up.
         instance = self._create_fake_instance_obj()
-        mock_lookup_instance.return_value = None
+        mock_lookup_instance.return_value = None, None
 
         cells_rpcapi = self.compute_api.cells_rpcapi
 
@@ -425,6 +437,49 @@ class CellsComputeAPITestCase(test_compute.ComputeAPITestCase):
                   cells_enabled=True)
 
 
+class CellsShelveComputeAPITestCase(test_shelve.ShelveComputeAPITestCase):
+    def setUp(self):
+        super(CellsShelveComputeAPITestCase, self).setUp()
+        global ORIG_COMPUTE_API
+        ORIG_COMPUTE_API = self.compute_api
+        self.compute_api = compute_cells_api.ComputeCellsAPI()
+
+        def _fake_validate_cell(*args, **kwargs):
+            return
+
+        def _fake_cast_to_cells(self, context, instance, method,
+                                *args, **kwargs):
+            fn = getattr(ORIG_COMPUTE_API, method)
+            fn(context, instance, *args, **kwargs)
+
+        self.stub_out('nova.compute.api.API._validate_cell',
+                      _fake_validate_cell)
+        self.stub_out('nova.compute.cells_api.ComputeCellsAPI._cast_to_cells',
+                      _fake_cast_to_cells)
+
+    def test_unshelve(self):
+        # Ensure instance can be unshelved on cell environment.
+        # The super class tests nova-shelve.
+        instance = self._create_fake_instance_obj()
+
+        self.assertIsNone(instance['task_state'])
+
+        self.compute_api.shelve(self.context, instance)
+
+        instance.task_state = None
+        instance.vm_state = vm_states.SHELVED
+        instance.save()
+
+        self.compute_api.unshelve(self.context, instance)
+
+        self.assertEqual(task_states.UNSHELVING, instance.task_state)
+
+    def tearDown(self):
+        global ORIG_COMPUTE_API
+        self.compute_api = ORIG_COMPUTE_API
+        super(CellsShelveComputeAPITestCase, self).tearDown()
+
+
 class CellsConductorAPIRPCRedirect(test.NoDBTestCase):
     def setUp(self):
         super(CellsConductorAPIRPCRedirect, self).setUp()
@@ -445,15 +500,18 @@ class CellsConductorAPIRPCRedirect(test.NoDBTestCase):
                              _validate, _get_image, _check_bdm,
                              _provision, _record_action_start):
         _get_image.return_value = (None, 'fake-image')
-        _validate.return_value = ({}, 1, None)
+        _validate.return_value = ({}, 1, None, ['default'])
         _check_bdm.return_value = objects.BlockDeviceMappingList()
-        _provision.return_value = 'instances'
+        _provision.return_value = []
 
-        self.compute_api.create(self.context, 'fake-flavor', 'fake-image')
+        with mock.patch.object(self.compute_api.compute_task_api,
+                               'schedule_and_build_instances') as sbi:
+            self.compute_api.create(self.context, 'fake-flavor', 'fake-image')
 
-        # Subsequent tests in class are verifying the hooking.  We don't check
-        # args since this is verified in compute test code.
-        self.assertTrue(self.cells_rpcapi.build_instances.called)
+            # Subsequent tests in class are verifying the hooking.  We
+            # don't check args since this is verified in compute test
+            # code.
+            self.assertTrue(sbi.called)
 
     @mock.patch.object(objects.RequestSpec, 'get_by_instance_uuid')
     @mock.patch.object(compute_api.API, '_record_action_start')
@@ -511,16 +569,13 @@ class CellsConductorAPIRPCRedirect(test.NoDBTestCase):
         orig_system_metadata = {}
         instance = fake_instance.fake_instance_obj(self.context,
                 vm_state=vm_states.ACTIVE, cell_name='fake-cell',
-                launched_at=timeutils.utcnow(), image_ref=uuids.image_id,
+                launched_at=timeutils.utcnow(),
                 system_metadata=orig_system_metadata,
                 expected_attrs=['system_metadata'])
         get_flavor.return_value = ''
-        # The API request schema validates that a UUID is passed for the
-        # imageRef parameter so we need to provide an image.
-        image_href = uuids.image_id
+        image_href = ''
         image = {"min_ram": 10, "min_disk": 1,
-                 "properties": {'architecture': 'x86_64'},
-                 "id": uuids.image_id}
+                 "properties": {'architecture': 'x86_64'}}
         admin_pass = ''
         files_to_inject = []
         bdms = objects.BlockDeviceMappingList()
