@@ -13,16 +13,19 @@
 #    under the License.
 
 import datetime
+import os
 
 import iso8601
-import netaddr
+import mock
 from oslo_versionedobjects import exception as ovo_exc
 import six
 
+from nova import exception
 from nova.network import model as network_model
 from nova.objects import fields
 from nova import signature_utils
 from nova import test
+from nova.tests.unit import fake_instance
 from nova import utils
 
 
@@ -61,6 +64,14 @@ class FakeEnumAlt(fields.Enum):
                                           **kwargs)
 
 
+class FakeAddress(fields.AddressBase):
+    PATTERN = '[a-z]+[0-9]+'
+
+
+class FakeAddressField(fields.AutoTypedField):
+    AUTO_TYPE = FakeAddress()
+
+
 class FakeEnumField(fields.BaseEnumField):
     AUTO_TYPE = FakeEnum()
 
@@ -179,248 +190,146 @@ class TestEnum(TestField):
 
 
 class TestArchitecture(TestField):
-    def setUp(self):
-        super(TestArchitecture, self).setUp()
-        self.field = fields.ArchitectureField()
-        self.coerce_good_values = [('x86_64', 'x86_64'),
-                                   ('amd64', 'x86_64'),
-                                   ('I686', 'i686'),
-                                   ('i386', 'i686')]
-        self.coerce_bad_values = ['x86_99']
-        self.to_primitive_values = self.coerce_good_values[0:1]
-        self.from_primitive_values = self.coerce_good_values[0:1]
+    @mock.patch.object(os, 'uname')
+    def test_host(self, mock_uname):
+        mock_uname.return_value = (
+            'Linux',
+            'localhost.localdomain',
+            '3.14.8-200.fc20.x86_64',
+            '#1 SMP Mon Jun 16 21:57:53 UTC 2014',
+            'i686'
+        )
 
-    def test_stringify(self):
-        self.assertEqual("'aarch64'", self.field.stringify('aarch64'))
+        self.assertEqual(fields.Architecture.I686,
+                         fields.Architecture.from_host())
 
-    def test_stringify_invalid(self):
-        self.assertRaises(ValueError, self.field.stringify, 'ppc42')
+    def test_valid_string(self):
+        self.assertTrue(fields.Architecture.is_valid('x86_64'))
 
+    def test_valid_constant(self):
+        self.assertTrue(fields.Architecture.is_valid(
+            fields.Architecture.X86_64))
 
-class TestBlockDeviceDestinationType(TestField):
-    def setUp(self):
-        super(TestBlockDeviceDestinationType, self).setUp()
-        self.field = fields.BlockDeviceDestinationTypeField()
-        self.coerce_good_values = [('local', 'local'),
-                                   ('volume', 'volume')]
-        self.coerce_bad_values = ['acme']
-        self.to_primitive_values = self.coerce_good_values[0:1]
-        self.from_primitive_values = self.coerce_good_values[0:1]
+    def test_valid_bogus(self):
+        self.assertFalse(fields.Architecture.is_valid('x86_64wibble'))
 
-    def test_stringify(self):
-        self.assertEqual("'volume'", self.field.stringify('volume'))
+    def test_canonicalize_i386(self):
+        self.assertEqual(fields.Architecture.I686,
+                         fields.Architecture.canonicalize('i386'))
 
-    def test_stringify_invalid(self):
-        self.assertRaises(ValueError, self.field.stringify, 'acme')
+    def test_canonicalize_amd64(self):
+        self.assertEqual(fields.Architecture.X86_64,
+                         fields.Architecture.canonicalize('amd64'))
 
+    def test_canonicalize_case(self):
+        self.assertEqual(fields.Architecture.X86_64,
+                         fields.Architecture.canonicalize('X86_64'))
 
-class TestBlockDeviceSourceType(TestField):
-    def setUp(self):
-        super(TestBlockDeviceSourceType, self).setUp()
-        self.field = fields.BlockDeviceSourceTypeField()
-        self.coerce_good_values = [('blank', 'blank'),
-                                   ('image', 'image'),
-                                   ('snapshot', 'snapshot'),
-                                   ('volume', 'volume')]
-        self.coerce_bad_values = ['acme']
-        self.to_primitive_values = self.coerce_good_values[0:1]
-        self.from_primitive_values = self.coerce_good_values[0:1]
+    def test_canonicalize_compat_xen1(self):
+        self.assertEqual(fields.Architecture.I686,
+                         fields.Architecture.canonicalize('x86_32'))
 
-    def test_stringify(self):
-        self.assertEqual("'image'", self.field.stringify('image'))
+    def test_canonicalize_compat_xen2(self):
+        self.assertEqual(fields.Architecture.I686,
+                         fields.Architecture.canonicalize('x86_32p'))
 
-    def test_stringify_invalid(self):
-        self.assertRaises(ValueError, self.field.stringify, 'acme')
-
-
-class TestBlockDeviceType(TestField):
-    def setUp(self):
-        super(TestBlockDeviceType, self).setUp()
-        self.field = fields.BlockDeviceTypeField()
-        self.coerce_good_values = [('cdrom', 'cdrom'),
-                                   ('disk', 'disk'),
-                                   ('floppy', 'floppy'),
-                                   ('fs', 'fs'),
-                                   ('lun', 'lun')]
-        self.coerce_bad_values = ['acme']
-        self.to_primitive_values = self.coerce_good_values[0:1]
-        self.from_primitive_values = self.coerce_good_values[0:1]
-
-    def test_stringify(self):
-        self.assertEqual("'disk'", self.field.stringify('disk'))
-
-    def test_stringify_invalid(self):
-        self.assertRaises(ValueError, self.field.stringify, 'acme')
-
-
-class TestCPUMode(TestField):
-    def setUp(self):
-        super(TestCPUMode, self).setUp()
-        self.field = fields.CPUModeField()
-        self.coerce_good_values = [('host-model', 'host-model'),
-                                   ('host-passthrough', 'host-passthrough'),
-                                   ('custom', 'custom')]
-        self.coerce_bad_values = ['magic']
-        self.to_primitive_values = self.coerce_good_values[0:1]
-        self.from_primitive_values = self.coerce_good_values[0:1]
-
-    def test_stringify(self):
-        self.assertEqual("'custom'", self.field.stringify('custom'))
-
-    def test_stringify_invalid(self):
-        self.assertRaises(ValueError, self.field.stringify, 'magic')
-
-
-class TestCPUMatch(TestField):
-    def setUp(self):
-        super(TestCPUMatch, self).setUp()
-        self.field = fields.CPUMatchField()
-        self.coerce_good_values = [('exact', 'exact'),
-                                   ('strict', 'strict'),
-                                   ('minimum', 'minimum')]
-        self.coerce_bad_values = ['best']
-        self.to_primitive_values = self.coerce_good_values[0:1]
-        self.from_primitive_values = self.coerce_good_values[0:1]
-
-    def test_stringify(self):
-        self.assertEqual("'exact'", self.field.stringify('exact'))
-
-    def test_stringify_invalid(self):
-        self.assertRaises(ValueError, self.field.stringify, 'best')
-
-
-class TestCPUFeaturePolicy(TestField):
-    def setUp(self):
-        super(TestCPUFeaturePolicy, self).setUp()
-        self.field = fields.CPUFeaturePolicyField()
-        self.coerce_good_values = [('force', 'force'),
-                                   ('require', 'require'),
-                                   ('optional', 'optional'),
-                                   ('disable', 'disable'),
-                                   ('forbid', 'forbid')]
-        self.coerce_bad_values = ['disallow']
-        self.to_primitive_values = self.coerce_good_values[0:1]
-        self.from_primitive_values = self.coerce_good_values[0:1]
-
-    def test_stringify(self):
-        self.assertEqual("'forbid'", self.field.stringify('forbid'))
-
-    def test_stringify_invalid(self):
-        self.assertRaises(ValueError, self.field.stringify, 'disallow')
-
-
-class TestConfigDrivePolicy(TestField):
-    def setUp(self):
-        super(TestConfigDrivePolicy, self).setUp()
-        self.field = fields.ConfigDrivePolicyField()
-        self.coerce_good_values = [('optional', 'optional'),
-                                   ('mandatory', 'mandatory')]
-        self.coerce_bad_values = ['acme']
-        self.to_primitive_values = self.coerce_good_values[0:1]
-        self.from_primitive_values = self.coerce_good_values[0:1]
-
-    def test_stringify(self):
-        self.assertEqual("'optional'", self.field.stringify('optional'))
-
-    def test_stringify_invalid(self):
-        self.assertRaises(ValueError, self.field.stringify, 'acme')
-
-
-class TestCPUAllocationPolicy(TestField):
-    def setUp(self):
-        super(TestCPUAllocationPolicy, self).setUp()
-        self.field = fields.CPUAllocationPolicyField()
-        self.coerce_good_values = [('dedicated', 'dedicated'),
-                                   ('shared', 'shared')]
-        self.coerce_bad_values = ['acme']
-        self.to_primitive_values = self.coerce_good_values[0:1]
-        self.from_primitive_values = self.coerce_good_values[0:1]
-
-    def test_stringify(self):
-        self.assertEqual("'shared'", self.field.stringify('shared'))
-
-    def test_stringify_invalid(self):
-        self.assertRaises(ValueError, self.field.stringify, 'acme')
-
-
-class TestCPUThreadAllocationPolicy(TestField):
-    def setUp(self):
-        super(TestCPUThreadAllocationPolicy, self).setUp()
-        self.field = fields.CPUThreadAllocationPolicyField()
-        self.coerce_good_values = [('prefer', 'prefer'),
-                                   ('isolate', 'isolate'),
-                                   ('require', 'require')]
-        self.coerce_bad_values = ['acme']
-        self.to_primitive_values = self.coerce_good_values[0:1]
-        self.from_primitive_values = self.coerce_good_values[0:1]
-
-    def test_stringify(self):
-        self.assertEqual("'prefer'", self.field.stringify('prefer'))
-
-    def test_stringify_invalid(self):
-        self.assertRaises(ValueError, self.field.stringify, 'acme')
-
-
-class TestPciDeviceType(TestField):
-    def setUp(self):
-        super(TestPciDeviceType, self).setUp()
-        self.field = fields.PciDeviceTypeField()
-        self.coerce_good_values = [('type-PCI', 'type-PCI'),
-                                   ('type-PF', 'type-PF'),
-                                   ('type-VF', 'type-VF')]
-        self.coerce_bad_values = ['acme']
-        self.to_primitive_values = self.coerce_good_values[0:1]
-        self.from_primitive_values = self.coerce_good_values[0:1]
-
-    def test_stringify(self):
-        self.assertEqual("'type-VF'", self.field.stringify('type-VF'))
-
-    def test_stringify_invalid(self):
-        self.assertRaises(ValueError, self.field.stringify, 'acme')
-
-
-class TestDiskBus(TestField):
-    def setUp(self):
-        super(TestDiskBus, self).setUp()
-        self.field = fields.DiskBusField()
-        self.coerce_good_values = [('fdc', 'fdc'),
-                                   ('ide', 'ide'),
-                                   ('sata', 'sata'),
-                                   ('scsi', 'scsi'),
-                                   ('usb', 'usb'),
-                                   ('virtio', 'virtio'),
-                                   ('xen', 'xen'),
-                                   ('lxc', 'lxc'),
-                                   ('uml', 'uml')]
-        self.coerce_bad_values = ['acme']
-        self.to_primitive_values = self.coerce_good_values[0:1]
-        self.from_primitive_values = self.coerce_good_values[0:1]
-
-    def test_stringify(self):
-        self.assertEqual("'ide'", self.field.stringify('ide'))
-
-    def test_stringify_invalid(self):
-        self.assertRaises(ValueError, self.field.stringify, 'acme')
+    def test_canonicalize_invalid(self):
+        self.assertRaises(exception.InvalidArchitectureName,
+                          fields.Architecture.canonicalize,
+                          'x86_64wibble')
 
 
 class TestHVType(TestField):
-    def setUp(self):
-        super(TestHVType, self).setUp()
-        self.field = fields.HVTypeField()
-        self.coerce_good_values = [('baremetal', 'baremetal'),
-                                   ('bhyve', 'bhyve'),
-                                   ('fake', 'fake'),
-                                   ('kvm', 'kvm'),
-                                   ('xapi', 'xen')]
-        self.coerce_bad_values = ['acme']
-        self.to_primitive_values = self.coerce_good_values[0:1]
-        self.from_primitive_values = self.coerce_good_values[0:1]
+    def test_valid_string(self):
+        self.assertTrue(fields.HVType.is_valid('vmware'))
 
-    def test_stringify(self):
-        self.assertEqual("'xen'", self.field.stringify('xen'))
+    def test_valid_constant(self):
+        self.assertTrue(fields.HVType.is_valid(fields.HVType.QEMU))
 
-    def test_stringify_invalid(self):
-        self.assertRaises(ValueError, self.field.stringify, 'acme')
+    def test_valid_docker(self):
+        self.assertTrue(fields.HVType.is_valid('docker'))
+
+    def test_valid_lxd(self):
+        self.assertTrue(fields.HVType.is_valid('lxd'))
+
+    def test_valid_vz(self):
+        self.assertTrue(fields.HVType.is_valid(
+            fields.HVType.VIRTUOZZO))
+
+    def test_valid_bogus(self):
+        self.assertFalse(fields.HVType.is_valid('acmehypervisor'))
+
+    def test_canonicalize_none(self):
+        self.assertIsNone(fields.HVType.canonicalize(None))
+
+    def test_canonicalize_case(self):
+        self.assertEqual(fields.HVType.QEMU,
+                         fields.HVType.canonicalize('QeMu'))
+
+    def test_canonicalize_xapi(self):
+        self.assertEqual(fields.HVType.XEN,
+                         fields.HVType.canonicalize('xapi'))
+
+    def test_canonicalize_invalid(self):
+        self.assertRaises(exception.InvalidHypervisorVirtType,
+                          fields.HVType.canonicalize,
+                          'wibble')
+
+
+class TestVMMode(TestField):
+    def _fake_object(self, updates):
+        return fake_instance.fake_instance_obj(None, **updates)
+
+    def test_case(self):
+        inst = self._fake_object(dict(vm_mode='HVM'))
+        mode = fields.VMMode.get_from_instance(inst)
+        self.assertEqual(mode, 'hvm')
+
+    def test_legacy_pv(self):
+        inst = self._fake_object(dict(vm_mode='pv'))
+        mode = fields.VMMode.get_from_instance(inst)
+        self.assertEqual(mode, 'xen')
+
+    def test_legacy_hv(self):
+        inst = self._fake_object(dict(vm_mode='hv'))
+        mode = fields.VMMode.get_from_instance(inst)
+        self.assertEqual(mode, 'hvm')
+
+    def test_bogus(self):
+        inst = self._fake_object(dict(vm_mode='wibble'))
+        self.assertRaises(exception.Invalid,
+                          fields.VMMode.get_from_instance,
+                          inst)
+
+    def test_good(self):
+        inst = self._fake_object(dict(vm_mode='hvm'))
+        mode = fields.VMMode.get_from_instance(inst)
+        self.assertEqual(mode, 'hvm')
+
+    def test_canonicalize_pv_compat(self):
+        mode = fields.VMMode.canonicalize('pv')
+        self.assertEqual(fields.VMMode.XEN, mode)
+
+    def test_canonicalize_hv_compat(self):
+        mode = fields.VMMode.canonicalize('hv')
+        self.assertEqual(fields.VMMode.HVM, mode)
+
+    def test_canonicalize_baremetal_compat(self):
+        mode = fields.VMMode.canonicalize('baremetal')
+        self.assertEqual(fields.VMMode.HVM, mode)
+
+    def test_canonicalize_hvm(self):
+        mode = fields.VMMode.canonicalize('hvm')
+        self.assertEqual(fields.VMMode.HVM, mode)
+
+    def test_canonicalize_none(self):
+        mode = fields.VMMode.canonicalize(None)
+        self.assertIsNone(mode)
+
+    def test_canonicalize_invalid(self):
+        self.assertRaises(exception.InvalidVirtualMachineMode,
+                          fields.VMMode.canonicalize,
+                          'invalid')
 
 
 class TestImageSignatureTypes(TestField):
@@ -433,34 +342,16 @@ class TestImageSignatureTypes(TestField):
 
     def test_hashes(self):
         for hash_name in list(signature_utils.HASH_METHODS.keys()):
-            self.assertIn(hash_name, self.hash_field.hashes)
+            self.assertIn(hash_name, self.hash_field.ALL)
 
     def test_key_types(self):
         key_type_dict = signature_utils.SignatureKeyType._REGISTERED_TYPES
         key_types = list(key_type_dict.keys())
         for key_type in key_types:
-            self.assertIn(key_type, self.key_type_field.key_types)
+            self.assertIn(key_type, self.key_type_field.ALL)
 
 
-class TestOSType(TestField):
-    def setUp(self):
-        super(TestOSType, self).setUp()
-        self.field = fields.OSTypeField()
-        self.coerce_good_values = [('linux', 'linux'),
-                                   ('windows', 'windows'),
-                                   ('WINDOWS', 'windows')]
-        self.coerce_bad_values = ['acme']
-        self.to_primitive_values = self.coerce_good_values[0:1]
-        self.from_primitive_values = self.coerce_good_values[0:1]
-
-    def test_stringify(self):
-        self.assertEqual("'linux'", self.field.stringify('linux'))
-
-    def test_stringify_invalid(self):
-        self.assertRaises(ValueError, self.field.stringify, 'acme')
-
-
-class TestResourceClass(TestField):
+class TestResourceClass(TestString):
     def setUp(self):
         super(TestResourceClass, self).setUp()
         self.field = fields.ResourceClassField()
@@ -476,228 +367,10 @@ class TestResourceClass(TestField):
             ('NUMA_MEMORY_MB', 'NUMA_MEMORY_MB'),
             ('IPV4_ADDRESS', 'IPV4_ADDRESS'),
         ]
-        self.expected_indexes = [
-            ('VCPU', 0),
-            ('MEMORY_MB', 1),
-            ('DISK_GB', 2),
-            ('PCI_DEVICE', 3),
-            ('SRIOV_NET_VF', 4),
-            ('NUMA_SOCKET', 5),
-            ('NUMA_CORE', 6),
-            ('NUMA_THREAD', 7),
-            ('NUMA_MEMORY_MB', 8),
-            ('IPV4_ADDRESS', 9),
-        ]
-        self.coerce_bad_values = ['acme']
+        self.coerce_bad_values = [object(), dict()]
         self.to_primitive_values = self.coerce_good_values[0:1]
         self.from_primitive_values = self.coerce_good_values[0:1]
 
-    def test_stringify(self):
-        self.assertEqual("'VCPU'", self.field.stringify(
-            fields.ResourceClass.VCPU))
-
-    def test_stringify_invalid(self):
-        self.assertRaises(ValueError, self.field.stringify, 'cow')
-
-    def test_index(self):
-        for name, index in self.expected_indexes:
-            self.assertEqual(index, self.field.index(name))
-
-    def test_index_invalid(self):
-        self.assertRaises(ValueError, self.field.index, 'cow')
-
-    def test_from_index(self):
-        for name, index in self.expected_indexes:
-            self.assertEqual(name, self.field.from_index(index))
-
-    def test_from_index_invalid(self):
-        self.assertRaises(IndexError, self.field.from_index, 999)
-
-
-class TestRNGModel(TestField):
-    def setUp(self):
-        super(TestRNGModel, self).setUp()
-        self.field = fields.RNGModelField()
-        self.coerce_good_values = [('virtio', 'virtio'), ]
-        self.coerce_bad_values = ['acme']
-        self.to_primitive_values = self.coerce_good_values[0:1]
-        self.from_primitive_values = self.coerce_good_values[0:1]
-
-    def test_stringify(self):
-        self.assertEqual("'virtio'", self.field.stringify('virtio'))
-
-    def test_stringify_invalid(self):
-        self.assertRaises(ValueError, self.field.stringify, 'acme')
-
-
-class TestSCSIModel(TestField):
-    def setUp(self):
-        super(TestSCSIModel, self).setUp()
-        self.field = fields.SCSIModelField()
-        self.coerce_good_values = [('buslogic', 'buslogic'),
-                                   ('ibmvscsi', 'ibmvscsi'),
-                                   ('lsilogic', 'lsilogic'),
-                                   ('lsisas1068', 'lsisas1068'),
-                                   ('lsisas1078', 'lsisas1078'),
-                                   ('virtio-scsi', 'virtio-scsi'),
-                                   ('vmpvscsi', 'vmpvscsi'),
-                                   ('lsilogicsas', 'lsisas1068'),
-                                   ('paravirtual', 'vmpvscsi')]
-        self.coerce_bad_values = ['acme']
-        self.to_primitive_values = self.coerce_good_values[0:1]
-        self.from_primitive_values = self.coerce_good_values[0:1]
-
-    def test_stringify(self):
-        self.assertEqual("'vmpvscsi'", self.field.stringify('vmpvscsi'))
-
-    def test_stringify_invalid(self):
-        self.assertRaises(ValueError, self.field.stringify, 'acme')
-
-
-class TestVideoModel(TestField):
-    def setUp(self):
-        super(TestVideoModel, self).setUp()
-        self.field = fields.VideoModelField()
-        self.coerce_good_values = [('cirrus', 'cirrus'),
-                                   ('qxl', 'qxl'),
-                                   ('vga', 'vga'),
-                                   ('vmvga', 'vmvga'),
-                                   ('xen', 'xen')]
-
-        self.coerce_bad_values = ['acme']
-        self.to_primitive_values = self.coerce_good_values[0:1]
-        self.from_primitive_values = self.coerce_good_values[0:1]
-
-    def test_stringify(self):
-        self.assertEqual("'cirrus'", self.field.stringify('cirrus'))
-
-    def test_stringify_invalid(self):
-        self.assertRaises(ValueError, self.field.stringify, 'acme')
-
-
-class TestVIFModel(TestField):
-    def setUp(self):
-        super(TestVIFModel, self).setUp()
-        self.field = fields.VIFModelField()
-        self.coerce_good_values = [('virtio', 'virtio'),
-                                   ('ne2k_pci', 'ne2k_pci'),
-                                   ('pcnet', 'pcnet'),
-                                   ('rtl8139', 'rtl8139'),
-                                   ('e1000', 'e1000'),
-                                   ('e1000e', 'e1000e'),
-                                   ('netfront', 'netfront'),
-                                   ('spapr-vlan', 'spapr-vlan'),
-                                   ('VirtualE1000', 'e1000'),
-                                   ('VirtualE1000e', 'e1000e'),
-                                   ('VirtualPCNet32', 'pcnet'),
-                                   ('VirtualSriovEthernetCard', 'sriov'),
-                                   ('VirtualVmxnet', 'vmxnet'),
-                                   ('VirtualVmxnet3', 'vmxnet3'),
-                                  ]
-        self.coerce_bad_values = ['acme']
-        self.to_primitive_values = self.coerce_good_values[0:1]
-        self.from_primitive_values = self.coerce_good_values[0:1]
-
-    def test_stringify(self):
-        self.assertEqual("'e1000'", self.field.stringify('e1000'))
-
-    def test_stringify_invalid(self):
-        self.assertRaises(ValueError, self.field.stringify, 'acme')
-
-
-class TestVMMode(TestField):
-    def setUp(self):
-        super(TestVMMode, self).setUp()
-        self.field = fields.VMModeField()
-        self.coerce_good_values = [('hvm', 'hvm'),
-                                   ('xen', 'xen'),
-                                   ('uml', 'uml'),
-                                   ('exe', 'exe'),
-                                   ('pv', 'xen'),
-                                   ('hv', 'hvm'),
-                                   ('baremetal', 'hvm')]
-        self.coerce_bad_values = ['acme']
-        self.to_primitive_values = self.coerce_good_values[0:1]
-        self.from_primitive_values = self.coerce_good_values[0:1]
-
-    def test_stringify(self):
-        self.assertEqual("'hvm'", self.field.stringify('hvm'))
-
-    def test_stringify_invalid(self):
-        self.assertRaises(ValueError, self.field.stringify, 'acme')
-
-
-class TestWatchdogAction(TestField):
-    def setUp(self):
-        super(TestWatchdogAction, self).setUp()
-        self.field = fields.WatchdogActionField()
-        self.coerce_good_values = [('none', 'none'),
-                                   ('pause', 'pause'),
-                                   ('poweroff', 'poweroff'),
-                                   ('reset', 'reset')]
-        self.coerce_bad_values = ['acme']
-        self.to_primitive_values = self.coerce_good_values[0:1]
-        self.from_primitive_values = self.coerce_good_values[0:1]
-
-    def test_stringify(self):
-        self.assertEqual("'reset'", self.field.stringify('reset'))
-
-    def test_stringify_invalid(self):
-        self.assertRaises(ValueError, self.field.stringify, 'acme')
-
-
-class TestMonitorMetricType(TestField):
-    def setUp(self):
-        super(TestMonitorMetricType, self).setUp()
-        self.field = fields.MonitorMetricTypeField()
-        self.coerce_good_values = [('cpu.frequency', 'cpu.frequency'),
-                                   ('cpu.user.time', 'cpu.user.time'),
-                                   ('cpu.kernel.time', 'cpu.kernel.time'),
-                                   ('cpu.idle.time', 'cpu.idle.time'),
-                                   ('cpu.iowait.time', 'cpu.iowait.time'),
-                                   ('cpu.user.percent', 'cpu.user.percent'),
-                                   ('cpu.kernel.percent',
-                                       'cpu.kernel.percent'),
-                                   ('cpu.idle.percent', 'cpu.idle.percent'),
-                                   ('cpu.iowait.percent',
-                                       'cpu.iowait.percent'),
-                                   ('cpu.percent', 'cpu.percent')]
-        self.coerce_bad_values = ['cpu.typo']
-        self.to_primitive_values = self.coerce_good_values[0:1]
-        self.from_primitive_values = self.coerce_good_values[0:1]
-
-    def test_stringify(self):
-        self.assertEqual("'cpu.frequency'",
-                         self.field.stringify('cpu.frequency'))
-
-    def test_stringify_invalid(self):
-        self.assertRaises(ValueError, self.field.stringify, 'cpufrequency')
-
-
-class TestDiskFormat(TestField):
-    def setUp(self):
-        super(TestDiskFormat, self).setUp()
-        self.field = fields.DiskFormatField()
-        self.coerce_good_values = [('qcow2', 'qcow2'),
-                                   ('raw', 'raw'),
-                                   ('lvm', 'lvm'),
-                                   ('rbd', 'rbd'),
-                                   ('ploop', 'ploop'),
-                                   ('vhd', 'vhd'),
-                                   ('vmdk', 'vmdk'),
-                                   ('vdi', 'vdi'),
-                                   ('iso', 'iso')]
-
-        self.coerce_bad_values = ['acme']
-        self.to_primitive_values = self.coerce_good_values[0:1]
-        self.from_primitive_values = self.coerce_good_values[0:1]
-
-    def test_stringify(self):
-        self.assertEqual("'rbd'", self.field.stringify('rbd'))
-
-    def test_stringify_invalid(self):
-        self.assertRaises(ValueError, self.field.stringify, 'acme')
-
 
 class TestInteger(TestField):
     def setUp(self):
@@ -712,7 +385,7 @@ class TestInteger(TestField):
 class TestNonNegativeInteger(TestInteger):
     def setUp(self):
         super(TestNonNegativeInteger, self).setUp()
-        self.field = fields.Field(fields.NonNegativeInteger())
+        self.field = fields.NonNegativeIntegerField()
         self.coerce_bad_values.extend(['-2', '4.2'])
 
 
@@ -729,7 +402,7 @@ class TestFloat(TestField):
 class TestNonNegativeFloat(TestFloat):
     def setUp(self):
         super(TestNonNegativeFloat, self).setUp()
-        self.field = fields.Field(fields.NonNegativeFloat())
+        self.field = fields.NonNegativeFloatField()
         self.coerce_bad_values.extend(['-4.2'])
 
 
@@ -763,49 +436,6 @@ class TestDateTime(TestField):
                                   tzinfo=iso8601.iso8601.Utc())))
 
 
-class TestIPAddress(TestField):
-    def setUp(self):
-        super(TestIPAddress, self).setUp()
-        self.field = fields.IPAddressField()
-        self.coerce_good_values = [('1.2.3.4', netaddr.IPAddress('1.2.3.4')),
-                                   ('::1', netaddr.IPAddress('::1')),
-                                   (netaddr.IPAddress('::1'),
-                                    netaddr.IPAddress('::1'))]
-        self.coerce_bad_values = ['1-2', 'foo']
-        self.to_primitive_values = [(netaddr.IPAddress('1.2.3.4'), '1.2.3.4'),
-                                    (netaddr.IPAddress('::1'), '::1')]
-        self.from_primitive_values = [('1.2.3.4',
-                                       netaddr.IPAddress('1.2.3.4')),
-                                      ('::1',
-                                       netaddr.IPAddress('::1'))]
-
-
-class TestIPAddressV4(TestField):
-    def setUp(self):
-        super(TestIPAddressV4, self).setUp()
-        self.field = fields.IPV4AddressField()
-        self.coerce_good_values = [('1.2.3.4', netaddr.IPAddress('1.2.3.4')),
-                                   (netaddr.IPAddress('1.2.3.4'),
-                                    netaddr.IPAddress('1.2.3.4'))]
-        self.coerce_bad_values = ['1-2', 'foo', '::1']
-        self.to_primitive_values = [(netaddr.IPAddress('1.2.3.4'), '1.2.3.4')]
-        self.from_primitive_values = [('1.2.3.4',
-                                       netaddr.IPAddress('1.2.3.4'))]
-
-
-class TestIPAddressV6(TestField):
-    def setUp(self):
-        super(TestIPAddressV6, self).setUp()
-        self.field = fields.IPV6AddressField()
-        self.coerce_good_values = [('::1', netaddr.IPAddress('::1')),
-                                   (netaddr.IPAddress('::1'),
-                                    netaddr.IPAddress('::1'))]
-        self.coerce_bad_values = ['1.2', 'foo', '1.2.3.4']
-        self.to_primitive_values = [(netaddr.IPAddress('::1'), '::1')]
-        self.from_primitive_values = [('::1',
-                                       netaddr.IPAddress('::1'))]
-
-
 class TestDict(TestField):
     def setUp(self):
         super(TestDict, self).setUp()
@@ -975,48 +605,6 @@ class TestNetworkModel(TestField):
                          self.field.stringify(networkinfo))
 
 
-class TestIPNetwork(TestField):
-    def setUp(self):
-        super(TestIPNetwork, self).setUp()
-        self.field = fields.Field(fields.IPNetwork())
-        good = ['192.168.1.0/24', '0.0.0.0/0', '::1/128', '::1/64', '::1/0']
-        self.coerce_good_values = [(x, netaddr.IPNetwork(x)) for x in good]
-        self.coerce_bad_values = ['192.168.0.0/f', '192.168.0.0/foo',
-                                  '::1/129', '192.168.0.0/-1']
-        self.to_primitive_values = [(netaddr.IPNetwork(x), x)
-                                    for x in good]
-        self.from_primitive_values = [(x, netaddr.IPNetwork(x))
-                                      for x in good]
-
-
-class TestIPV4Network(TestField):
-    def setUp(self):
-        super(TestIPV4Network, self).setUp()
-        self.field = fields.Field(fields.IPV4Network())
-        good = ['192.168.1.0/24', '0.0.0.0/0']
-        self.coerce_good_values = [(x, netaddr.IPNetwork(x)) for x in good]
-        self.coerce_bad_values = ['192.168.0.0/f', '192.168.0.0/foo',
-                                  '::1/129', '192.168.0.0/-1']
-        self.to_primitive_values = [(netaddr.IPNetwork(x), x)
-                                    for x in good]
-        self.from_primitive_values = [(x, netaddr.IPNetwork(x))
-                                      for x in good]
-
-
-class TestIPV6Network(TestField):
-    def setUp(self):
-        super(TestIPV6Network, self).setUp()
-        self.field = fields.Field(fields.IPV6Network())
-        good = ['::1/128', '::1/64', '::1/0']
-        self.coerce_good_values = [(x, netaddr.IPNetwork(x)) for x in good]
-        self.coerce_bad_values = ['192.168.0.0/f', '192.168.0.0/foo',
-                                  '::1/129', '192.168.0.0/-1']
-        self.to_primitive_values = [(netaddr.IPNetwork(x), x)
-                                    for x in good]
-        self.from_primitive_values = [(x, netaddr.IPNetwork(x))
-                                      for x in good]
-
-
 class TestNotificationPriority(TestField):
     def setUp(self):
         super(TestNotificationPriority, self).setUp()
@@ -1070,3 +658,96 @@ class TestNotificationAction(TestField):
 
     def test_stringify_invalid(self):
         self.assertRaises(ValueError, self.field.stringify, 'magic')
+
+
+class TestPCIAddress(TestField):
+    def setUp(self):
+        super(TestPCIAddress, self).setUp()
+        self.field = fields.Field(fields.PCIAddressField())
+        self.coerce_good_values = [('0000:00:02.0', '0000:00:02.0')]
+        self.coerce_bad_values = [
+            '000:00:02.0',
+            '0000:0:02.0',
+            '0000:00:2.0',
+            '0000:00:02.',
+            '-000:00:02.0',
+            '0000:0-:02.0',
+            '0000:00:-2.0',
+            '0000:00:02.-',
+            '000000:02.0',
+            '0000:0:02.0',
+            '0000:00:020',
+        ]
+        self.to_primitive_values = self.coerce_good_values
+        self.from_primitive_values = self.coerce_good_values
+
+
+class TestUSBAddress(TestField):
+    def setUp(self):
+        super(TestUSBAddress, self).setUp()
+        self.field = fields.Field(fields.USBAddressField())
+        self.coerce_good_values = [('0:0', '0:0')]
+        self.coerce_bad_values = [
+            '00',
+            '0:',
+            '0.0',
+            '-.0',
+        ]
+        self.to_primitive_values = self.coerce_good_values
+        self.from_primitive_values = self.coerce_good_values
+
+
+class TestSCSIAddress(TestField):
+    def setUp(self):
+        super(TestSCSIAddress, self).setUp()
+        self.field = fields.Field(fields.SCSIAddressField())
+        self.coerce_good_values = [('1:0:2:0', '1:0:2:0')]
+        self.coerce_bad_values = [
+                '1:0:2',
+                '-:0:2:0',
+                '1:-:2:0',
+                '1:0:-:0',
+                '1:0:2:-',
+        ]
+        self.to_primitive_values = self.coerce_good_values
+        self.from_primitive_values = self.coerce_good_values
+
+
+class TestIDEAddress(TestField):
+    def setUp(self):
+        super(TestIDEAddress, self).setUp()
+        self.field = fields.Field(fields.IDEAddressField())
+        self.coerce_good_values = [('0:0', '0:0')]
+        self.coerce_bad_values = [
+            '0:2',
+            '00',
+            '0',
+        ]
+        self.to_primitive_values = self.coerce_good_values
+        self.from_primitive_values = self.coerce_good_values
+
+
+class TestSecureBoot(TestField):
+    def setUp(self):
+        super(TestSecureBoot, self).setUp()
+        self.field = fields.SecureBoot()
+        self.coerce_good_values = [('required', 'required'),
+                                   ('disabled', 'disabled'),
+                                   ('optional', 'optional')]
+        self.coerce_bad_values = ['enabled']
+        self.to_primitive_values = self.coerce_good_values[0:1]
+        self.from_primitive_values = self.coerce_good_values[0:1]
+
+    def test_stringify(self):
+        self.assertEqual("'required'", self.field.stringify('required'))
+
+    def test_stringify_invalid(self):
+        self.assertRaises(ValueError, self.field.stringify, 'enabled')
+
+
+class TestSchemaGeneration(test.NoDBTestCase):
+    def test_address_base_get_schema(self):
+        field = FakeAddressField()
+        expected = {'type': ['string'], 'pattern': '[a-z]+[0-9]+',
+                    'readonly': False}
+        self.assertEqual(expected, field.get_schema())
