@@ -16,6 +16,7 @@ import datetime
 
 from nova import exception
 from nova import objects
+from nova.objects import fields
 from nova import test
 
 
@@ -282,12 +283,19 @@ class TestImageMetaProps(test.NoDBTestCase):
 
     def test_obj_make_compatible(self):
         props = {
+            'hw_firmware_type': 'uefi',
+            'hw_cpu_realtime_mask': '^0-1',
+            'hw_cpu_thread_policy': 'prefer',
             'img_config_drive': 'mandatory',
             'os_admin_user': 'root',
             'hw_vif_multiqueue_enabled': True,
             'img_hv_type': 'kvm',
             'img_hv_requested_version': '>= 1.0',
             'os_require_quiesce': True,
+            'os_secure_boot': 'required',
+            'hw_rescue_bus': 'ide',
+            'hw_rescue_device': 'disk',
+            'hw_watchdog_action': fields.WatchdogAction.DISABLED,
         }
 
         obj = objects.ImageMetaProps(**props)
@@ -299,3 +307,19 @@ class TestImageMetaProps(test.NoDBTestCase):
             obj.hw_disk_bus = bus
             self.assertRaises(exception.ObjectActionError,
                               obj.obj_to_primitive, '1.0')
+
+    def test_obj_make_compatible_watchdog_action_not_disabled(self):
+        """Tests that we don't pop the hw_watchdog_action if the value is not
+        'disabled'.
+        """
+        obj = objects.ImageMetaProps(
+            hw_watchdog_action=fields.WatchdogAction.PAUSE)
+        primitive = obj.obj_to_primitive('1.0')
+        self.assertIn('hw_watchdog_action', primitive['nova_object.data'])
+        self.assertEqual(fields.WatchdogAction.PAUSE,
+                         primitive['nova_object.data']['hw_watchdog_action'])
+
+    def test_set_os_secure_boot(self):
+        props = {'os_secure_boot': "required"}
+        secure_props = objects.ImageMetaProps.from_dict(props)
+        self.assertEqual("required", secure_props.os_secure_boot)
