@@ -124,6 +124,25 @@ class _TestNUMA(object):
         numacell.unpin_cpus_with_siblings(set([4]))
         self.assertEqual(set([1, 2, 3, 4]), numacell.free_cpus)
 
+    def test_pinning_with_siblings_with_empty_siblings_list(self):
+        numacell = objects.NUMACell(id=0, cpuset=set([1, 2, 3, 4]), memory=512,
+                                    cpu_usage=0, memory_usage=256,
+                                    pinned_cpus=set([]),
+                                    siblings=[],
+                                    mempages=[])
+
+        numacell.pin_cpus_with_siblings(set([1, 2]))
+        self.assertEqual(set([1, 2]), numacell.pinned_cpus)
+        numacell.unpin_cpus_with_siblings(set([1]))
+        self.assertEqual(set([2]), numacell.pinned_cpus)
+        self.assertRaises(exception.CPUUnpinningInvalid,
+                          numacell.unpin_cpus_with_siblings,
+                          set([1]))
+        self.assertRaises(exception.CPUPinningInvalid,
+                          numacell.pin_cpus_with_siblings,
+                          set([2]))
+        self.assertEqual(set([2]), numacell.pinned_cpus)
+
     def test_pages_topology_wipe(self):
         pages_topology = objects.NUMAPagesTopology(
             size_kb=2048, total=1024, used=512)
