@@ -12,6 +12,8 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import mock
+
 from nova import db
 from nova.objects import instance
 from nova.objects import security_group
@@ -38,42 +40,40 @@ class _TestSecurityGroupObject(object):
         # NOTE(danms): Account for the difference in 'deleted'
         return dict(db_secgroup.items(), deleted=False)
 
-    def test_get(self):
-        self.mox.StubOutWithMock(db, 'security_group_get')
-        db.security_group_get(self.context, 1).AndReturn(fake_secgroup)
-        self.mox.ReplayAll()
+    @mock.patch.object(db, 'security_group_get',
+                       return_value=fake_secgroup)
+    def test_get(self, mock_get):
         secgroup = security_group.SecurityGroup.get(self.context, 1)
         ovo_fixture.compare_obj(self, secgroup,
                                 self._fix_deleted(fake_secgroup))
         self.assertEqual(secgroup.obj_what_changed(), set())
+        mock_get.assert_called_once_with(self.context, 1)
 
-    def test_get_by_name(self):
-        self.mox.StubOutWithMock(db, 'security_group_get_by_name')
-        db.security_group_get_by_name(self.context, 'fake-project',
-                                      'fake-name').AndReturn(fake_secgroup)
-        self.mox.ReplayAll()
+    @mock.patch.object(db, 'security_group_get_by_name',
+                       return_value=fake_secgroup)
+    def test_get_by_name(self, mock_get):
         secgroup = security_group.SecurityGroup.get_by_name(self.context,
                                                             'fake-project',
                                                             'fake-name')
         ovo_fixture.compare_obj(self, secgroup,
                                 self._fix_deleted(fake_secgroup))
         self.assertEqual(secgroup.obj_what_changed(), set())
+        mock_get.assert_called_once_with(self.context,
+                                         'fake-project',
+                                         'fake-name')
 
-    def test_in_use(self):
-        self.mox.StubOutWithMock(db, 'security_group_in_use')
-        db.security_group_in_use(self.context, 123).AndReturn(True)
-        self.mox.ReplayAll()
+    @mock.patch.object(db, 'security_group_in_use',
+                       return_value=True)
+    def test_in_use(self, mock_inuse):
         secgroup = security_group.SecurityGroup(context=self.context)
         secgroup.id = 123
         self.assertTrue(secgroup.in_use())
+        mock_inuse.assert_called_once_with(self.context, 123)
 
-    def test_save(self):
-        self.mox.StubOutWithMock(db, 'security_group_update')
+    @mock.patch.object(db, 'security_group_update')
+    def test_save(self, mock_update):
         updated_secgroup = dict(fake_secgroup, project_id='changed')
-        db.security_group_update(self.context, 1,
-                                 {'description': 'foobar'}).AndReturn(
-                                     updated_secgroup)
-        self.mox.ReplayAll()
+        mock_update.return_value = updated_secgroup
         secgroup = security_group.SecurityGroup._from_db_object(
             self.context, security_group.SecurityGroup(),
             fake_secgroup)
@@ -82,20 +82,21 @@ class _TestSecurityGroupObject(object):
         ovo_fixture.compare_obj(self, secgroup,
                                 self._fix_deleted(updated_secgroup))
         self.assertEqual(secgroup.obj_what_changed(), set())
+        mock_update.assert_called_once_with(self.context, 1,
+                                            {'description': 'foobar'})
 
-    def test_save_no_changes(self):
-        self.mox.StubOutWithMock(db, 'security_group_update')
-        self.mox.ReplayAll()
+    @mock.patch.object(db, 'security_group_update')
+    def test_save_no_changes(self, mock_update):
         secgroup = security_group.SecurityGroup._from_db_object(
             self.context, security_group.SecurityGroup(),
             fake_secgroup)
         secgroup.save()
+        self.assertFalse(mock_update.called)
 
-    def test_refresh(self):
+    @mock.patch.object(db, 'security_group_get')
+    def test_refresh(self, mock_get):
         updated_secgroup = dict(fake_secgroup, description='changed')
-        self.mox.StubOutWithMock(db, 'security_group_get')
-        db.security_group_get(self.context, 1).AndReturn(updated_secgroup)
-        self.mox.ReplayAll()
+        mock_get.return_value = updated_secgroup
         secgroup = security_group.SecurityGroup._from_db_object(
             self.context, security_group.SecurityGroup(self.context),
             fake_secgroup)
@@ -103,6 +104,30 @@ class _TestSecurityGroupObject(object):
         ovo_fixture.compare_obj(self, secgroup,
                                 self._fix_deleted(updated_secgroup))
         self.assertEqual(secgroup.obj_what_changed(), set())
+        mock_get.assert_called_once_with(self.context, 1)
+
+    @mock.patch.object(db, 'security_group_update')
+    def test_with_uuid(self, mock_db_update):
+        """Tests that we can set a uuid but not save it and it's removed when
+        backporting to an older version of the object.
+        """
+        # Test set/get.
+        secgroup = security_group.SecurityGroup(
+            self.context, uuid=uuids.neutron_id)
+        self.assertEqual(uuids.neutron_id, secgroup.uuid)
+        # Test backport.
+        primitive = secgroup.obj_to_primitive(target_version='1.1')
+        self.assertNotIn('uuid', primitive)
+        # Make sure the uuid is still set before we save().
+        self.assertIn('uuid', secgroup)
+        secgroup.save()
+        self.assertFalse(mock_db_update.called)
+
+    def test_identifier(self):
+        secgroup = security_group.SecurityGroup(name='foo')
+        self.assertEqual('foo', secgroup.identifier)
+        secgroup.uuid = uuids.secgroup
+        self.assertEqual(uuids.secgroup, secgroup.identifier)
 
 
 class TestSecurityGroupObject(test_objects._LocalTest,
@@ -122,10 +147,9 @@ fake_secgroups = [
 
 
 class _TestSecurityGroupListObject(object):
-    def test_get_all(self):
-        self.mox.StubOutWithMock(db, 'security_group_get_all')
-        db.security_group_get_all(self.context).AndReturn(fake_secgroups)
-        self.mox.ReplayAll()
+    @mock.patch.object(db, 'security_group_get_all',
+                       return_value=fake_secgroups)
+    def test_get_all(self, mock_get):
         secgroup_list = security_group.SecurityGroupList.get_all(self.context)
         for i in range(len(fake_secgroups)):
             self.assertIsInstance(secgroup_list[i],
@@ -133,13 +157,11 @@ class _TestSecurityGroupListObject(object):
             self.assertEqual(fake_secgroups[i]['id'],
                              secgroup_list[i].id)
             self.assertEqual(secgroup_list[i]._context, self.context)
+            mock_get.assert_called_once_with(self.context)
 
-    def test_get_by_project(self):
-        self.mox.StubOutWithMock(db, 'security_group_get_by_project')
-        db.security_group_get_by_project(self.context,
-                                         'fake-project').AndReturn(
-                                             fake_secgroups)
-        self.mox.ReplayAll()
+    @mock.patch.object(db, 'security_group_get_by_project',
+                       return_value=fake_secgroups)
+    def test_get_by_project(self, mock_get):
         secgroup_list = security_group.SecurityGroupList.get_by_project(
             self.context, 'fake-project')
         for i in range(len(fake_secgroups)):
@@ -147,15 +169,13 @@ class _TestSecurityGroupListObject(object):
                                   security_group.SecurityGroup)
             self.assertEqual(fake_secgroups[i]['id'],
                              secgroup_list[i].id)
+        mock_get.assert_called_once_with(self.context, 'fake-project')
 
-    def test_get_by_instance(self):
+    @mock.patch.object(db, 'security_group_get_by_instance',
+                       return_value=fake_secgroups)
+    def test_get_by_instance(self, mock_get):
         inst = instance.Instance()
         inst.uuid = uuids.instance
-        self.mox.StubOutWithMock(db, 'security_group_get_by_instance')
-        db.security_group_get_by_instance(self.context,
-                                          uuids.instance).AndReturn(
-                                              fake_secgroups)
-        self.mox.ReplayAll()
         secgroup_list = security_group.SecurityGroupList.get_by_instance(
             self.context, inst)
         for i in range(len(fake_secgroups)):
@@ -163,6 +183,7 @@ class _TestSecurityGroupListObject(object):
                                   security_group.SecurityGroup)
             self.assertEqual(fake_secgroups[i]['id'],
                              secgroup_list[i].id)
+        mock_get.assert_called_once_with(self.context, inst.uuid)
 
 
 class TestSecurityGroupListObject(test_objects._LocalTest,
