@@ -14,14 +14,18 @@
 #    under the License.
 
 import mock
+from oslo_config import cfg
 import six
 
 from nova import exception
 from nova import objects
 from nova.objects import fields
 from nova.pci import stats
+from nova.pci import whitelist
 from nova import test
 from nova.tests.unit.pci import fakes
+
+CONF = cfg.CONF
 fake_pci_1 = {
     'compute_node_id': 1,
     'address': '0000:00:00.1',
@@ -68,9 +72,9 @@ class PciDeviceStatsTestCase(test.NoDBTestCase):
         self.fake_dev_3 = objects.PciDevice.create(None, fake_pci_3)
         self.fake_dev_4 = objects.PciDevice.create(None, fake_pci_4)
 
-        map(self.pci_stats.add_device,
-            [self.fake_dev_1, self.fake_dev_2,
-             self.fake_dev_3, self.fake_dev_4])
+        for dev in [self.fake_dev_1, self.fake_dev_2,
+                    self.fake_dev_3, self.fake_dev_4]:
+            self.pci_stats.add_device(dev)
 
     def setUp(self):
         super(PciDeviceStatsTestCase, self).setUp()
@@ -101,17 +105,19 @@ class PciDeviceStatsTestCase(test.NoDBTestCase):
 
     def test_pci_stats_equivalent(self):
         pci_stats2 = stats.PciDeviceStats()
-        map(pci_stats2.add_device, [self.fake_dev_1,
-                                    self.fake_dev_2,
-                                    self.fake_dev_3,
-                                    self.fake_dev_4])
+        for dev in [self.fake_dev_1,
+                    self.fake_dev_2,
+                    self.fake_dev_3,
+                    self.fake_dev_4]:
+            pci_stats2.add_device(dev)
         self.assertEqual(self.pci_stats, pci_stats2)
 
     def test_pci_stats_not_equivalent(self):
         pci_stats2 = stats.PciDeviceStats()
-        map(pci_stats2.add_device, [self.fake_dev_1,
-                                    self.fake_dev_2,
-                                    self.fake_dev_3])
+        for dev in [self.fake_dev_1,
+                    self.fake_dev_2,
+                    self.fake_dev_3]:
+            pci_stats2.add_device(dev)
         self.assertNotEqual(self.pci_stats, pci_stats2)
 
     def test_object_create(self):
@@ -125,15 +131,14 @@ class PciDeviceStatsTestCase(test.NoDBTestCase):
                          set(['v1', 'v2', 'v3']))
 
     def test_support_requests(self):
-        self.assertEqual(self.pci_stats.support_requests(pci_requests),
-                         True)
+        self.assertTrue(self.pci_stats.support_requests(pci_requests))
         self.assertEqual(len(self.pci_stats.pools), 3)
         self.assertEqual(set([d['count'] for d in self.pci_stats]),
                          set((1, 2)))
 
     def test_support_requests_failed(self):
-        self.assertEqual(
-            self.pci_stats.support_requests(pci_requests_multiple), False)
+        self.assertFalse(
+            self.pci_stats.support_requests(pci_requests_multiple))
         self.assertEqual(len(self.pci_stats.pools), 3)
         self.assertEqual(set([d['count'] for d in self.pci_stats]),
                          set([1, 2]))
@@ -164,37 +169,34 @@ class PciDeviceStatsTestCase(test.NoDBTestCase):
                           pci_requests_multiple))
 
     def test_support_requests_numa(self):
-        cells = [objects.NUMACell(id=0, cpuset=set(), memory=0),
-                 objects.NUMACell(id=1, cpuset=set(), memory=0)]
-        self.assertTrue(self.pci_stats.support_requests(
-                                                        pci_requests, cells))
+        cells = [objects.InstanceNUMACell(id=0, cpuset=set(), memory=0),
+                 objects.InstanceNUMACell(id=1, cpuset=set(), memory=0)]
+        self.assertTrue(self.pci_stats.support_requests(pci_requests, cells))
 
     def test_support_requests_numa_failed(self):
-        cells = [objects.NUMACell(id=0, cpuset=set(), memory=0)]
-        self.assertFalse(self.pci_stats.support_requests(
-                                                        pci_requests, cells))
+        cells = [objects.InstanceNUMACell(id=0, cpuset=set(), memory=0)]
+        self.assertFalse(self.pci_stats.support_requests(pci_requests, cells))
 
     def test_support_requests_no_numa_info(self):
-        cells = [objects.NUMACell(id=0, cpuset=set(), memory=0)]
+        cells = [objects.InstanceNUMACell(id=0, cpuset=set(), memory=0)]
         pci_request = [objects.InstancePCIRequest(count=1,
                     spec=[{'vendor_id': 'v3'}])]
-        self.assertTrue(self.pci_stats.support_requests(
-                                                        pci_request, cells))
+        self.assertTrue(self.pci_stats.support_requests(pci_request, cells))
 
     def test_consume_requests_numa(self):
-        cells = [objects.NUMACell(id=0, cpuset=set(), memory=0),
-                 objects.NUMACell(id=1, cpuset=set(), memory=0)]
+        cells = [objects.InstanceNUMACell(id=0, cpuset=set(), memory=0),
+                 objects.InstanceNUMACell(id=1, cpuset=set(), memory=0)]
         devs = self.pci_stats.consume_requests(pci_requests, cells)
         self.assertEqual(2, len(devs))
         self.assertEqual(set(['v1', 'v2']),
                          set([dev.vendor_id for dev in devs]))
 
     def test_consume_requests_numa_failed(self):
-        cells = [objects.NUMACell(id=0, cpuset=set(), memory=0)]
+        cells = [objects.InstanceNUMACell(id=0, cpuset=set(), memory=0)]
         self.assertIsNone(self.pci_stats.consume_requests(pci_requests, cells))
 
     def test_consume_requests_no_numa_info(self):
-        cells = [objects.NUMACell(id=0, cpuset=set(), memory=0)]
+        cells = [objects.InstanceNUMACell(id=0, cpuset=set(), memory=0)]
         pci_request = [objects.InstancePCIRequest(count=1,
                     spec=[{'vendor_id': 'v3'}])]
         devs = self.pci_stats.consume_requests(pci_request, cells)
@@ -202,6 +204,16 @@ class PciDeviceStatsTestCase(test.NoDBTestCase):
         self.assertEqual(set(['v3']),
                          set([dev.vendor_id for dev in devs]))
 
+    @mock.patch(
+        'nova.pci.whitelist.Whitelist._parse_white_list_from_config')
+    def test_white_list_parsing(self, mock_whitelist_parse):
+        white_list = '{"product_id":"0001", "vendor_id":"8086"}'
+        CONF.set_override('passthrough_whitelist', white_list, 'pci')
+        pci_stats = stats.PciDeviceStats()
+        pci_stats.add_device(self.fake_dev_2)
+        pci_stats.remove_device(self.fake_dev_2)
+        self.assertEqual(1, mock_whitelist_parse.call_count)
+
 
 class PciDeviceStatsWithTagsTestCase(test.NoDBTestCase):
 
@@ -210,8 +222,9 @@ class PciDeviceStatsWithTagsTestCase(test.NoDBTestCase):
         white_list = ['{"vendor_id":"1137","product_id":"0071",'
                         '"address":"*:0a:00.*","physical_network":"physnet1"}',
                        '{"vendor_id":"1137","product_id":"0072"}']
-        self.flags(pci_passthrough_whitelist=white_list)
-        self.pci_stats = stats.PciDeviceStats()
+        self.flags(passthrough_whitelist=white_list, group='pci')
+        dev_filter = whitelist.Whitelist(white_list)
+        self.pci_stats = stats.PciDeviceStats(dev_filter=dev_filter)
 
     def _create_pci_devices(self):
         self.pci_tagged_devices = []
@@ -242,8 +255,11 @@ class PciDeviceStatsWithTagsTestCase(test.NoDBTestCase):
             self.pci_untagged_devices.append(objects.PciDevice.create(None,
                                                                       pci_dev))
 
-        map(self.pci_stats.add_device, self.pci_tagged_devices)
-        map(self.pci_stats.add_device, self.pci_untagged_devices)
+        for dev in self.pci_tagged_devices:
+            self.pci_stats.add_device(dev)
+
+        for dev in self.pci_untagged_devices:
+            self.pci_stats.add_device(dev)
 
     def _assertPoolContent(self, pool, vendor_id, product_id, count, **tags):
         self.assertEqual(vendor_id, pool['vendor_id'])
@@ -336,7 +352,7 @@ class PciDeviceVFPFStatsTestCase(test.NoDBTestCase):
         super(PciDeviceVFPFStatsTestCase, self).setUp()
         white_list = ['{"vendor_id":"8086","product_id":"1528"}',
                       '{"vendor_id":"8086","product_id":"1515"}']
-        self.flags(pci_passthrough_whitelist=white_list)
+        self.flags(passthrough_whitelist=white_list, group='pci')
         self.pci_stats = stats.PciDeviceStats()
 
     def _create_pci_devices(self, vf_product_id=1515, pf_product_id=1528):
@@ -351,8 +367,9 @@ class PciDeviceVFPFStatsTestCase(test.NoDBTestCase):
                        'dev_type': fields.PciDeviceType.SRIOV_PF,
                        'parent_addr': None,
                        'numa_node': 0}
-            self.sriov_pf_devices.append(objects.PciDevice.create(None,
-                                                                  pci_dev))
+            dev_obj = objects.PciDevice.create(None, pci_dev)
+            dev_obj.child_devices = []
+            self.sriov_pf_devices.append(dev_obj)
 
         self.sriov_vf_devices = []
         for dev in range(8):
@@ -365,95 +382,66 @@ class PciDeviceVFPFStatsTestCase(test.NoDBTestCase):
                        'dev_type': fields.PciDeviceType.SRIOV_VF,
                        'parent_addr': '0000:81:00.%d' % int(dev / 4),
                        'numa_node': 0}
-            self.sriov_vf_devices.append(objects.PciDevice.create(None,
-                                                                  pci_dev))
+            dev_obj = objects.PciDevice.create(None, pci_dev)
+            dev_obj.parent_device = self.sriov_pf_devices[int(dev / 4)]
+            dev_obj.parent_device.child_devices.append(dev_obj)
+            self.sriov_vf_devices.append(dev_obj)
 
         list(map(self.pci_stats.add_device, self.sriov_pf_devices))
         list(map(self.pci_stats.add_device, self.sriov_vf_devices))
 
-    def _fake_get_by_parent_address(self, ctxt, node_id, addr):
-        vf_devs = []
-        for dev in self.sriov_vf_devices:
-            if dev.parent_addr == addr:
-                vf_devs.append(dev)
-        return vf_devs
-
-    def _fake_pci_device_get_by_addr(self, ctxt, id, addr):
-        for dev in self.sriov_pf_devices:
-            if dev.address == addr:
-                return dev
-
     def test_consume_VF_requests(self):
-        with mock.patch.object(objects.PciDevice, 'get_by_dev_addr',
-                               side_effect=self._fake_pci_device_get_by_addr):
-            self._create_pci_devices()
-            pci_requests = [objects.InstancePCIRequest(count=2,
-                                spec=[{'product_id': '1515'}])]
-            devs = self.pci_stats.consume_requests(pci_requests)
-            self.assertEqual(2, len(devs))
-            self.assertEqual(set(['1515']),
-                             set([dev.product_id for dev in devs]))
-            free_devs = self.pci_stats.get_free_devs()
-            # Validate that the parents of these VFs has been removed
-            # from pools.
-            for dev in devs:
-                self.assertTrue(all(dev.parent_addr != free_dev.address
-                                    for free_dev in free_devs))
+        self._create_pci_devices()
+        pci_requests = [objects.InstancePCIRequest(count=2,
+                            spec=[{'product_id': '1515'}])]
+        devs = self.pci_stats.consume_requests(pci_requests)
+        self.assertEqual(2, len(devs))
+        self.assertEqual(set(['1515']),
+                            set([dev.product_id for dev in devs]))
+        free_devs = self.pci_stats.get_free_devs()
+        # Validate that the parents of these VFs has been removed
+        # from pools.
+        for dev in devs:
+            self.assertNotIn(dev.parent_addr,
+                             [free_dev.address for free_dev in free_devs])
 
     def test_consume_PF_requests(self):
-        with mock.patch.object(objects.PciDeviceList, 'get_by_parent_address',
-                               side_effect=self._fake_get_by_parent_address):
-            self._create_pci_devices()
-            pci_requests = [objects.InstancePCIRequest(count=2,
-                                spec=[{'product_id': '1528',
-                                       'dev_type': 'type-PF'}])]
-            devs = self.pci_stats.consume_requests(pci_requests)
-            self.assertEqual(2, len(devs))
-            self.assertEqual(set(['1528']),
-                             set([dev.product_id for dev in devs]))
-            free_devs = self.pci_stats.get_free_devs()
-            # Validate that there are no free devices left, as when allocating
-            # both available PFs, its VFs should not be available.
-            self.assertEqual(0, len(free_devs))
+        self._create_pci_devices()
+        pci_requests = [objects.InstancePCIRequest(count=2,
+                            spec=[{'product_id': '1528',
+                                    'dev_type': 'type-PF'}])]
+        devs = self.pci_stats.consume_requests(pci_requests)
+        self.assertEqual(2, len(devs))
+        self.assertEqual(set(['1528']),
+                            set([dev.product_id for dev in devs]))
+        free_devs = self.pci_stats.get_free_devs()
+        # Validate that there are no free devices left, as when allocating
+        # both available PFs, its VFs should not be available.
+        self.assertEqual(0, len(free_devs))
 
     def test_consume_VF_and_PF_requests(self):
-        with test.nested(
-            mock.patch.object(objects.PciDevice, 'get_by_dev_addr',
-                               side_effect=self._fake_pci_device_get_by_addr),
-            mock.patch.object(objects.PciDeviceList, 'get_by_parent_address',
-                               side_effect=self._fake_get_by_parent_address)):
-            self._create_pci_devices()
-            pci_requests = [objects.InstancePCIRequest(count=2,
-                                spec=[{'product_id': '1515'}]),
-                            objects.InstancePCIRequest(count=1,
-                                spec=[{'product_id': '1528',
-                                       'dev_type': 'type-PF'}])]
-            devs = self.pci_stats.consume_requests(pci_requests)
-            self.assertEqual(3, len(devs))
-            self.assertEqual(set(['1528', '1515']),
-                             set([dev.product_id for dev in devs]))
+        self._create_pci_devices()
+        pci_requests = [objects.InstancePCIRequest(count=2,
+                            spec=[{'product_id': '1515'}]),
+                        objects.InstancePCIRequest(count=1,
+                            spec=[{'product_id': '1528',
+                                    'dev_type': 'type-PF'}])]
+        devs = self.pci_stats.consume_requests(pci_requests)
+        self.assertEqual(3, len(devs))
+        self.assertEqual(set(['1528', '1515']),
+                            set([dev.product_id for dev in devs]))
 
     def test_consume_VF_and_PF_requests_failed(self):
-        with test.nested(
-            mock.patch.object(objects.PciDevice, 'get_by_dev_addr',
-                               side_effect=self._fake_pci_device_get_by_addr),
-            mock.patch.object(objects.PciDeviceList, 'get_by_parent_address',
-                               side_effect=self._fake_get_by_parent_address)):
-            self._create_pci_devices()
-            pci_requests = [objects.InstancePCIRequest(count=5,
-                                spec=[{'product_id': '1515'}]),
-                            objects.InstancePCIRequest(count=1,
-                                spec=[{'product_id': '1528',
-                                       'dev_type': 'type-PF'}])]
-            self.assertIsNone(self.pci_stats.consume_requests(pci_requests))
+        self._create_pci_devices()
+        pci_requests = [objects.InstancePCIRequest(count=5,
+                            spec=[{'product_id': '1515'}]),
+                        objects.InstancePCIRequest(count=1,
+                            spec=[{'product_id': '1528',
+                                    'dev_type': 'type-PF'}])]
+        self.assertIsNone(self.pci_stats.consume_requests(pci_requests))
 
     def test_consume_VF_and_PF_same_prodict_id_failed(self):
-        with test.nested(
-            mock.patch.object(objects.PciDevice, 'get_by_dev_addr',
-                               side_effect=self._fake_pci_device_get_by_addr),
-            mock.patch.object(objects.PciDeviceList, 'get_by_parent_address',
-                               side_effect=self._fake_get_by_parent_address)):
-            self._create_pci_devices(pf_product_id=1515)
-            pci_requests = [objects.InstancePCIRequest(count=9,
-                                spec=[{'product_id': '1515'}])]
-            self.assertIsNone(self.pci_stats.consume_requests(pci_requests))
+        self._create_pci_devices(pf_product_id=1515)
+        pci_requests = [objects.InstancePCIRequest(count=9,
+                            spec=[{'product_id': '1515'}])]
+        self.assertIsNone(self.pci_stats.consume_requests(pci_requests))
