@@ -22,56 +22,8 @@ from nova.objects import base as obj_base
 from nova import test
 
 
-DEFAULT_FLAVORS = [
-    {'memory_mb': 512, 'root_gb': 1, 'deleted_at': None, 'name': 'm1.tiny',
-     'deleted': 0, 'created_at': None, 'ephemeral_gb': 0, 'updated_at': None,
-     'disabled': False, 'vcpus': 1, 'extra_specs': {}, 'swap': 0,
-     'rxtx_factor': 1.0, 'is_public': True, 'flavorid': '1',
-     'vcpu_weight': None, 'id': 2},
-    {'memory_mb': 2048, 'root_gb': 20, 'deleted_at': None, 'name': 'm1.small',
-     'deleted': 0, 'created_at': None, 'ephemeral_gb': 0, 'updated_at': None,
-     'disabled': False, 'vcpus': 1, 'extra_specs': {}, 'swap': 0,
-     'rxtx_factor': 1.0, 'is_public': True, 'flavorid': '2',
-     'vcpu_weight': None, 'id': 5},
-    {'memory_mb': 4096, 'root_gb': 40, 'deleted_at': None, 'name': 'm1.medium',
-     'deleted': 0, 'created_at': None, 'ephemeral_gb': 0, 'updated_at': None,
-     'disabled': False, 'vcpus': 2, 'extra_specs': {}, 'swap': 0,
-     'rxtx_factor': 1.0, 'is_public': True, 'flavorid': '3',
-     'vcpu_weight': None, 'id': 1},
-    {'memory_mb': 8192, 'root_gb': 80, 'deleted_at': None, 'name': 'm1.large',
-     'deleted': 0, 'created_at': None, 'ephemeral_gb': 0, 'updated_at': None,
-     'disabled': False, 'vcpus': 4, 'extra_specs': {}, 'swap': 0,
-     'rxtx_factor': 1.0, 'is_public': True, 'flavorid': '4',
-     'vcpu_weight': None, 'id': 3},
-    {'memory_mb': 16384, 'root_gb': 160, 'deleted_at': None,
-     'name': 'm1.xlarge', 'deleted': 0, 'created_at': None, 'ephemeral_gb': 0,
-     'updated_at': None, 'disabled': False, 'vcpus': 8, 'extra_specs': {},
-     'swap': 0, 'rxtx_factor': 1.0, 'is_public': True, 'flavorid': '5',
-     'vcpu_weight': None, 'id': 4}
-]
-
-CONTEXT = context.RequestContext('fake', 'fake', is_admin=False)
-
-DEFAULT_FLAVOR_OBJS = [
-    objects.Flavor._obj_from_primitive(CONTEXT, objects.Flavor.VERSION,
-                                       {'nova_object.data': flavor})
-    for flavor in DEFAULT_FLAVORS
-]
-
-
 class InstanceTypeTestCase(test.TestCase):
     """Test cases for flavor  code."""
-    def test_non_existent_inst_type_should_not_delete(self):
-        # Ensures that flavor creation fails with invalid args.
-        self.assertRaises(exception.FlavorNotFoundByName,
-                          flavors.destroy,
-                          'unknown_flavor')
-
-    def test_will_not_destroy_with_no_name(self):
-        # Ensure destroy said path of no name raises error.
-        self.assertRaises(exception.FlavorNotFoundByName,
-                          flavors.destroy, None)
-
     def test_will_not_get_bad_default_instance_type(self):
         # ensures error raised on bad default flavor.
         self.flags(default_flavor='unknown_flavor')
@@ -104,74 +56,6 @@ class InstanceTypeTestCase(test.TestCase):
         self.assertIsInstance(fetched, objects.Flavor)
         self.assertEqual(default_instance_type.flavorid, fetched.flavorid)
 
-    def test_can_read_deleted_types_using_flavor_id(self):
-        # Ensure deleted flavors can be read when querying flavor_id.
-        inst_type_name = "test"
-        inst_type_flavor_id = "test1"
-
-        inst_type = flavors.create(inst_type_name, 256, 1, 120, 100,
-                inst_type_flavor_id)
-        self.assertEqual(inst_type_name, inst_type.name)
-
-        # NOTE(jk0): The deleted flavor will show up here because the context
-        # in get_flavor_by_flavor_id() is set to use read_deleted by
-        # default.
-        flavors.destroy(inst_type.name)
-        deleted_inst_type = flavors.get_flavor_by_flavor_id(
-                inst_type_flavor_id)
-        self.assertEqual(inst_type_name, deleted_inst_type.name)
-
-    def test_read_deleted_false_converting_flavorid(self):
-        """Ensure deleted flavors are not returned when not needed (for
-        example when creating a server and attempting to translate from
-        flavorid to instance_type_id.
-        """
-        flavors.create("instance_type1", 256, 1, 120, 100, "test1")
-        flavors.destroy("instance_type1")
-        flavors.create("instance_type1_redo", 256, 1, 120, 100, "test1")
-
-        instance_type = flavors.get_flavor_by_flavor_id(
-                "test1", read_deleted="no")
-        self.assertEqual("instance_type1_redo", instance_type.name)
-
-    def test_get_all_flavors_sorted_list_sort(self):
-        # Test default sort
-        all_flavors = flavors.get_all_flavors_sorted_list()
-        self.assertEqual(len(DEFAULT_FLAVORS), len(all_flavors))
-        for i in range(len(all_flavors)):
-            f = all_flavors[i]
-            self.assertIsInstance(f, objects.Flavor)
-            self.assertEqual(DEFAULT_FLAVORS[i]['flavorid'], f.flavorid)
-
-        # Test sorted by name
-        all_flavors = flavors.get_all_flavors_sorted_list(sort_key='name')
-        expected = sorted(DEFAULT_FLAVORS, key=lambda item: item['name'])
-        self.assertEqual(len(expected), len(all_flavors))
-        for i in range(len(all_flavors)):
-            f = all_flavors[i]
-            self.assertIsInstance(f, objects.Flavor)
-            self.assertEqual(expected[i]['flavorid'], f.flavorid)
-
-    def test_get_all_flavors_sorted_list_limit(self):
-        limited_flavors = flavors.get_all_flavors_sorted_list(limit=2)
-        self.assertEqual(2, len(limited_flavors))
-
-    def test_get_all_flavors_sorted_list_marker(self):
-        all_flavors = flavors.get_all_flavors_sorted_list()
-
-        # Set the 3rd result as the marker
-        marker_flavorid = all_flavors[2].flavorid
-        marked_flavors = flavors.get_all_flavors_sorted_list(
-            marker=marker_flavorid)
-        # We expect everything /after/ the 3rd result
-        expected_results = all_flavors[3:]
-        self.assertEqual(len(expected_results), len(marked_flavors))
-        for i in range(len(marked_flavors)):
-            f = marked_flavors[i]
-            self.assertIsInstance(f, objects.Flavor)
-            self.assertEqual(expected_results[i].flavorid,
-                             f.flavorid)
-
 
 class InstanceTypeToolsTest(test.TestCase):
     def _dict_to_metadata(self, data):
@@ -262,9 +146,9 @@ class InstanceTypeFilteringTest(test.TestCase):
         self.context = context.get_admin_context()
 
     def assertFilterResults(self, filters, expected):
-        inst_types = db.flavor_get_all(
+        inst_types = objects.FlavorList.get_all(
                 self.context, filters=filters)
-        inst_names = [i['name'] for i in inst_types]
+        inst_names = [i.name for i in inst_types]
         self.assertEqual(inst_names, expected)
 
     def test_no_filters(self):
@@ -394,14 +278,14 @@ class CreateInstanceTypeTest(test.TestCase):
         db.flavor_get_all(_context)
         # We do * 10 since this is an approximation and we need to make sure
         # the difference is noticeble.
-        over_rxtx_factor = flavors.SQL_SP_FLOAT_MAX * 10
+        over_rxtx_factor = db.SQL_SP_FLOAT_MAX * 10
 
         self.assertInvalidInput('flavor1', 64, 1, 120,
                                 rxtx_factor=over_rxtx_factor)
 
         flavor = flavors.create('flavor2', 64, 1, 120,
-                                rxtx_factor=flavors.SQL_SP_FLOAT_MAX)
-        self.assertEqual(flavors.SQL_SP_FLOAT_MAX, flavor.rxtx_factor)
+                                rxtx_factor=db.SQL_SP_FLOAT_MAX)
+        self.assertEqual(db.SQL_SP_FLOAT_MAX, flavor.rxtx_factor)
 
     def test_is_public_must_be_valid_bool_string(self):
         self.assertInvalidInput('flavor1', 64, 1, 120, is_public='foo')
@@ -418,10 +302,10 @@ class CreateInstanceTypeTest(test.TestCase):
 
     def test_flavorid_populated(self):
         flavor1 = flavors.create('flavor1', 64, 1, 120)
-        self.assertIsNot(None, flavor1.flavorid)
+        self.assertIsNotNone(flavor1.flavorid)
 
         flavor2 = flavors.create('flavor2', 64, 1, 120, flavorid='')
-        self.assertIsNot(None, flavor2.flavorid)
+        self.assertIsNotNone(flavor2.flavorid)
 
         flavor3 = flavors.create('flavor3', 64, 1, 120, flavorid='foo')
         self.assertEqual('foo', flavor3.flavorid)
@@ -429,7 +313,7 @@ class CreateInstanceTypeTest(test.TestCase):
     def test_default_values(self):
         flavor1 = flavors.create('flavor1', 64, 1, 120)
 
-        self.assertIsNot(None, flavor1.flavorid)
+        self.assertIsNotNone(flavor1.flavorid)
         self.assertEqual(flavor1.ephemeral_gb, 0)
         self.assertEqual(flavor1.swap, 0)
         self.assertEqual(flavor1.rxtx_factor, 1.0)
@@ -462,9 +346,9 @@ class CreateInstanceTypeTest(test.TestCase):
         self.assertNotEqual(len(original_list), len(new_list),
                             'instance type was not created')
 
-        flavors.destroy('flavor')
+        flavor.destroy()
         self.assertRaises(exception.FlavorNotFound,
-                          objects.Flavor.get_by_id, ctxt, flavor.id)
+                          objects.Flavor.get_by_name, ctxt, flavor.name)
 
         # Deleted instance should not be in list anymore
         new_list = objects.FlavorList.get_all(ctxt)
@@ -474,14 +358,14 @@ class CreateInstanceTypeTest(test.TestCase):
             self.assertEqual(f.flavorid, new_list[i].flavorid)
 
     def test_duplicate_names_fail(self):
-        # Ensures that name duplicates raise FlavorCreateFailed.
+        # Ensures that name duplicates raise FlavorExists
         flavors.create('flavor', 256, 1, 120, 200, 'flavor1')
         self.assertRaises(exception.FlavorExists,
                           flavors.create,
                           'flavor', 64, 1, 120)
 
     def test_duplicate_flavorids_fail(self):
-        # Ensures that flavorid duplicates raise FlavorCreateFailed.
+        # Ensures that flavorid duplicates raise FlavorExists
         flavors.create('flavor1', 64, 1, 120, flavorid='flavorid')
         self.assertRaises(exception.FlavorIdExists,
                           flavors.create,
