@@ -37,9 +37,6 @@ from nova.tests.unit import utils
 from nova import wsgi
 
 test_service_opts = [
-    cfg.StrOpt("fake_manager",
-               default="nova.tests.unit.test_service.FakeManager",
-               help="Manager for testing"),
     cfg.StrOpt("test_service_listen",
                default='127.0.0.1',
                help="Host to bind test service to"),
@@ -98,17 +95,28 @@ class ServiceTestCase(test.NoDBTestCase):
         self.host = 'foo'
         self.binary = 'nova-fake'
         self.topic = 'fake'
-        self.flags(use_local=True, group='conductor')
 
     def test_create(self):
 
         # NOTE(vish): Create was moved out of mox replay to make sure that
         #             the looping calls are created in StartService.
         app = service.Service.create(host=self.host, binary=self.binary,
-                topic=self.topic)
+                topic=self.topic,
+                manager='nova.tests.unit.test_service.FakeManager')
 
         self.assertTrue(app)
 
+    def test_repr(self):
+        # Test if a Service object is correctly represented, for example in
+        # log files.
+        serv = service.Service(self.host,
+                               self.binary,
+                               self.topic,
+                               'nova.tests.unit.test_service.FakeManager')
+        exp = "<Service: host=foo, binary=nova-fake, " \
+              "manager_class_name=nova.tests.unit.test_service.FakeManager>"
+        self.assertEqual(exp, repr(serv))
+
     def _service_start_mocks(self):
         self.mox.StubOutWithMock(objects.Service, 'create')
         self.mox.StubOutWithMock(objects.Service, 'get_by_host_and_binary')
@@ -160,7 +168,7 @@ class ServiceTestCase(test.NoDBTestCase):
         serv.start()
 
         # test service version got updated and saved:
-        service_obj.save.assert_called_once_with()
+        self.assertEqual(1, service_obj.save.call_count)
         self.assertEqual(objects.service.SERVICE_VERSION, service_obj.version)
 
     def _test_service_check_create_race(self, ex):
@@ -322,17 +330,6 @@ class TestWSGIService(test.NoDBTestCase):
         test_service = service.WSGIService("osapi_compute")
         self.assertEqual(test_service.workers, 8)
 
-    def test_workers_set_zero_user_setting(self):
-        CONF.set_override('osapi_compute_workers', 0)
-        test_service = service.WSGIService("osapi_compute")
-        # If a value less than 1 is used, defaults to number of procs available
-        self.assertEqual(test_service.workers, processutils.get_worker_count())
-
-    def test_service_start_with_illegal_workers(self):
-        CONF.set_override("osapi_compute_workers", -1)
-        self.assertRaises(exception.InvalidInput,
-                          service.WSGIService, "osapi_compute")
-
     def test_openstack_compute_api_workers_set_default(self):
         test_service = service.WSGIService("openstack_compute_api_v2")
         self.assertEqual(test_service.workers, processutils.get_worker_count())
@@ -342,17 +339,6 @@ class TestWSGIService(test.NoDBTestCase):
         test_service = service.WSGIService("openstack_compute_api_v2")
         self.assertEqual(test_service.workers, 8)
 
-    def test_openstack_compute_api_workers_set_zero_user_setting(self):
-        CONF.set_override('osapi_compute_workers', 0)
-        test_service = service.WSGIService("openstack_compute_api_v2")
-        # If a value less than 1 is used, defaults to number of procs available
-        self.assertEqual(test_service.workers, processutils.get_worker_count())
-
-    def test_openstack_compute_api_service_start_with_illegal_workers(self):
-        CONF.set_override("osapi_compute_workers", -1)
-        self.assertRaises(exception.InvalidInput,
-                          service.WSGIService, "openstack_compute_api_v2")
-
     @testtools.skipIf(not utils.is_ipv6_supported(), "no ipv6 support")
     @mock.patch('nova.objects.Service.get_by_host_and_binary')
     def test_service_random_port_with_ipv6(self, mock_get):
@@ -376,7 +362,7 @@ class TestWSGIService(test.NoDBTestCase):
         test_service.reset()
         test_service.start()
         self.assertEqual(test_service.server._pool.size,
-                         CONF.wsgi_default_pool_size)
+                         CONF.wsgi.default_pool_size)
 
 
 class TestLauncher(test.NoDBTestCase):
