@@ -1019,12 +1019,13 @@ class Connection(object):
                 self.host_info.cpu_cores,
                 self.host_info.cpu_threads]
 
-    def lookupByName(self, name):
-        if name in self._vms:
-            return self._vms[name]
+    def lookupByUUIDString(self, uuid):
+        for vm in self._vms.values():
+            if vm.UUIDString() == uuid:
+                return vm
         raise make_libvirtError(
                 libvirtError,
-                'Domain not found: no domain with matching name "%s"' % name,
+                'Domain not found: no domain with matching uuid "%s"' % uuid,
                 error_code=VIR_ERR_NO_DOMAIN,
                 error_domain=VIR_FROM_QEMU)
 
