@@ -15,7 +15,7 @@ import platform
 import mock
 from os_brick.initiator import connector
 
-from nova.compute import arch
+from nova.objects import fields as obj_fields
 from nova.tests.unit.virt.libvirt.volume import test_volume
 from nova.virt.libvirt.volume import fibrechannel
 
@@ -25,27 +25,29 @@ class LibvirtFibreChannelVolumeDriverTestCase(
 
     def test_libvirt_fibrechan_driver(self):
         libvirt_driver = fibrechannel.LibvirtFibreChannelVolumeDriver(
-                                                                self.fake_conn)
+                                                                self.fake_host)
         self.assertIsInstance(libvirt_driver.connector,
                               connector.FibreChannelConnector)
 
     def _test_libvirt_fibrechan_driver_s390(self):
         libvirt_driver = fibrechannel.LibvirtFibreChannelVolumeDriver(
-                                                                self.fake_conn)
+                                                                self.fake_host)
         self.assertIsInstance(libvirt_driver.connector,
                               connector.FibreChannelConnectorS390X)
 
-    @mock.patch.object(platform, 'machine', return_value=arch.S390)
+    @mock.patch.object(platform, 'machine',
+                       return_value=obj_fields.Architecture.S390)
     def test_libvirt_fibrechan_driver_s390(self, mock_machine):
         self._test_libvirt_fibrechan_driver_s390()
 
-    @mock.patch.object(platform, 'machine', return_value=arch.S390X)
+    @mock.patch.object(platform, 'machine',
+                       return_value=obj_fields.Architecture.S390X)
     def test_libvirt_fibrechan_driver_s390x(self, mock_machine):
         self._test_libvirt_fibrechan_driver_s390()
 
     def test_libvirt_fibrechan_driver_get_config(self):
         libvirt_driver = fibrechannel.LibvirtFibreChannelVolumeDriver(
-                                                                self.fake_conn)
+                                                                self.fake_host)
 
         device_path = '/dev/fake-dev'
         connection_info = {'data': {'device_path': device_path}}
