@@ -18,7 +18,6 @@ import mock
 from nova import exception
 from nova import test
 from nova.tests.unit.virt.libvirt import fakelibvirt
-from nova import utils
 from nova.virt.libvirt import host
 from nova.virt.libvirt.volume import volume
 
@@ -59,18 +58,12 @@ class LibvirtVolumeBaseTestCase(test.NoDBTestCase):
             self.executes.append(cmd)
             return None, None
 
-        self.stubs.Set(utils, 'execute', fake_execute)
+        self.stub_out('nova.utils.execute', fake_execute)
 
         self.useFixture(fakelibvirt.FakeLibvirtFixture())
 
-        class FakeLibvirtDriver(object):
-            def __init__(self):
-                self._host = host.Host("qemu:///system")
+        self.fake_host = host.Host("qemu:///system")
 
-            def _get_all_block_devices(self):
-                return []
-
-        self.fake_conn = FakeLibvirtDriver()
         self.connr = {
             'ip': '127.0.0.1',
             'initiator': 'fake_initiator',
@@ -131,7 +124,7 @@ class LibvirtVolumeTestCase(LibvirtISCSIVolumeBaseTestCase):
         self.assertEqual(disk_info['dev'], tree.find('./target').get('dev'))
 
     def _test_libvirt_volume_driver_disk_info(self):
-        libvirt_driver = volume.LibvirtVolumeDriver(self.fake_conn)
+        libvirt_driver = volume.LibvirtVolumeDriver(self.fake_host)
         connection_info = {
             'driver_volume_type': 'fake',
             'data': {
@@ -156,7 +149,7 @@ class LibvirtVolumeTestCase(LibvirtISCSIVolumeBaseTestCase):
         self._test_libvirt_volume_driver_disk_info()
 
     def test_libvirt_volume_driver_serial(self):
-        libvirt_driver = volume.LibvirtVolumeDriver(self.fake_conn)
+        libvirt_driver = volume.LibvirtVolumeDriver(self.fake_host)
         connection_info = {
             'driver_volume_type': 'fake',
             'data': {
@@ -172,7 +165,7 @@ class LibvirtVolumeTestCase(LibvirtISCSIVolumeBaseTestCase):
         self.assertIsNone(tree.find("driver[@discard]"))
 
     def test_libvirt_volume_driver_blockio(self):
-        libvirt_driver = volume.LibvirtVolumeDriver(self.fake_conn)
+        libvirt_driver = volume.LibvirtVolumeDriver(self.fake_host)
         connection_info = {
             'driver_volume_type': 'fake',
             'data': {
@@ -194,7 +187,7 @@ class LibvirtVolumeTestCase(LibvirtISCSIVolumeBaseTestCase):
         self.assertEqual('4096', blockio.get('physical_block_size'))
 
     def test_libvirt_volume_driver_iotune(self):
-        libvirt_driver = volume.LibvirtVolumeDriver(self.fake_conn)
+        libvirt_driver = volume.LibvirtVolumeDriver(self.fake_host)
         connection_info = {
             'driver_volume_type': 'fake',
             'data': {
@@ -233,7 +226,7 @@ class LibvirtVolumeTestCase(LibvirtISCSIVolumeBaseTestCase):
         self.assertEqual('200', tree.find('./iotune/write_iops_sec').text)
 
     def test_libvirt_volume_driver_readonly(self):
-        libvirt_driver = volume.LibvirtVolumeDriver(self.fake_conn)
+        libvirt_driver = volume.LibvirtVolumeDriver(self.fake_host)
         connection_info = {
             'driver_volume_type': 'fake',
             'data': {
@@ -266,7 +259,7 @@ class LibvirtVolumeTestCase(LibvirtISCSIVolumeBaseTestCase):
     def test_libvirt_volume_driver_discard_true(self, mock_has_min_version):
         # Check the discard attrib is present in driver section
         mock_has_min_version.return_value = True
-        libvirt_driver = volume.LibvirtVolumeDriver(self.fake_conn)
+        libvirt_driver = volume.LibvirtVolumeDriver(self.fake_host)
         connection_info = {
             'driver_volume_type': 'fake',
             'data': {
@@ -284,7 +277,7 @@ class LibvirtVolumeTestCase(LibvirtISCSIVolumeBaseTestCase):
 
     def test_libvirt_volume_driver_discard_false(self):
         # Check the discard attrib is not present in driver section
-        libvirt_driver = volume.LibvirtVolumeDriver(self.fake_conn)
+        libvirt_driver = volume.LibvirtVolumeDriver(self.fake_host)
         connection_info = {
             'driver_volume_type': 'fake',
             'data': {
@@ -303,7 +296,7 @@ class LibvirtVolumeTestCase(LibvirtISCSIVolumeBaseTestCase):
             self, mock_has_min_version):
         # Check the discard attrib is not present in driver section
         mock_has_min_version.return_value = False
-        libvirt_driver = volume.LibvirtVolumeDriver(self.fake_conn)
+        libvirt_driver = volume.LibvirtVolumeDriver(self.fake_host)
         connection_info = {
             'driver_volume_type': 'fake',
             'data': {
