@@ -1344,15 +1344,18 @@ class XenstoreCallsTestCase(VMOpsTestBase):
 
 class LiveMigrateTestCase(VMOpsTestBase):
 
+    @mock.patch.object(vmops.VMOps, '_get_network_ref')
     @mock.patch.object(vmops.VMOps, '_ensure_host_in_aggregate')
     def _test_check_can_live_migrate_destination_shared_storage(
                                                 self,
                                                 shared,
-                                                mock_ensure_host):
+                                                mock_ensure_host,
+                                                mock_net_ref):
         fake_instance = {"name": "fake_instance", "host": "fake_host"}
         block_migration = None
         disk_over_commit = False
         ctxt = 'ctxt'
+        mock_net_ref.return_value = 'fake_net_ref'
 
         with mock.patch.object(self._session, 'get_rec') as fake_sr_rec:
             fake_sr_rec.return_value = {'shared': shared}
@@ -1363,6 +1366,8 @@ class LiveMigrateTestCase(VMOpsTestBase):
             self.assertFalse(migrate_data_ret.block_migration)
         else:
             self.assertTrue(migrate_data_ret.block_migration)
+        self.assertEqual({'': 'fake_net_ref'},
+                         migrate_data_ret.vif_uuid_map)
 
     def test_check_can_live_migrate_destination_shared_storage(self):
         self._test_check_can_live_migrate_destination_shared_storage(True)
@@ -1370,15 +1375,18 @@ class LiveMigrateTestCase(VMOpsTestBase):
     def test_check_can_live_migrate_destination_shared_storage_false(self):
         self._test_check_can_live_migrate_destination_shared_storage(False)
 
+    @mock.patch.object(vmops.VMOps, '_get_network_ref')
     @mock.patch.object(vmops.VMOps, '_ensure_host_in_aggregate',
                        side_effect=exception.MigrationPreCheckError(reason=""))
     def test_check_can_live_migrate_destination_block_migration(
                                                 self,
-                                                mock_ensure_host):
+                                                mock_ensure_host,
+                                                mock_net_ref):
         fake_instance = {"name": "fake_instance", "host": "fake_host"}
         block_migration = None
         disk_over_commit = False
         ctxt = 'ctxt'
+        mock_net_ref.return_value = 'fake_net_ref'
 
         migrate_data_ret = self.vmops.check_can_live_migrate_destination(
             ctxt, fake_instance, block_migration, disk_over_commit)
@@ -1388,6 +1396,8 @@ class LiveMigrateTestCase(VMOpsTestBase):
                          migrate_data_ret.destination_sr_ref)
         self.assertEqual({'value': 'fake_migrate_data'},
                          migrate_data_ret.migrate_send_data)
+        self.assertEqual({'': 'fake_net_ref'},
+                         migrate_data_ret.vif_uuid_map)
 
     @mock.patch.object(vmops.objects.AggregateList, 'get_by_host')
     def test_get_host_uuid_from_aggregate_no_aggr(self, mock_get_by_host):
@@ -1641,6 +1651,20 @@ class LiveMigrateHelperTestCase(VMOpsTestBase):
                         'vif_ref2': 'dest_net_ref2'}
             self.assertEqual(vif_map, expected)
 
+    def test_generate_vif_network_map_default_net(self):
+        with mock.patch.object(self._session.VIF,
+                               'get_other_config') as mock_other_config, \
+             mock.patch.object(self._session.VM,
+                              'get_VIFs') as mock_get_vif:
+            mock_other_config.side_effect = [{'nicira-iface-id': 'vif_id_a'},
+                                             {'nicira-iface-id': 'vif_id_b'}]
+            mock_get_vif.return_value = ['vif_ref1']
+            vif_uuid_map = {'': 'default_net_ref'}
+            vif_map = self.vmops._generate_vif_network_map('vm_ref',
+                                                           vif_uuid_map)
+            expected = {'vif_ref1': 'default_net_ref'}
+            self.assertEqual(vif_map, expected)
+
     def test_generate_vif_network_map_exception(self):
         with mock.patch.object(self._session.VIF,
                                'get_other_config') as mock_other_config, \
