@@ -1,5 +1,3 @@
-# coding=utf-8
-#
 # Copyright 2014 Hewlett-Packard Development Company, L.P.
 # Copyright 2014 Red Hat, Inc.
 # All Rights Reserved.
@@ -21,7 +19,7 @@ Helper classes for Ironic HTTP PATCH creation.
 """
 
 from oslo_serialization import jsonutils
-import six
+
 
 import nova.conf
 
@@ -58,22 +56,24 @@ class GenericDriverFields(object):
         patch.append({'path': '/instance_info/image_source', 'op': 'add',
                       'value': image_meta.id})
         patch.append({'path': '/instance_info/root_gb', 'op': 'add',
-                      'value': str(instance.root_gb)})
+                      'value': str(instance.flavor.root_gb)})
         patch.append({'path': '/instance_info/swap_mb', 'op': 'add',
                       'value': str(flavor['swap'])})
         patch.append({'path': '/instance_info/display_name',
                       'op': 'add', 'value': instance.display_name})
         patch.append({'path': '/instance_info/vcpus', 'op': 'add',
-                      'value': str(instance.vcpus)})
+                      'value': str(instance.flavor.vcpus)})
+        patch.append({'path': '/instance_info/nova_host_id', 'op': 'add',
+                      'value': instance.get('host')})
         patch.append({'path': '/instance_info/memory_mb', 'op': 'add',
-                      'value': str(instance.memory_mb)})
+                      'value': str(instance.flavor.memory_mb)})
         patch.append({'path': '/instance_info/local_gb', 'op': 'add',
                       'value': str(self.node.properties.get('local_gb', 0))})
 
-        if instance.ephemeral_gb:
+        if instance.flavor.ephemeral_gb:
             patch.append({'path': '/instance_info/ephemeral_gb',
                           'op': 'add',
-                          'value': str(instance.ephemeral_gb)})
+                          'value': str(instance.flavor.ephemeral_gb)})
             if CONF.default_ephemeral_format:
                 patch.append({'path': '/instance_info/ephemeral_format',
                               'op': 'add',
@@ -91,7 +91,7 @@ class GenericDriverFields(object):
         # scan through the extra_specs values and ignore the keys
         # not starting with keyword 'capabilities'.
 
-        for key, val in six.iteritems(extra_specs):
+        for key, val in extra_specs.items():
             if not key.startswith('capabilities:'):
                 continue
 
