@@ -14,22 +14,20 @@
 #    under the License.
 
 from os_brick.initiator import connector
-from oslo_config import cfg
 
+import nova.conf
 from nova import utils
 from nova.virt.libvirt.volume import volume as libvirt_volume
 
 
-CONF = cfg.CONF
-CONF.import_opt('num_iscsi_scan_tries', 'nova.virt.libvirt.volume.iscsi',
-                group='libvirt')
+CONF = nova.conf.CONF
 
 
 class LibvirtHGSTVolumeDriver(libvirt_volume.LibvirtBaseVolumeDriver):
     """Driver to attach HGST volumes to libvirt."""
-    def __init__(self, connection):
+    def __init__(self, host):
         super(LibvirtHGSTVolumeDriver,
-              self).__init__(connection, is_block_dev=True)
+              self).__init__(host, is_block_dev=True)
         self.connector = connector.InitiatorConnector.factory(
             'HGST', utils.get_root_helper(),
             device_scan_attempts=CONF.libvirt.num_iscsi_scan_tries)
