@@ -51,29 +51,41 @@ A fake XenAPI SDK.
 import base64
 import pickle
 import random
-import uuid
 from xml.sax import saxutils
 import zlib
 
+from os_xenapi.client import session as xenapi_session
+from os_xenapi.client import XenAPI
 from oslo_log import log as logging
 from oslo_serialization import jsonutils
 from oslo_utils import timeutils
 from oslo_utils import units
-import six
+from oslo_utils import uuidutils
+
 
 from nova import exception
 from nova.i18n import _
-from nova.virt.xenapi.client import session as xenapi_session
 
 
 _CLASSES = ['host', 'network', 'session', 'pool', 'SR', 'VBD',
             'PBD', 'VDI', 'VIF', 'PIF', 'VM', 'VLAN', 'task']
+_after_create_functions = {}
+_destroy_functions = {}
 
 _db_content = {}
 
 LOG = logging.getLogger(__name__)
 
 
+def add_to_dict(functions):
+    """A decorator that adds a function to dictionary."""
+
+    def decorator(func):
+        functions[func.__name__] = func
+        return func
+    return decorator
+
+
 def reset():
     for c in _CLASSES:
         _db_content[c] = {}
@@ -81,7 +93,8 @@ def reset():
     create_vm('fake dom 0',
               'Running',
               is_a_template=False,
-              is_control_domain=True)
+              is_control_domain=True,
+              domid='0')
 
 
 def reset_table(table):
@@ -119,23 +132,24 @@ def create_network(name_label, bridge):
 
 def create_vm(name_label, status, **kwargs):
     if status == 'Running':
-        domid = random.randrange(1, 1 << 16)
+        domid = "%d" % random.randrange(1, 1 << 16)
         resident_on = list(_db_content['host'])[0]
     else:
-        domid = -1
+        domid = "-1"
         resident_on = ''
 
-    vm_rec = kwargs.copy()
-    vm_rec.update({'name_label': name_label,
-                   'domid': domid,
-                   'power_state': status,
-                   'blocked_operations': {},
-                   'resident_on': resident_on})
+    vm_rec = {'name_label': name_label,
+              'domid': domid,
+              'power_state': status,
+              'blocked_operations': {},
+              'resident_on': resident_on}
+    vm_rec.update(kwargs.copy())
     vm_ref = _create_object('VM', vm_rec)
     after_VM_create(vm_ref, vm_rec)
     return vm_ref
 
 
+@add_to_dict(_destroy_functions)
 def destroy_vm(vm_ref):
     vm_rec = _db_content['VM'][vm_ref]
 
@@ -148,6 +162,7 @@ def destroy_vm(vm_ref):
     del _db_content['VM'][vm_ref]
 
 
+@add_to_dict(_destroy_functions)
 def destroy_vbd(vbd_ref):
     vbd_rec = _db_content['VBD'][vbd_ref]
 
@@ -162,6 +177,7 @@ def destroy_vbd(vbd_ref):
     del _db_content['VBD'][vbd_ref]
 
 
+@add_to_dict(_destroy_functions)
 def destroy_vdi(vdi_ref):
     vdi_rec = _db_content['VDI'][vdi_ref]
 
@@ -195,6 +211,7 @@ def create_vdi(name_label, sr_ref, **kwargs):
     return vdi_ref
 
 
+@add_to_dict(_after_create_functions)
 def after_VDI_create(vdi_ref, vdi_rec):
     vdi_rec.setdefault('VBDs', [])
 
@@ -213,6 +230,7 @@ def create_vbd(vm_ref, vdi_ref, userdevice=0, other_config=None):
     return vbd_ref
 
 
+@add_to_dict(_after_create_functions)
 def after_VBD_create(vbd_ref, vbd_rec):
     """Create read-only fields and backref from VM and VDI to VBD when VBD
     is created.
@@ -234,6 +252,7 @@ def after_VBD_create(vbd_ref, vbd_rec):
         vdi_rec['VBDs'].append(vbd_ref)
 
 
+@add_to_dict(_after_create_functions)
 def after_VIF_create(vif_ref, vif_rec):
     """Create backref from VM to VIF when VIF is created.
     """
@@ -242,9 +261,10 @@ def after_VIF_create(vif_ref, vif_rec):
     vm_rec['VIFs'].append(vif_ref)
 
 
+@add_to_dict(_after_create_functions)
 def after_VM_create(vm_ref, vm_rec):
     """Create read-only fields in the VM record."""
-    vm_rec.setdefault('domid', -1)
+    vm_rec.setdefault('domid', "-1")
     vm_rec.setdefault('is_control_domain', False)
     vm_rec.setdefault('is_a_template', False)
     vm_rec.setdefault('memory_static_max', str(8 * units.Gi))
@@ -331,8 +351,8 @@ def _create_local_pif(host_ref):
 
 
 def _create_object(table, obj):
-    ref = str(uuid.uuid4())
-    obj['uuid'] = str(uuid.uuid4())
+    ref = uuidutils.generate_uuid()
+    obj['uuid'] = uuidutils.generate_uuid()
     _db_content[table][ref] = obj
     return ref
 
@@ -341,7 +361,7 @@ def _create_sr(table, obj):
     sr_type = obj[6]
     # Forces fake to support iscsi only
     if sr_type != 'iscsi' and sr_type != 'nfs':
-        raise Failure(['SR_UNKNOWN_DRIVER', sr_type])
+        raise XenAPI.Failure(['SR_UNKNOWN_DRIVER', sr_type])
     host_ref = list(_db_content['host'])[0]
     sr_ref = _create_object(table, obj[2])
     if sr_type == 'iscsi':
@@ -433,7 +453,7 @@ def get_record(table, ref):
     if ref in _db_content[table]:
         return _db_content[table].get(ref)
     else:
-        raise Failure(['HANDLE_INVALID', table, ref])
+        raise XenAPI.Failure(['HANDLE_INVALID', table, ref])
 
 
 def check_for_session_leaks():
@@ -492,14 +512,14 @@ class SessionBase(object):
     def VBD_plug(self, _1, ref):
         rec = get_record('VBD', ref)
         if rec['currently_attached']:
-            raise Failure(['DEVICE_ALREADY_ATTACHED', ref])
+            raise XenAPI.Failure(['DEVICE_ALREADY_ATTACHED', ref])
         rec['currently_attached'] = True
-        rec['device'] = rec['userdevice']
+        rec['device'] = 'fakedev'
 
     def VBD_unplug(self, _1, ref):
         rec = get_record('VBD', ref)
         if not rec['currently_attached']:
-            raise Failure(['DEVICE_ALREADY_DETACHED', ref])
+            raise XenAPI.Failure(['DEVICE_ALREADY_DETACHED', ref])
         rec['currently_attached'] = False
         rec['device'] = ''
 
@@ -508,8 +528,8 @@ class SessionBase(object):
         if 'other_config' not in db_ref:
             db_ref['other_config'] = {}
         if key in db_ref['other_config']:
-            raise Failure(['MAP_DUPLICATE_KEY', 'VBD', 'other_config',
-                           vbd_ref, key])
+            raise XenAPI.Failure(
+                ['MAP_DUPLICATE_KEY', 'VBD', 'other_config', vbd_ref, key])
         db_ref['other_config'][key] = value
 
     def VBD_get_other_config(self, _1, vbd_ref):
@@ -526,7 +546,7 @@ class SessionBase(object):
     def PBD_plug(self, _1, pbd_ref):
         rec = get_record('PBD', pbd_ref)
         if rec['currently_attached']:
-            raise Failure(['DEVICE_ALREADY_ATTACHED', rec])
+            raise XenAPI.Failure(['DEVICE_ALREADY_ATTACHED', rec])
         rec['currently_attached'] = True
         sr_ref = rec['SR']
         _db_content['SR'][sr_ref]['PBDs'] = [pbd_ref]
@@ -534,14 +554,14 @@ class SessionBase(object):
     def PBD_unplug(self, _1, pbd_ref):
         rec = get_record('PBD', pbd_ref)
         if not rec['currently_attached']:
-            raise Failure(['DEVICE_ALREADY_DETACHED', rec])
+            raise XenAPI.Failure(['DEVICE_ALREADY_DETACHED', rec])
         rec['currently_attached'] = False
         sr_ref = rec['SR']
         _db_content['SR'][sr_ref]['PBDs'].remove(pbd_ref)
 
     def SR_introduce(self, _1, sr_uuid, label, desc, type, content_type,
                      shared, sm_config):
-        for ref, rec in six.iteritems(_db_content['SR']):
+        for ref, rec in _db_content['SR'].items():
             if rec.get('uuid') == sr_uuid:
                 # make forgotten = 0 and return ref
                 _db_content['SR'][ref]['forgotten'] = 0
@@ -606,8 +626,8 @@ class SessionBase(object):
         if 'other_config' not in db_ref:
             db_ref['other_config'] = {}
         if key in db_ref['other_config']:
-            raise Failure(['MAP_DUPLICATE_KEY', 'VDI', 'other_config',
-                           vdi_ref, key])
+            raise XenAPI.Failure(
+                ['MAP_DUPLICATE_KEY', 'VDI', 'other_config', vdi_ref, key])
         db_ref['other_config'][key] = value
 
     def VDI_copy(self, _1, vdi_to_copy_ref, sr_ref):
@@ -663,7 +683,6 @@ class SessionBase(object):
         assert vdi_ref
         return pickle.dumps(None)
 
-    _plugin_glance_upload_vhd = _plugin_pickle_noop
     _plugin_glance_upload_vhd2 = _plugin_pickle_noop
     _plugin_kernel_copy_vdi = _plugin_noop
     _plugin_kernel_create_kernel_ramdisk = _plugin_noop
@@ -757,16 +776,22 @@ class SessionBase(object):
     def _plugin_console_get_console_log(self, method, args):
         dom_id = args["dom_id"]
         if dom_id == 0:
-            raise Failure('Guest does not have a console')
-        return base64.b64encode(zlib.compress("dom_id: %s" % dom_id))
+            raise XenAPI.Failure('Guest does not have a console')
+        return base64.b64encode(
+            zlib.compress(("dom_id: %s" % dom_id).encode('utf-8')))
 
-    def _plugin_nova_plugin_version_get_version(self, method, args):
-        return pickle.dumps("1.3")
+    def _plugin_dom0_plugin_version_get_version(self, method, args):
+        return pickle.dumps("2.0")
 
     def _plugin_xenhost_query_gc(self, method, args):
         return pickle.dumps("False")
 
+    def _plugin_partition_utils_make_partition(self, method, args):
+        return pickle.dumps(None)
+
     def host_call_plugin(self, _1, _2, plugin, method, args):
+        plugin = plugin.rstrip('.py')
+
         func = getattr(self, '_plugin_%s_%s' % (plugin, method), None)
         if not func:
             raise Exception('No simulation in host_call_plugin for %s,%s' %
@@ -785,10 +810,10 @@ class SessionBase(object):
     def _VM_reboot(self, session, vm_ref):
         db_ref = _db_content['VM'][vm_ref]
         if db_ref['power_state'] != 'Running':
-            raise Failure(['VM_BAD_POWER_STATE',
-                'fake-opaque-ref', db_ref['power_state'].lower(), 'halted'])
+            raise XenAPI.Failure(['VM_BAD_POWER_STATE', 'fake-opaque-ref',
+                 db_ref['power_state'].lower(), 'halted'])
         db_ref['power_state'] = 'Running'
-        db_ref['domid'] = random.randrange(1, 1 << 16)
+        db_ref['domid'] = '%d' % (random.randrange(1, 1 << 16))
 
     def VM_clean_reboot(self, session, vm_ref):
         return self._VM_reboot(session, vm_ref)
@@ -799,7 +824,7 @@ class SessionBase(object):
     def VM_hard_shutdown(self, session, vm_ref):
         db_ref = _db_content['VM'][vm_ref]
         db_ref['power_state'] = 'Halted'
-        db_ref['domid'] = -1
+        db_ref['domid'] = "-1"
     VM_clean_shutdown = VM_hard_shutdown
 
     def VM_suspend(self, session, vm_ref):
@@ -852,8 +877,8 @@ class SessionBase(object):
             return meth(*full_params)
 
     def _login(self, method, params):
-        self._session = str(uuid.uuid4())
-        _session_info = {'uuid': str(uuid.uuid4()),
+        self._session = uuidutils.generate_uuid()
+        _session_info = {'uuid': uuidutils.generate_uuid(),
                          'this_host': list(_db_content['host'])[0]}
         _db_content['session'][self._session] = _session_info
 
@@ -951,7 +976,7 @@ class SessionBase(object):
                 if (field in _db_content[cls][ref]):
                     return _db_content[cls][ref][field]
             else:
-                raise Failure(['HANDLE_INVALID', cls, ref])
+                raise XenAPI.Failure(['HANDLE_INVALID', cls, ref])
 
         LOG.debug('Raising NotImplemented')
         raise NotImplementedError(
@@ -994,8 +1019,12 @@ class SessionBase(object):
 
         # Call hook to provide any fixups needed (ex. creating backrefs)
         after_hook = 'after_%s_create' % cls
-        if after_hook in globals():
-            globals()[after_hook](ref, params[1])
+        try:
+            func = _after_create_functions[after_hook]
+        except KeyError:
+            pass
+        else:
+            func(ref, params[1])
 
         obj = get_record(cls, ref)
 
@@ -1010,10 +1039,10 @@ class SessionBase(object):
         table = name.split('.')[0]
         ref = params[1]
         if ref not in _db_content[table]:
-            raise Failure(['HANDLE_INVALID', table, ref])
+            raise XenAPI.Failure(['HANDLE_INVALID', table, ref])
 
         # Call destroy function (if exists)
-        destroy_func = globals().get('destroy_%s' % table.lower())
+        destroy_func = _destroy_functions.get('destroy_%s' % table.lower())
         if destroy_func:
             destroy_func(ref)
         else:
@@ -1029,7 +1058,7 @@ class SessionBase(object):
                 result = as_value(result)
             task['result'] = result
             task['status'] = 'success'
-        except Failure as exc:
+        except XenAPI.Failure as exc:
             task['error_info'] = exc.details
             task['status'] = 'failed'
         task['finished'] = timeutils.utcnow()
@@ -1038,7 +1067,8 @@ class SessionBase(object):
     def _check_session(self, params):
         if (self._session is None or
                 self._session not in _db_content['session']):
-            raise Failure(['HANDLE_INVALID', 'session', self._session])
+            raise XenAPI.Failure(
+                ['HANDLE_INVALID', 'session', self._session])
         if len(params) == 0 or params[0] != self._session:
             LOG.debug('Raising NotImplemented')
             raise NotImplementedError('Call to XenAPI without using .xenapi')
@@ -1046,12 +1076,12 @@ class SessionBase(object):
     def _check_arg_count(self, params, expected):
         actual = len(params)
         if actual != expected:
-            raise Failure(['MESSAGE_PARAMETER_COUNT_MISMATCH',
-                                  expected, actual])
+            raise XenAPI.Failure(
+                ['MESSAGE_PARAMETER_COUNT_MISMATCH', expected, actual])
 
     def _get_by_field(self, recs, k, v, return_singleton):
         result = []
-        for ref, rec in six.iteritems(recs):
+        for ref, rec in recs.items():
             if rec.get(k) == v:
                 result.append(ref)
 
@@ -1059,14 +1089,14 @@ class SessionBase(object):
             try:
                 return result[0]
             except IndexError:
-                raise Failure(['UUID_INVALID', v, result, recs, k])
+                raise XenAPI.Failure(['UUID_INVALID', v, result, recs, k])
 
         return result
 
 
 class FakeXenAPI(object):
     def __init__(self):
-        self.Failure = Failure
+        self.Failure = XenAPI.Failure
 
 
 # Based upon _Method from xmlrpclib.
