@@ -16,18 +16,18 @@
 import functools
 import sys
 
-from oslo_config import cfg
+from os_xenapi.client import exception as xenapi_exception
 from oslo_log import log as logging
 import six
 
 from nova.compute import utils as compute_utils
+import nova.conf
 from nova import exception
 from nova.image import glance
 from nova import utils
 from nova.virt.xenapi import vm_utils
 
-CONF = cfg.CONF
-CONF.import_opt('num_retries', 'nova.image.glance', group='glance')
+CONF = nova.conf.CONF
 LOG = logging.getLogger(__name__)
 
 
@@ -38,6 +38,7 @@ class GlanceStore(object):
         def pick_glance(kwargs):
             server = next(glance_api_servers)
             kwargs['endpoint'] = server
+            kwargs['api_version'] = 2
             # NOTE(sdague): is the return significant here at all?
             return server
 
@@ -51,7 +52,8 @@ class GlanceStore(object):
         cb = functools.partial(retry_cb, context, instance)
 
         return session.call_plugin_serialized_with_retry(
-            'glance', fn, CONF.glance.num_retries, pick_glance, cb, **params)
+            'glance.py', fn, CONF.glance.num_retries, pick_glance, cb,
+            **params)
 
     def _make_params(self, context, session, image_id):
         return {'image_id': image_id,
@@ -65,7 +67,7 @@ class GlanceStore(object):
         try:
             vdis = self._call_glance_plugin(context, instance, session,
                                             'download_vhd2', params)
-        except exception.PluginRetriesExceeded:
+        except xenapi_exception.PluginRetriesExceeded:
             raise exception.CouldNotFetchImage(image_id=image_id)
 
         return vdis
@@ -90,5 +92,5 @@ class GlanceStore(object):
         try:
             self._call_glance_plugin(context, instance, session,
                                      'upload_vhd2', params)
-        except exception.PluginRetriesExceeded:
+        except xenapi_exception.PluginRetriesExceeded:
             raise exception.CouldNotUploadImage(image_id=image_id)
